"""
BiomeConversionID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class BiomeConversionID(IntEnum):
    Purity = 0
    Corruption = 1
    Hallow = 2
    GlowingMushroom = 3
    Crimson = 4
    Sand = 5
    Snow = 6
    Dirt = 7
    ChlorophyteSpread = 8
    ChlorophyteDefenseWhenChloroSpreads = 9
    ChlorophyteDefenseWhenEvilSpreads = 10
    PurificationPowder = 11
    ForcedCorruption = 12
    ForcedCrimson = 13
    ForcedHallow = 14
    ForcedGlowingMushroom = 15
    ForcedSand = 16
    ForcedSnow = 17
    ForcedDirt = 18
    ForcedJungle = 19
    ForcedTemple = 20
    ForcedDungeon = 21

