from terrex.id import MessageID
from terrex.packet.base import ServerPacket


class CrystalInvasionWipeAllTheThingsss(ServerPacket):
    id = MessageID.CrystalInvasionWipeAllTheThingsss

    def read(self, reader):
        pass
