"""
GlowMaskID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class GlowMaskID(IntEnum):
    FakeUser = -2
    NoneValue = -1
    UFOMinion = 0
    VortexAxe = 1
    VortexChainsawProjectile = 2
    VortexDrillProjectile = 3
    VortexHammer = 4
    VortexPickaxe = 5
    NebulaAxe = 6
    NebulaChainsawProjectile = 7
    NebulaDrillProjectile = 8
    NebulaHammer = 9
    NebulaPickaxe = 10
    MartianOfficer = 11
    NebulaArmorArm = 12
    VortexArmorBody = 13
    NebulaArmorBody = 14
    VortexArmorHead = 15
    NebulaArmorHead = 16
    NebulaArmorLegs = 17
    VortexArmorBodyFemale = 18
    NebulaArmorBodyFemale = 19
    VortexChainsawItem = 20
    VortexDrillItem = 21
    NebulaChainsawItem = 22
    NebulaDrillItem = 23
    BrainScrambler = 24
    Electrified = 25
    VortexItemHead = 26
    VortexItemBody = 27
    NebulaItemHead = 28
    NebulaItemBody = 29
    NebulaItemLegs = 30
    MartianEngineer = 31
    MartianTurret = 32
    MartianDrone = 33
    GigaZapper = 34
    LaserMachinegun = 35
    ElectrosphereLauncher = 36
    ElectrosphereMissile = 37
    Xenopopper = 38
    LaserDrill = 39
    LaserDrillTip = 40
    MartianUniformArmorHead = 41
    MartianUniformArmorBody = 42
    MartianUniformArmorBodyFemale = 43
    MartianUniformArmorArms = 44
    MartianUnifromTorso = 45
    MartianUniformHelmet = 46
    LaserMachinegunItem = 47
    MartianSaucer = 48
    MartianSaucerCore = 49
    MartianSaucerCannon = 50
    MartianAstroClock = 51
    MartianBathtub = 52
    MartianBed = 53
    MartianHoverChair = 54
    MartianChandelier = 55
    MartianChest = 56
    MartianDoorClosed = 57
    MartianDoorOpen = 58
    MartianDresser = 59
    MartianHolobookcase = 60
    MartianHoverCandle = 61
    MartianLamppost = 62
    MartianLantern = 63
    MartianPiano = 64
    MartianPlatform = 65
    MartianSofa = 66
    MartianTable = 67
    MartianTableLamp = 68
    MartianWorkBench = 69
    MartianAstroClockItem = 70
    MartianBathtubItem = 71
    MartianBedItem = 72
    MartianHoverChairItem = 73
    MartianChandelierItem = 74
    MartianChestItem = 75
    MartianDoorItem = 76
    MartianDresserItem = 77
    MartianHolobookcaseItem = 78
    MartianHoverCandleItem = 79
    MartianLamppostItem = 80
    MartianLanternItem = 81
    MartianPianoItem = 82
    MartianPlatformItem = 83
    MartianSofaItem = 84
    MartianTableItem = 85
    MartianTableLampItem = 86
    MartianWorkBenchItem = 87
    MartianSink = 88
    MartianSinkItem = 89
    BGMartianUFOSmall = 90
    BGMartianUFOBig = 91
    MothronWings = 92
    MartianConduitPlatingItem = 93
    MartianConduitPlatingTile = 94
    MartianConduitWallItem = 95
    HiTekSunglasses = 96
    HiTekSunglassesItem = 97
    MartianHairDye = 98
    MartianArmorDye = 99
    MartianProbe = 100
    MartianProbeDiode = 101
    ChargedBlasterCannon = 102
    ChlorophyteDye = 103
    PixieDye = 104
    WispDye = 105
    InfernalWispDye = 106
    UnicornWispDye = 107
    CultistTabletFront = 108
    CultistTabletBack = 109
    ShadowflameApparation = 110
    MeteorBrick = 111
    MeteorPlatform = 112
    MeteorBathtub = 113
    MeteorBed = 114
    MeteorBookcase = 115
    MeteorChair = 116
    MeteorChest = 117
    MeteorClock = 118
    MeteorDoorOpen = 119
    MeteorDresser = 120
    MeteorPiano = 121
    MeteorSink = 122
    MeteorSofa = 123
    MeteorTable = 124
    MeteorWorkbench = 125
    LavaMoss = 126
    LongLavaMoss = 127
    DeadlySphere = 128
    LavaLamp = 129
    LavaLampTile = 130
    EnchantedNightcrawler = 131
    LunarTowerStardust = 132
    StardustWormBody = 133
    StardustWormTail = 134
    StardustWormHead = 135
    StardustSoldier = 136
    StardustSpiderSmall = 137
    StardustSpiderBig = 138
    StardustJellyfishBig = 139
    StardustJellyfishSmall = 140
    StardustCellBig = 141
    StardustCellSmall = 142
    LunarTowerNebula = 143
    NebulaSoldier = 144
    NebulaBeast = 145
    NebulaHeadcrab = 146
    NebulaBrain = 147
    NebulaEye = 148
    LunarTowerVortex = 149
    VortexRifleman = 150
    VortexSoldier = 151
    VortexHornet = 152
    VortexHornetQueen = 153
    SolarSolenian = 154
    SolarDrakoMire = 155
    SolarDrakoMireRider = 156
    SolarCrawltipedeHead = 157
    SolarCrawltipedeBody = 158
    SolarCrawltipedeTail = 159
    SolarSroller = 160
    SolarCorite = 161
    LunarTowerSolar = 162
    SolarSpearman = 163
    MartianWalker = 164
    MartianWalkerCannon = 165
    Truffle = 166
    Cyborg = 167
    TruffleSpore = 168
    DesertGhoulCorruption = 169
    DesertGhoulCrimson = 170
    DesertGhoulHallow = 171
    DesertDjinn = 172
    PortalGunProj = 173
    StardustAxeItem = 174
    StardustChainsawItem = 175
    StardustDrillItem = 176
    StardustHammerItem = 177
    StardustPickaxeItem = 178
    StardustChainsawProjectile = 179
    StardustDrillProjectile = 180
    WingsVortex = 181
    WingsNebula = 182
    WingsStardust = 183
    ArmorStardustHead = 184
    ArmorStardustBodyMale = 185
    ArmorStardustBodyFemale = 186
    ArmorStardustLegs = 187
    ArmorStardustArm = 188
    StardustCellMinion = 189
    StardustCellMinionShot = 190
    VortexBeaterItem = 191
    VortexBeaterProj = 192
    VortexBeaterRocket = 193
    NebulaArcanumItem = 194
    NebulaArcanumItemHold = 195
    LunarHamaxeVortex = 196
    LunarHamaxeNebula = 197
    LunarHamaxeStardust = 198
    VortexArmorLegs = 199
    Phantasm = 200
    LunarMonolith = 201
    LunarCraftingStation = 202
    LunarHookSolar = 203
    LunarHookVortex = 204
    LunarHookNebula = 205
    LunarHookStardust = 206
    NebulaBlaze = 207
    JimsHead = 208
    LokisHelm = 209
    LokisBody = 210
    LokisArm = 211
    LokisLegs = 212
    LokisWings = 213
    WireBulb = 214
    CannonTile = 215
    SandElemental = 216
    ForbiddenSign = 217
    SpiritFlameItem = 218
    BlackBolt = 219
    BlackBoltEye = 220
    DD2FlameBurstTowerT1 = 221
    DD2FlameBurstTowerT2 = 222
    DD2FlameBurstTowerT3 = 223
    DD2WitherBeast = 224
    DD2DarkMage = 225
    DD2Betsy = 226
    DD2SquireBetsySword = 227
    DD2LightningAuraT1 = 228
    DD2LightningAuraT2 = 229
    DD2LightningAuraT3 = 230
    MonkStaffT2 = 231
    MonkStaffT3 = 232
    MonkStaffT3Item = 233
    BetsyBow = 234
    DD2ExplosiveTrapT1 = 235
    DD2ExplosiveTrapT2 = 236
    DD2ExplosiveTrapT3 = 237
    BetsysWrath = 238
    DD2CrystalOrb = 239
    ApprenticeDarkArmFlame = 240
    ApprenticeDarkHeadFlame = 241
    ValhallaKnightHead = 242
    DefendersForge = 243
    DefendersForgeItem = 244
    ArkhalisHat = 245
    ArkhalisShirt_Male = 246
    ArkhalisShirt_Female = 247
    ArkhalisShirt_Arm = 248
    ArkhalisPants_Male = 249
    ArkhalisPants_Female = 250
    ArkhalisWings = 251
    BoulderStaffOfEarth = 252
    Everscream = 253
    Santank = 254
    HeadlessHorseman = 255
    UltraBrightHelmet = 256
    JackOLantern = 257
    LavaMossBrick = 258
    KryptonMoss = 259
    KryptonMossBrick = 260
    XenonMoss = 261
    XenonMossBrick = 262
    ArgonMoss = 263
    ArgonMossBrick = 264
    VoidMonolith = 265
    ScarabBomb = 266
    PlasmaLamp = 267
    PinkFairyJar = 268
    GreenFairyJar = 269
    BlueFairyJar = 270
    FirstFractal = 271
    GroxTheGreatWings = 272
    GroxTheGreatHelm = 273
    GroxTheGreatGreaves = 274
    DestroyerPet = 275
    SkeletronPrimePet = 276
    GolemPet = 277
    PumpkingPet = 278
    EverscreamPet = 279
    FairyQueenPet = 280
    MartianPet = 281
    MoonLordPet = 282
    SpookyWoodMount = 283
    WallOfFleshGoatMount = 284
    LavaSharkMount = 285
    GemSquirrel = 286
    GemBunny = 287
    HellButterfly = 288
    HellButterflyJar = 289
    Lavafly = 290
    LavaflyinaBottle = 291
    MagmaSnail = 292
    MagmaSnailCage = 293
    BrazierSuspended = 294
    VolcanoSmall = 295
    VolcanoLarge = 296
    PottedPlants2 = 297
    PottedLavaPlants = 298
    PottedLavaPlantTendrils = 299
    TruffleWormCage = 300
    RoninHat = 301
    TimelessTravelerHood = 302
    TimelessTravelerBottom = 303
    FloretProtectorHelmet = 304
    CapricornMask = 305
    CapricornLegs = 306
    CapricornTail = 307
    FloretProtectorFrontTube = 308
    TVHeadMask = 309
    Magiluminescence = 310
    VioletMoss = 311
    VioletMossBrick = 312
    RainbowMoss = 313
    RainbowMossBrick = 314
    TreeAsh = 315
    TreeAshTop = 316
    TreeAshBranches = 317
    FishingBobberGlowingStar = 318
    FishingBobberGlowingLava = 319
    FishingBobberGlowingKrypton = 320
    FishingBobberGlowingXenon = 321
    FishingBobberGlowingArgon = 322
    FishingBobberGlowingViolet = 323
    FishingBobberGlowingRainbow = 324
    Sundial = 325
    AshGrass = 326
    AshVines = 327
    LightsBane = 328
    GlowTulip = 329
    EchoMonolith = 330
    ShimmerCloakFront = 331
    ShimmerCloakBack = 332
    ShimmerMonolith = 333
    ShimmerMonolithOrb = 334
    Moondial = 335
    LavaMossBlock = 336
    ArgonMossBlock = 337
    KryptonMossBlock = 338
    XenonMossBlock = 339
    VioletMossBlock = 340
    RainbowMossBlock = 341
    LavaMossBlockWall = 342
    ArgonMossBlockWall = 343
    KryptonMossBlockWall = 344
    XenonMossBlockWall = 345
    VioletMossBlockWall = 346
    RainbowMossBlockWall = 347
    ShimmerBlock = 348
    ShimmerBrick = 349
    CyborgShimmered = 350
    CyborgShimmeredParty = 351
    TruffleShimmered = 352
    DeadCellsPotionStation = 353
    DeadCellsMushroomBoi = 354
    DeadCellsFlint = 355
    DeadCellsBarrel = 356
    DeadCellsBeheadedHead = 357
    EelWhip = 358
    Shimmerfall = 359
    FireImp = 360
    ShimmerfallWall = 361
    LavaCloud = 362
    ChickenBonesRobeLeg = 363
    ChickenBonesRobeTorso = 364
    ChickenBonesHead = 365
    ChickenBonesWings = 366
    UpgradedMiningHead = 367
    CRTMonolith = 368
    RetroMonolith = 369
    BatMountBody = 370
    NoirMonolith = 371
    RainbowPhaseblade = 372
    RainbowPhasesaber = 373
    TrueCopperShortsword = 374
    KazzymodusHood = 375
    KazzymodusChestpiece = 376
    PalworldDigtoise = 377
    LunasHead = 378

