"""
ItemHoldStyleID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class ItemHoldStyleID(IntEnum):
    NoneValue = 0
    HoldFront = 1
    HoldUp = 2
    HoldHeavy = 3
    HoldGolfClub = 4
    HoldGuitar = 5
    HoldLamp = 6
    HoldRadio = 7
    HoldOrb = 8

