"""
AmmoID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from terrex.id.set_factory import SetFactory
from enum import IntEnum, auto
from terrex.id.ItemID import ItemID


class AmmoID(IntEnum):
    NoneValue = 0
    Gel = 23
    Acorn = 27
    Arrow = 40
    Coin = 71
    FallenStar = 75
    Bullet = 97
    Sand = 169
    Dart = 283
    Rocket = 771
    Solution = 780
    Flare = 931
    Snowball = 949
    StyngerBolt = 1261
    CandyCorn = 1783
    JackOLantern = 1785
    Stake = 1836
    NailFriendly = 3108
    Count = 0


class AmmoIDSets:
    class Main:
        factory = SetFactory(ItemID.Count)
        IsArrow = factory.create_bool_set(False, AmmoID.Arrow, AmmoID.Stake)
        IsBullet = factory.create_bool_set(False, AmmoID.Bullet, AmmoID.CandyCorn)
        IsSpecialist = factory.create_bool_set(False, AmmoID.Rocket, AmmoID.StyngerBolt, AmmoID.JackOLantern, AmmoID.NailFriendly, AmmoID.Coin, AmmoID.Flare, AmmoID.Dart, AmmoID.Snowball, AmmoID.FallenStar, AmmoID.Gel)
