"""
DustID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class DustID(IntEnum):
    Dirt = 0
    Stone = 1
    Grass = 2
    GrassBlades = 3
    TintableDust = 4
    t_Slime = 4
    Blood = 5
    t_Flesh = 5
    Torch = 6
    Iron = 8
    t_SteampunkMetal = 8
    Copper = 9
    Gold = 10
    t_Golden = 10
    Silver = 11
    LifeCrystal = 12
    Glass = 13
    Corruption = 14
    JesterSparkleBlue = 15
    Cloud = 16
    CorruptPlants = 17
    CorruptGibs = 18
    t_Meteor = 23
    Bone = 26
    Shadowflame = 27
    WaterCandle = 29
    Web = 30
    Smoke = 31
    Sand = 32
    UnderwaterBubble = 34
    Lava = 35
    Ash = 36
    JunglePlants = 40
    t_Cactus = 40
    TintableDustLighted = 43
    HallowedPlants = 47
    JesterSparkleYellow = 57
    PinkStarfury = 58
    BlueTorch = 59
    RedTorch = 60
    GreenTorch = 61
    PurpleTorch = 62
    WhiteTorch = 63
    YellowTorch = 64
    DemonTorch = 65
    RainbowTorch = 66
    BlueCrystalShard = 68
    t_Crystal = 68
    PinkCrystalShard = 69
    PurpleCrystalShard = 70
    CursedTorch = 75
    t_LivingWood = 78
    t_PearlWood = 78
    Ice = 80
    t_Frozen = 80
    Tin = 81
    Lead = 82
    Tungsten = 83
    Platinum = 84
    GemAmethyst = 86
    GemTopaz = 87
    GemSapphire = 88
    GemEmerald = 89
    GemRuby = 90
    GemDiamond = 91
    GreenMoss = 93
    BrownMoss = 94
    RedMoss = 95
    BlueMoss = 96
    PurpleMoss = 97
    Terra = 107
    PureSpray = 110
    HallowSpray = 111
    CorruptSpray = 112
    MushroomSpray = 113
    CrimsonSpray = 114
    Crimson = 115
    CrimsonPlants = 125
    Flare = 127
    IceTorch = 135
    GemAmber = 138
    Confetti = 139
    TintablePaint = 143
    t_Honey = 147
    t_Lihzahrd = 148
    Honey = 152
    UltraBrightTorch = 156
    Chlorophyte = 157
    OrangeTorch = 158
    BlueGreenElectricity = 160
    HeatRay = 162
    PlanteraPetal = 166
    PlanteraGrass = 167
    PlanteraBulb = 168
    IchorTorch = 169
    IchorSplash = 170
    Shadowbeam = 173
    Eater = 184
    BlueFlare = 187
    SnowflakeIce = 197
    t_BorealWood = 214
    Fireworks = 219
    Electric = 226
    t_Martian = 226
    MartianBlood = 227
    GoldFlame = 228
    Vortex = 229
    BoneTorch = 234
    Marble = 236
    t_Marble = 236
    Mothron = 237
    MothronEgg = 238
    Silk = 239
    Granite = 240
    t_Granite = 240
    MarblePot = 241
    PinkTorch = 242
    PinkSlime = 243
    CopperCoin = 244
    SilverCoin = 245
    GoldCoin = 246
    PlatinumCoin = 247
    EnchantedNightcrawler = 248
    Grubby = 249
    Sluggy = 250
    Buggy = 251
    CrystalPulse = 254
    CrystalPulse2 = 255
    ToxicBubble = 256
    BubbleBlock = 257
    LavaMoss = 258
    SolarFlare = 259
    SparksMech = 260
    AncientLight = 261
    AmberBolt = 262
    PortalBolt = 263
    PortalBoltTrail = 264
    LunarOre = 265
    SomethingRed = 266
    RainbowMk2 = 267
    Sandstorm = 268
    Sandnado = 269
    FlameBurst = 270
    HealingPlus = 271
    WitherLightning = 272
    GreenBlood = 273
    ApprenticeStorm = 274
    DungeonBlue = 275
    DungeonGreen = 276
    DungeonPink = 277
    FireworksRGB = 278
    SilverFlame = 279
    BeachShell = 280
    RedStarfish = 281
    PinkStarfish = 282
    YellowStarfish = 283
    FoodPiece = 284
    GolfPaticle = 285
    OrangeStainedGlass = 286
    DesertPot = 287
    DesertWater2 = 288
    SeaOatsOasis = 289
    SeaOatsBeach = 290
    OasisCactus = 291
    YellowStarDust = 292
    DesertTorch = 293
    CoralTorch = 294
    CorruptTorch = 295
    CrimsonTorch = 296
    HallowedTorch = 297
    JungleTorch = 298
    KryptonMoss = 299
    XenonMoss = 300
    ArgonMoss = 301
    Terragrim = 302
    SteampunkSteam = 303
    Firefly = 304
    VioletMoss = 305
    SparkForLightDisc = 306
    MushroomTorch = 307
    ShimmerSplash = 308
    ShimmerSpark = 309
    ShimmerTorch = 310
    SandSpray = 311
    SnowSpray = 312
    DirtSpray = 313
    LunarRust = 314
    DarkCelestial = 315
    Astra = 316
    CosmicEmber = 317
    Cryocore = 318
    Mercury = 319
    StarRoyale = 320
    Heavenforge = 321
    Poop = 322
    MoonBoulder = 323
    ShimmerStream = 324
    PinkPhaseblade = 325
    LavaCloud = 326
    StarCloud = 327
    RainbowCloud = 328
    BirdDroppings = 329
    PrettyMirror = 330

