"""
MusicID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 07:02 UTC
"""

from terrex.id.set_factory import SetFactory
from enum import IntEnum, auto


class MusicID(IntEnum):
    NoneValue = 0
    OverworldDay = 1
    Eerie = 2
    OverworldNight = 3
    Underground = 4
    Boss1 = 5
    TitleClassic = 6
    JungleDay = 7
    Corruption = 8
    Hallow = 9
    UndergroundCorruption = 10
    UndergroundHallow = 11
    Boss2 = 12
    Boss3 = 13
    Snow = 14
    SpaceNight = 15
    Crimson = 16
    Golem = 17
    OverworldDayAlt = 18
    Rain = 19
    Ice = 20
    Desert = 21
    OceanDay = 22
    Dungeon = 23
    Plantera = 24
    Boss5 = 25
    Temple = 26
    Eclipse = 27
    RainAmbience = 28
    Mushroom = 29
    PumpkinMoon = 30
    UndergroundAlt = 31
    FrostMoon = 32
    UndergroundCrimson = 33
    LunarPillars = 34
    PirateInvasion = 35
    Underworld = 36
    MartianMadness = 37
    MoonLord = 38
    GoblinArmy = 39
    Sandstorm = 40
    OldOnesArmy = 41
    SpaceDay = 42
    OceanNight = 43
    WindyDay = 44
    WindAmbience = 45
    TownDay = 46
    TownNight = 47
    SlimeRain = 48
    OverworldDayRemix = 49
    TitleJourneysBeginningWithIntro = 50
    TitleJourneysBeginning = 51
    Storm = 52
    Graveyard = 53
    UndergroundJungle = 54
    JungleNight = 55
    QueenSlime = 56
    EmpressOfLight = 57
    DukeFishron = 58
    MorningRain = 59
    TitleAlt = 60
    UndergroundDesert = 61
    OtherworldRain = 62
    OtherworlddDay = 63
    OtherworldNight = 64
    OtherworldUnderground = 65
    OtherworldDesert = 66
    OtherworldOcean = 67
    OtherworldMushroom = 68
    OtherworldDungeon = 69
    OtherworldSpace = 70
    OtherworldUnderworld = 71
    OtherworldSnow = 72
    OtherworldCorruption = 73
    OtherworldUndergroundCorruption = 74
    OtherworldCrimson = 75
    OtherworldUndergroundCrimson = 76
    OtherworldIce = 77
    OtherworldUndergroundHallow = 78
    OtherworldEerie = 79
    OtherworldBoss2 = 80
    OtherworldBoss1 = 81
    OtherworldInvasion = 82
    OtherworldLunarPillars = 83
    OtherworldMoonLord = 84
    OtherworldPlantera = 85
    OtherworldJungle = 86
    OtherworldWallOfFlesh = 87
    OtherworldHallow = 88
    JourneysEnd = 89
    Deerclops = 90
    Aether = 91
    Destroyer = 92
    KingSlime = 93
    LunaticCultist = 94
    QueenBeeAlt = 95
    QueenBee = 96
    Twins = 97
    SkeletronPrime = 98
    EaterOfWorlds = 99
    TorchGodVocals = 100
    TorchGodInstrumental = 101
    RainbowBoulderStart = 102
    RainbowBoulderLoop = 103
    Skeletron = 104
    Count = 105


class MusicIDSets:
    class Main:
        factory = SetFactory(MusicID.Count)
        CanBeRecorded = factory.create_bool_set(True, 0, 28, 45, 103, 102)
