"""
ProjectileDrawLayerID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class ProjectileDrawLayerID(IntEnum):
    NoneValue = 0
    BehindNPCsAndTiles = 1
    BehindNPCs = 2
    BehindProjectiles = 3
    OverPlayers = 4
    OverWiresUI = 5
    FirstFractals = 6
    HeldProj = 7
    HeldProjOverHand = 8

