"""
PlayerVariantID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from terrex.id.set_factory import SetFactory
from enum import IntEnum, auto


class PlayerVariantID(IntEnum):
    MaleStarter = 0
    MaleSticker = 1
    MaleGangster = 2
    MaleCoat = 3
    FemaleStarter = 4
    FemaleSticker = 5
    FemaleGangster = 6
    FemaleCoat = 7
    MaleDress = 8
    FemaleDress = 9
    MaleDisplayDoll = 10
    FemaleDisplayDoll = 11
    Count = 12


class PlayerVariantIDSets:
    class Main:
        factory = SetFactory(PlayerVariantID.Count)
        Male = factory.create_bool_set(False, 0, 1, 2, 3, 8, 10)
        AltGenderReference = factory.create_int_set(0, 0, 4, 4, 0, 1, 5, 5, 1, 2, 6, 6, 2, 3, 7, 7, 3, 8, 9, 9, 8, 10, 11, 11, 10)
        VariantOrderMale = [0, 1, 2, 3, 8, 10]
        VariantOrderFemale = [4, 5, 6, 7, 9, 11]
