"""
NPCID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 06:54 UTC
"""

from terrex.id.set_factory import SetFactory
from enum import IntEnum, auto


class NPCID:
    Count = 697

    class BasicNPCPortrait(IntEnum):
        NegativeIDCount = -66
        BigHornetStingy = -65
        LittleHornetStingy = -64
        BigHornetSpikey = -63
        LittleHornetSpikey = -62
        BigHornetLeafy = -61
        LittleHornetLeafy = -60
        BigHornetHoney = -59
        LittleHornetHoney = -58
        BigHornetFatty = -57
        LittleHornetFatty = -56
        BigRainZombie = -55
        SmallRainZombie = -54
        BigPantlessSkeleton = -53
        SmallPantlessSkeleton = -52
        BigMisassembledSkeleton = -51
        SmallMisassembledSkeleton = -50
        BigHeadacheSkeleton = -49
        SmallHeadacheSkeleton = -48
        BigSkeleton = -47
        SmallSkeleton = -46
        BigFemaleZombie = -45
        SmallFemaleZombie = -44
        DemonEye2 = -43
        PurpleEye2 = -42
        GreenEye2 = -41
        DialatedEye2 = -40
        SleepyEye2 = -39
        CataractEye2 = -38
        BigTwiggyZombie = -37
        SmallTwiggyZombie = -36
        BigSwampZombie = -35
        SmallSwampZombie = -34
        BigSlimedZombie = -33
        SmallSlimedZombie = -32
        BigPincushionZombie = -31
        SmallPincushionZombie = -30
        BigBaldZombie = -29
        SmallBaldZombie = -28
        BigZombie = -27
        SmallZombie = -26
        BigCrimslime = -25
        LittleCrimslime = -24
        BigCrimera = -23
        LittleCrimera = -22
        GiantMossHornet = -21
        BigMossHornet = -20
        LittleMossHornet = -19
        TinyMossHornet = -18
        BigStinger = -17
        LittleStinger = -16
        HeavySkeleton = -15
        BigBoned = -14
        ShortBones = -13
        BigEater = -12
        LittleEater = -11
        JungleSlime = -10
        YellowSlime = -9
        RedSlime = -8
        PurpleSlime = -7
        BlackSlime = -6
        BabySlime = -5
        Pinky = -4
        GreenSlime = -3
        Slimer2 = -2
        Slimeling = -1
        NoneValue = 0
        BlueSlime = 1
        DemonEye = 2
        Zombie = 3
        EyeofCthulhu = 4
        ServantofCthulhu = 5
        EaterofSouls = 6
        DevourerHead = 7
        DevourerBody = 8
        DevourerTail = 9
        GiantWormHead = 10
        GiantWormBody = 11
        GiantWormTail = 12
        EaterofWorldsHead = 13
        EaterofWorldsBody = 14
        EaterofWorldsTail = 15
        MotherSlime = 16
        Merchant = 17
        Nurse = 18
        ArmsDealer = 19
        Dryad = 20
        Skeleton = 21
        Guide = 22
        MeteorHead = 23
        FireImp = 24
        BurningSphere = 25
        GoblinPeon = 26
        GoblinThief = 27
        GoblinWarrior = 28
        GoblinSorcerer = 29
        ChaosBall = 30
        AngryBones = 31
        DarkCaster = 32
        WaterSphere = 33
        CursedSkull = 34
        SkeletronHead = 35
        SkeletronHand = 36
        OldMan = 37
        Demolitionist = 38
        BoneSerpentHead = 39
        BoneSerpentBody = 40
        BoneSerpentTail = 41
        Hornet = 42
        ManEater = 43
        UndeadMiner = 44
        Tim = 45
        Bunny = 46
        CorruptBunny = 47
        Harpy = 48
        CaveBat = 49
        KingSlime = 50
        JungleBat = 51
        DoctorBones = 52
        TheGroom = 53
        Clothier = 54
        Goldfish = 55
        Snatcher = 56
        CorruptGoldfish = 57
        Piranha = 58
        LavaSlime = 59
        Hellbat = 60
        Vulture = 61
        Demon = 62
        BlueJellyfish = 63
        PinkJellyfish = 64
        Shark = 65
        VoodooDemon = 66
        Crab = 67
        DungeonGuardian = 68
        Antlion = 69
        SpikeBall = 70
        DungeonSlime = 71
        BlazingWheel = 72
        GoblinScout = 73
        Bird = 74
        Pixie = 75
        None2 = 76
        ArmoredSkeleton = 77
        Mummy = 78
        DarkMummy = 79
        LightMummy = 80
        CorruptSlime = 81
        Wraith = 82
        CursedHammer = 83
        EnchantedSword = 84
        Mimic = 85
        Unicorn = 86
        WyvernHead = 87
        WyvernLegs = 88
        WyvernBody = 89
        WyvernBody2 = 90
        WyvernBody3 = 91
        WyvernTail = 92
        GiantBat = 93
        Corruptor = 94
        DiggerHead = 95
        DiggerBody = 96
        DiggerTail = 97
        SeekerHead = 98
        SeekerBody = 99
        SeekerTail = 100
        Clinger = 101
        AnglerFish = 102
        GreenJellyfish = 103
        Werewolf = 104
        BoundGoblin = 105
        BoundWizard = 106
        GoblinTinkerer = 107
        Wizard = 108
        Clown = 109
        SkeletonArcher = 110
        GoblinArcher = 111
        VileSpit = 112
        WallofFlesh = 113
        WallofFleshEye = 114
        TheHungry = 115
        TheHungryII = 116
        LeechHead = 117
        LeechBody = 118
        LeechTail = 119
        ChaosElemental = 120
        Slimer = 121
        Gastropod = 122
        BoundMechanic = 123
        Mechanic = 124
        Retinazer = 125
        Spazmatism = 126
        SkeletronPrime = 127
        PrimeCannon = 128
        PrimeSaw = 129
        PrimeVice = 130
        PrimeLaser = 131
        BaldZombie = 132
        WanderingEye = 133
        TheDestroyer = 134
        TheDestroyerBody = 135
        TheDestroyerTail = 136
        IlluminantBat = 137
        IlluminantSlime = 138
        Probe = 139
        PossessedArmor = 140
        ToxicSludge = 141
        SantaClaus = 142
        SnowmanGangsta = 143
        MisterStabby = 144
        SnowBalla = 145
        None3 = 146
        IceSlime = 147
        Penguin = 148
        PenguinBlack = 149
        IceBat = 150
        Lavabat = 151
        GiantFlyingFox = 152
        GiantTortoise = 153
        IceTortoise = 154
        Wolf = 155
        RedDevil = 156
        Arapaima = 157
        VampireBat = 158
        Vampire = 159
        Truffle = 160
        ZombieEskimo = 161
        Frankenstein = 162
        BlackRecluse = 163
        WallCreeper = 164
        WallCreeperWall = 165
        SwampThing = 166
        UndeadViking = 167
        CorruptPenguin = 168
        IceElemental = 169
        PigronCorruption = 170
        PigronHallow = 171
        RuneWizard = 172
        Crimera = 173
        Herpling = 174
        AngryTrapper = 175
        MossHornet = 176
        Derpling = 177
        Steampunker = 178
        CrimsonAxe = 179
        PigronCrimson = 180
        FaceMonster = 181
        FloatyGross = 182
        Crimslime = 183
        SpikedIceSlime = 184
        SnowFlinx = 185
        PincushionZombie = 186
        SlimedZombie = 187
        SwampZombie = 188
        TwiggyZombie = 189
        CataractEye = 190
        SleepyEye = 191
        DialatedEye = 192
        GreenEye = 193
        PurpleEye = 194
        LostGirl = 195
        Nymph = 196
        ArmoredViking = 197
        Lihzahrd = 198
        LihzahrdCrawler = 199
        FemaleZombie = 200
        HeadacheSkeleton = 201
        MisassembledSkeleton = 202
        PantlessSkeleton = 203
        SpikedJungleSlime = 204
        Moth = 205
        IcyMerman = 206
        DyeTrader = 207
        PartyGirl = 208
        Cyborg = 209
        Bee = 210
        BeeSmall = 211
        PirateDeckhand = 212
        PirateCorsair = 213
        PirateDeadeye = 214
        PirateCrossbower = 215
        PirateCaptain = 216
        CochinealBeetle = 217
        CyanBeetle = 218
        LacBeetle = 219
        SeaSnail = 220
        Squid = 221
        QueenBee = 222
        ZombieRaincoat = 223
        FlyingFish = 224
        UmbrellaSlime = 225
        FlyingSnake = 226
        Painter = 227
        WitchDoctor = 228
        Pirate = 229
        GoldfishWalker = 230
        HornetFatty = 231
        HornetHoney = 232
        HornetLeafy = 233
        HornetSpikey = 234
        HornetStingy = 235
        JungleCreeper = 236
        JungleCreeperWall = 237
        BlackRecluseWall = 238
        BloodCrawler = 239
        BloodCrawlerWall = 240
        BloodFeeder = 241
        BloodJelly = 242
        IceGolem = 243
        RainbowSlime = 244
        Golem = 245
        GolemHead = 246
        GolemFistLeft = 247
        GolemFistRight = 248
        GolemHeadFree = 249
        AngryNimbus = 250
        Eyezor = 251
        Parrot = 252
        Reaper = 253
        ZombieMushroom = 254
        ZombieMushroomHat = 255
        FungoFish = 256
        AnomuraFungus = 257
        MushiLadybug = 258
        FungiBulb = 259
        GiantFungiBulb = 260
        FungiSpore = 261
        Plantera = 262
        PlanterasHook = 263
        PlanterasTentacle = 264
        Spore = 265
        BrainofCthulhu = 266
        Creeper = 267
        IchorSticker = 268
        RustyArmoredBonesAxe = 269
        RustyArmoredBonesFlail = 270
        RustyArmoredBonesSword = 271
        RustyArmoredBonesSwordNoArmor = 272
        BlueArmoredBones = 273
        BlueArmoredBonesMace = 274
        BlueArmoredBonesNoPants = 275
        BlueArmoredBonesSword = 276
        HellArmoredBones = 277
        HellArmoredBonesSpikeShield = 278
        HellArmoredBonesMace = 279
        HellArmoredBonesSword = 280
        RaggedCaster = 281
        RaggedCasterOpenCoat = 282
        Necromancer = 283
        NecromancerArmored = 284
        DiabolistRed = 285
        DiabolistWhite = 286
        BoneLee = 287
        DungeonSpirit = 288
        GiantCursedSkull = 289
        Paladin = 290
        SkeletonSniper = 291
        TacticalSkeleton = 292
        SkeletonCommando = 293
        AngryBonesBig = 294
        AngryBonesBigMuscle = 295
        AngryBonesBigHelmet = 296
        BirdBlue = 297
        BirdRed = 298
        Squirrel = 299
        Mouse = 300
        Raven = 301
        SlimeMasked = 302
        BunnySlimed = 303
        HoppinJack = 304
        Scarecrow1 = 305
        Scarecrow2 = 306
        Scarecrow3 = 307
        Scarecrow4 = 308
        Scarecrow5 = 309
        Scarecrow6 = 310
        Scarecrow7 = 311
        Scarecrow8 = 312
        Scarecrow9 = 313
        Scarecrow10 = 314
        HeadlessHorseman = 315
        Ghost = 316
        DemonEyeOwl = 317
        DemonEyeSpaceship = 318
        ZombieDoctor = 319
        ZombieSuperman = 320
        ZombiePixie = 321
        SkeletonTopHat = 322
        SkeletonAstonaut = 323
        SkeletonAlien = 324
        MourningWood = 325
        Splinterling = 326
        Pumpking = 327
        PumpkingBlade = 328
        Hellhound = 329
        Poltergeist = 330
        ZombieXmas = 331
        ZombieSweater = 332
        SlimeRibbonWhite = 333
        SlimeRibbonYellow = 334
        SlimeRibbonGreen = 335
        SlimeRibbonRed = 336
        BunnyXmas = 337
        ZombieElf = 338
        ZombieElfBeard = 339
        ZombieElfGirl = 340
        PresentMimic = 341
        GingerbreadMan = 342
        Yeti = 343
        Everscream = 344
        IceQueen = 345
        SantaNK1 = 346
        ElfCopter = 347
        Nutcracker = 348
        NutcrackerSpinning = 349
        ElfArcher = 350
        Krampus = 351
        Flocko = 352
        Stylist = 353
        WebbedStylist = 354
        Firefly = 355
        Butterfly = 356
        Worm = 357
        LightningBug = 358
        Snail = 359
        GlowingSnail = 360
        Frog = 361
        Duck = 362
        Duck2 = 363
        DuckWhite = 364
        DuckWhite2 = 365
        ScorpionBlack = 366
        Scorpion = 367
        TravellingMerchant = 368
        Angler = 369
        DukeFishron = 370
        DetonatingBubble = 371
        Sharkron = 372
        Sharkron2 = 373
        TruffleWorm = 374
        TruffleWormDigger = 375
        SleepingAngler = 376
        Grasshopper = 377
        ChatteringTeethBomb = 378
        CultistArcherBlue = 379
        CultistArcherWhite = 380
        BrainScrambler = 381
        RayGunner = 382
        MartianOfficer = 383
        ForceBubble = 384
        GrayGrunt = 385
        MartianEngineer = 386
        MartianTurret = 387
        MartianDrone = 388
        GigaZapper = 389
        ScutlixRider = 390
        Scutlix = 391
        MartianSaucer = 392
        MartianSaucerTurret = 393
        MartianSaucerCannon = 394
        MartianSaucerCore = 395
        MoonLordHead = 396
        MoonLordHand = 397
        MoonLordCore = 398
        MartianProbe = 399
        MoonLordFreeEye = 400
        MoonLordLeechBlob = 401
        StardustWormHead = 402
        StardustWormBody = 403
        StardustWormTail = 404
        StardustCellBig = 405
        StardustCellSmall = 406
        StardustJellyfishBig = 407
        StardustJellyfishSmall = 408
        StardustSpiderBig = 409
        StardustSpiderSmall = 410
        StardustSoldier = 411
        SolarCrawltipedeHead = 412
        SolarCrawltipedeBody = 413
        SolarCrawltipedeTail = 414
        SolarDrakomire = 415
        SolarDrakomireRider = 416
        SolarSroller = 417
        SolarCorite = 418
        SolarSolenian = 419
        NebulaBrain = 420
        NebulaHeadcrab = 421
        LunarTowerVortex = 422
        NebulaBeast = 423
        NebulaSoldier = 424
        VortexRifleman = 425
        VortexHornetQueen = 426
        VortexHornet = 427
        VortexLarva = 428
        VortexSoldier = 429
        ArmedZombie = 430
        ArmedZombieEskimo = 431
        ArmedZombiePincussion = 432
        ArmedZombieSlimed = 433
        ArmedZombieSwamp = 434
        ArmedZombieTwiggy = 435
        ArmedZombieCenx = 436
        CultistTablet = 437
        CultistDevote = 438
        CultistBoss = 439
        CultistBossClone = 440
        TaxCollector = 441
        GoldBird = 442
        GoldBunny = 443
        GoldButterfly = 444
        GoldFrog = 445
        GoldGrasshopper = 446
        GoldMouse = 447
        GoldWorm = 448
        BoneThrowingSkeleton = 449
        BoneThrowingSkeleton2 = 450
        BoneThrowingSkeleton3 = 451
        BoneThrowingSkeleton4 = 452
        SkeletonMerchant = 453
        CultistDragonHead = 454
        CultistDragonBody1 = 455
        CultistDragonBody2 = 456
        CultistDragonBody3 = 457
        CultistDragonBody4 = 458
        CultistDragonTail = 459
        Butcher = 460
        CreatureFromTheDeep = 461
        Fritz = 462
        Nailhead = 463
        CrimsonBunny = 464
        CrimsonGoldfish = 465
        Psycho = 466
        DeadlySphere = 467
        DrManFly = 468
        ThePossessed = 469
        CrimsonPenguin = 470
        GoblinSummoner = 471
        ShadowFlameApparition = 472
        BigMimicCorruption = 473
        BigMimicCrimson = 474
        BigMimicHallow = 475
        BigMimicJungle = 476
        Mothron = 477
        MothronEgg = 478
        MothronSpawn = 479
        Medusa = 480
        GreekSkeleton = 481
        GraniteGolem = 482
        GraniteFlyer = 483
        EnchantedNightcrawler = 484
        Grubby = 485
        Sluggy = 486
        Buggy = 487
        TargetDummy = 488
        BloodZombie = 489
        Drippler = 490
        PirateShip = 491
        PirateShipCannon = 492
        LunarTowerStardust = 493
        Crawdad = 494
        Crawdad2 = 495
        GiantShelly = 496
        GiantShelly2 = 497
        Salamander = 498
        Salamander2 = 499
        Salamander3 = 500
        Salamander4 = 501
        Salamander5 = 502
        Salamander6 = 503
        Salamander7 = 504
        Salamander8 = 505
        Salamander9 = 506
        LunarTowerNebula = 507
        GiantWalkingAntlion = 508
        GiantFlyingAntlion = 509
        DuneSplicerHead = 510
        DuneSplicerBody = 511
        DuneSplicerTail = 512
        TombCrawlerHead = 513
        TombCrawlerBody = 514
        TombCrawlerTail = 515
        SolarFlare = 516
        LunarTowerSolar = 517
        SolarSpearman = 518
        SolarGoop = 519
        MartianWalker = 520
        AncientCultistSquidhead = 521
        AncientLight = 522
        AncientDoom = 523
        DesertGhoul = 524
        DesertGhoulCorruption = 525
        DesertGhoulCrimson = 526
        DesertGhoulHallow = 527
        DesertLamiaLight = 528
        DesertLamiaDark = 529
        DesertScorpionWalk = 530
        DesertScorpionWall = 531
        DesertBeast = 532
        DesertDjinn = 533
        DemonTaxCollector = 534
        SlimeSpiked = 535
        TheBride = 536
        SandSlime = 537
        SquirrelRed = 538
        SquirrelGold = 539
        PartyBunny = 540
        SandElemental = 541
        SandShark = 542
        SandsharkCorrupt = 543
        SandsharkCrimson = 544
        SandsharkHallow = 545
        Tumbleweed = 546
        DD2AttackerTest = 547
        DD2EterniaCrystal = 548
        DD2LanePortal = 549
        DD2Bartender = 550
        DD2Betsy = 551
        DD2GoblinT1 = 552
        DD2GoblinT2 = 553
        DD2GoblinT3 = 554
        DD2GoblinBomberT1 = 555
        DD2GoblinBomberT2 = 556
        DD2GoblinBomberT3 = 557
        DD2WyvernT1 = 558
        DD2WyvernT2 = 559
        DD2WyvernT3 = 560
        DD2JavelinstT1 = 561
        DD2JavelinstT2 = 562
        DD2JavelinstT3 = 563
        DD2DarkMageT1 = 564
        DD2DarkMageT3 = 565
        DD2SkeletonT1 = 566
        DD2SkeletonT3 = 567
        DD2WitherBeastT2 = 568
        DD2WitherBeastT3 = 569
        DD2DrakinT2 = 570
        DD2DrakinT3 = 571
        DD2KoboldWalkerT2 = 572
        DD2KoboldWalkerT3 = 573
        DD2KoboldFlyerT2 = 574
        DD2KoboldFlyerT3 = 575
        DD2OgreT2 = 576
        DD2OgreT3 = 577
        DD2LightningBugT3 = 578
        BartenderUnconscious = 579
        WalkingAntlion = 580
        FlyingAntlion = 581
        LarvaeAntlion = 582
        FairyCritterPink = 583
        FairyCritterGreen = 584
        FairyCritterBlue = 585
        ZombieMerman = 586
        EyeballFlyingFish = 587
        Golfer = 588
        GolferRescue = 589
        TorchZombie = 590
        ArmedTorchZombie = 591
        GoldGoldfish = 592
        GoldGoldfishWalker = 593
        WindyBalloon = 594
        BlackDragonfly = 595
        BlueDragonfly = 596
        GreenDragonfly = 597
        OrangeDragonfly = 598
        RedDragonfly = 599
        YellowDragonfly = 600
        GoldDragonfly = 601
        Seagull = 602
        Seagull2 = 603
        LadyBug = 604
        GoldLadyBug = 605
        Maggot = 606
        Pupfish = 607
        Grebe = 608
        Grebe2 = 609
        Rat = 610
        Owl = 611
        WaterStrider = 612
        GoldWaterStrider = 613
        ExplosiveBunny = 614
        Dolphin = 615
        Turtle = 616
        TurtleJungle = 617
        BloodNautilus = 618
        BloodSquid = 619
        GoblinShark = 620
        BloodEelHead = 621
        BloodEelBody = 622
        BloodEelTail = 623
        Gnome = 624
        SeaTurtle = 625
        Seahorse = 626
        GoldSeahorse = 627
        Dandelion = 628
        IceMimic = 629
        BloodMummy = 630
        RockGolem = 631
        MaggotZombie = 632
        BestiaryGirl = 633
        SporeBat = 634
        SporeSkeleton = 635
        HallowBoss = 636
        TownCat = 637
        TownDog = 638
        GemSquirrelAmethyst = 639
        GemSquirrelTopaz = 640
        GemSquirrelSapphire = 641
        GemSquirrelEmerald = 642
        GemSquirrelRuby = 643
        GemSquirrelDiamond = 644
        GemSquirrelAmber = 645
        GemBunnyAmethyst = 646
        GemBunnyTopaz = 647
        GemBunnySapphire = 648
        GemBunnyEmerald = 649
        GemBunnyRuby = 650
        GemBunnyDiamond = 651
        GemBunnyAmber = 652
        HellButterfly = 653
        Lavafly = 654
        MagmaSnail = 655
        TownBunny = 656
        QueenSlimeBoss = 657
        QueenSlimeMinionBlue = 658
        QueenSlimeMinionPink = 659
        QueenSlimeMinionPurple = 660
        EmpressButterfly = 661
        PirateGhost = 662
        Princess = 663
        TorchGod = 664
        ChaosBallTim = 665
        VileSpitEaterOfWorlds = 666
        GoldenSlime = 667
        Deerclops = 668
        Stinkbug = 669
        TownSlimeBlue = 670
        ScarletMacaw = 671
        BlueMacaw = 672
        Toucan = 673
        YellowCockatiel = 674
        GrayCockatiel = 675
        ShimmerSlime = 676
        Shimmerfly = 677
        TownSlimeGreen = 678
        TownSlimeOld = 679
        TownSlimePurple = 680
        TownSlimeRainbow = 681
        TownSlimeRed = 682
        TownSlimeYellow = 683
        TownSlimeCopper = 684
        BoundTownSlimeOld = 685
        BoundTownSlimePurple = 686
        BoundTownSlimeYellow = 687
        Pufferfish = 688
        OwlMimic = 689
        StatueMimic = 690
        MossZombie = 691
        Orca = 692
        LibrarianSkeleton = 693
        WaterBoltMimic = 694
        PalworldCattivaDistressed = 695
        PalworldFoxsparksDistressed = 696
        Count = 697

    class NPCPortraitSelector(IntEnum):
        Poisoned = 20
        OnFire = 24
        Bleeding = 30
        Confused = 31
        CursedInferno = 39
        Frostburn = 44
        Ichor = 69
        Venom = 70
        ShadowFlame = 153
        BoneJavelin = 169
        Daybreak = 189
        BetsysCurse = 203
        Oiled = 204
        OnFire3 = 323
        Frostburn2 = 324
        TentacleSpike = 337
        BloodButcherer = 344
        Hemorrhage = 375


class NPCIDSets:
    class Main:
        factory = SetFactory(NPCID.Count)
        SpawnOnPlayerCanSpawnInMidairOnSkyblock = factory.create_bool_set(False, 4, 266, 222, 125, 126, 127, 262, 551)
        DontDropDungeonKeysOrSouls = factory.create_bool_set(False, 23)
        DontDoHardmodeScaling = factory.create_bool_set(False, 5, 13, 14, 15, 267, 113, 114, 115, 116, 117, 118, 119, 658, 659, 660, 400, 522)
        ReflectStarShotsInForTheWorthy = factory.create_bool_set(False, 4, 5, 13, 14, 15, 266, 267, 35, 36, 113, 114, 115, 116, 117, 118, 119, 125, 126, 134, 135, 136, 139, 127, 128, 131, 129, 130, 262, 263, 264, 245, 247, 248, 246, 249, 398, 400, 397, 396, 401)
        IsTownPet = factory.create_bool_set(False, 637, 638, 656, 670, 678, 679, 680, 681, 682, 683, 684)
        IsTownSlime = factory.create_bool_set(False, 670, 678, 679, 680, 681, 682, 683, 684)
        CanConvertIntoCopperSlimeTownNPC = factory.create_bool_set(False, 1, 302, 335, 336, 333, 334)
        IsGoldCritter = factory.create_bool_set(False, 442, 443, 444, 445, 446, 447, 448, 539, 592, 593, 601, 605, 613, 627)
        ZappingJellyfish = factory.create_bool_set(False, 63, 64, 103, 242)
        CantTakeLunchMoney = factory.create_bool_set(False, 394, 393, 392, 690, 492, 491, 662, 384, 478, 535, 658, 659, 660, 128, 131, 129, 130, 139, 267, 247, 248, 246, 249, 245, 409, 410, 397, 396, 401, 400, 440, 68, 534, 316)
        TrailingMode = factory.create_int_set(-1, 439, 0, 440, 0, 370, 1, 372, 1, 373, 1, 396, 1, 400, 1, 401, 1, 473, 2, 474, 2, 475, 2, 476, 2, 4, 3, 471, 3, 477, 3, 479, 3, 120, 4, 137, 4, 138, 4, 94, 5, 125, 6, 126, 6, 127, 6, 128, 6, 129, 6, 130, 6, 131, 6, 139, 6, 140, 6, 407, 6, 420, 6, 425, 6, 427, 6, 426, 6, 581, 6, 516, 6, 542, 6, 543, 6, 544, 6, 545, 6, 402, 7, 417, 7, 419, 7, 418, 7, 574, 7, 575, 7, 519, 7, 521, 7, 522, 7, 546, 7, 558, 7, 559, 7, 560, 7, 551, 7, 620, 7, 657, 6, 636, 7, 677, 7, 685, 7)
        IsDragonfly = factory.create_bool_set(False, 595, 596, 597, 598, 599, 600, 601)
        BelongsToInvasionOldOnesArmy = factory.create_bool_set(False, 552, 553, 554, 561, 562, 563, 555, 556, 557, 558, 559, 560, 576, 577, 568, 569, 566, 567, 570, 571, 572, 573, 548, 549, 564, 565, 574, 575, 551, 578)
        TeleportationImmune = factory.create_bool_set(False, 552, 553, 554, 561, 562, 563, 555, 556, 557, 558, 559, 560, 576, 577, 568, 569, 566, 567, 570, 571, 572, 573, 548, 549, 564, 565, 574, 575, 551, 578)
        UsesNewTargetting = factory.create_bool_set(False, 547, 552, 553, 554, 561, 562, 563, 555, 556, 557, 558, 559, 560, 576, 577, 568, 569, 566, 567, 570, 571, 572, 573, 564, 565, 574, 575, 551, 578, 210, 211, 620, 668)
        BirdThatCanPoop = factory.create_bool_set(False, 74, 297, 298, 442, 363, 365, 603, 609, 671, 672, 673, 674, 675)
        CritterThatCanTurnOnPlayers = factory.create_bool_set(False, 645, 639, 644, 642, 643, 641, 640, 299, 539, 538)
        TakesDamageFromHostilesWithoutBeingFriendly = factory.create_bool_set(False, 46, 55, 74, 148, 149, 230, 297, 298, 299, 303, 355, 356, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 377, 357, 374, 442, 443, 444, 445, 446, 448, 538, 539, 337, 540, 484, 485, 486, 487, 592, 593, 595, 596, 597, 598, 599, 600, 601, 602, 603, 604, 605, 606, 607, 608, 609, 611, 689, 612, 613, 614, 615, 616, 617, 625, 626, 627, 639, 640, 641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 583, 584, 585, 669, 671, 672, 673, 674, 675, 677, 687, 688)
        AllNPCs = factory.create_bool_set(True)
        HurtingBees = factory.create_bool_set(False, 210, 211)
        CanBeHurtByBees = factory.create_bool_set(True, 210, 211, 222)
        ConveyorBeltCollision = factory.create_bool_set(False, 624, 85, 629, 195, 1, 147, 184, 537, 204, 16, 59, 71, 535, 225, 676, 303, 335, 336, 333, 334, 667, 141, 81, 121, 183, 138, 244, 304, 105, 123, 685, 686, 687, 106, 354, 376, 579, 589, 37, 695, 696)
        SlimeCanContainItems = factory.create_bool_set(False, 1, 59, 147, 184, 537)
        FighterUsesDD2PortalAppearEffect = factory.create_bool_set(False, 552, 553, 554, 561, 562, 563, 555, 556, 557, 576, 577, 568, 569, 570, 571, 572, 573, 564, 565)
        NoEarlymodeLootWhenSpawnedFromStatue = factory.create_bool_set(False, 480, 82, 86, 170, 180, 171)
        NeedsExpertScaling = factory.create_bool_set(False, 25, 30, 665, 33, 112, 666, 261, 265, 371, 516, 519, 397, 396, 398, 491)
        ProjectileNPC = factory.create_bool_set(False, 25, 30, 665, 33, 112, 666, 261, 265, 371, 516, 519)
        SavesAndLoads = factory.create_bool_set(False, 422, 507, 517, 493)
        TrailCacheLength = factory.create_int_set(10, 402, 36, 519, 20, 522, 20, 620, 20, 677, 60, 685, 10)
        SearchSpawnSlotsInReverse = factory.create_bool_set(False, 222, 245)
        CannotSpawnInSlot0 = factory.create_bool_set(False, 134, 135, 136, 7, 8, 9, 10, 11, 12, 13, 14, 15, 39, 40, 41, 87, 88, 89, 90, 91, 92, 95, 96, 97, 98, 99, 100, 117, 118, 119, 375, 402, 412, 413, 414, 454, 455, 456, 457, 458, 459, 510, 511, 512, 513, 514, 515, 621, 622, 623)
        SkipUpdateInUnsyncedTiles = factory.create_bool_set(True, 135, 136, 14, 15, 8, 9, 11, 12, 40, 41, 96, 97, 99, 100, 118, 119, 622, 623, 511, 512, 514, 515, 455, 456, 457, 458, 459, 89, 90, 91, 92, 413, 414)
        UsesMultiplayerProximitySyncing = factory.create_bool_set(True, 398, 397, 396)
        NoMultiplayerSmoothingByType = factory.create_bool_set(False, 50, 657, 120, 245, 247, 248, 246, 370, 222, 398, 397, 396, 400, 401, 668, 70, 690)
        NoMultiplayerSmoothingByAI = factory.create_bool_set(False, 6, 8, 37)
        MPAllowedEnemies = factory.create_bool_set(False, 4, 13, 50, 126, 125, 134, 127, 128, 131, 129, 130, 222, 245, 266, 370, 657, 668)
        TownCritter = factory.create_bool_set(False, 46, 148, 149, 230, 299, 300, 303, 337, 361, 362, 364, 366, 367, 443, 445, 447, 538, 539, 540, 583, 584, 585, 592, 593, 602, 607, 608, 610, 616, 617, 625, 626, 627, 639, 640, 641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 687, 688)
        CountsAsCritter = factory.create_bool_set(False, 46, 303, 337, 540, 443, 74, 297, 298, 442, 611, 689, 377, 446, 612, 613, 356, 444, 595, 596, 597, 598, 599, 600, 601, 604, 605, 357, 448, 374, 484, 355, 358, 606, 359, 360, 485, 486, 487, 148, 149, 55, 230, 592, 593, 299, 538, 539, 300, 447, 361, 445, 362, 363, 364, 365, 367, 366, 583, 584, 585, 602, 603, 607, 608, 609, 610, 616, 617, 625, 626, 627, 615, 639, 640, 641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 661, 669, 671, 672, 673, 674, 675, 677, 687, 688)
        HasNoPartyText = factory.create_bool_set(False, 441, 453)
        HatOffsetY = factory.create_int_set(0, 227, 4, 107, 2, 108, 2, 229, 4, 17, 2, 38, 8, 160, -10, 208, 2, 142, 2, 124, 2, 453, 2, 37, 4, 54, 4, 209, 4, 369, 6, 441, 6, 353, -2, 633, -2, 550, -2, 588, 2, 663, 2, 637, 0, 638, 0, 656, 4, 670, 0, 678, 0, 679, 0, 680, 0, 681, 0, 682, 0, 683, 0, 684, 0)
        FaceEmote = factory.create_int_set(0, 17, 101, 18, 102, 19, 103, 20, 104, 22, 105, 37, 106, 38, 107, 54, 108, 107, 109, 108, 110, 124, 111, 142, 112, 160, 113, 178, 114, 207, 115, 208, 116, 209, 117, 227, 118, 228, 119, 229, 120, 353, 121, 368, 122, 369, 123, 453, 124, 441, 125, 588, 140, 633, 141, 663, 145)
        DangerDetectRange = factory.create_int_set(-1, 38, 300, 17, 320, 107, 300, 19, 900, 22, 700, 124, 800, 228, 800, 178, 900, 18, 300, 229, 1000, 209, 1000, 54, 700, 108, 700, 160, 700, 20, 1200, 369, 300, 453, 300, 368, 900, 207, 60, 227, 800, 208, 400, 142, 500, 441, 50, 353, 60, 633, 100, 550, 120, 588, 120, 663, 700, 638, 250, 637, 250, 656, 250, 670, 250, 678, 250, 679, 250, 680, 250, 681, 250, 682, 250, 683, 250, 684, 250)
        ShimmerImmunity = factory.create_bool_set(False, 637, 638, 656, 670, 684, 678, 679, 680, 681, 682, 683, 356, 669, 676, 244, 677, 594, 667, 662, 5, 115, 116, 139, 245, 247, 248, 246, 249, 344, 325, 50, 535, 657, 658, 659, 660, 668, 25, 30, 33, 70, 72, 665, 666, 112, 516, 517, 518, 519, 520, 521, 522, 523, 381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 420, 421, 423, 424, 425, 426, 427, 428, 429, 548, 549, 551, 552, 553, 554, 555, 556, 557, 558, 559, 560, 561, 562, 563, 564, 565, 566, 567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 577, 578)
        ShimmerTransformToItem = factory.create_int_set(-1, 651, 182, 644, 182, 650, 178, 643, 178, 649, 179, 642, 179, 648, 177, 641, 177, 640, 180, 647, 180, 646, 181, 639, 181, 652, 999, 645, 999, 448, 5341)
        ShimmerTownTransform = factory.create_bool_set(False, 22, 17, 18, 227, 207, 633, 588, 208, 369, 353, 38, 20, 550, 19, 107, 228, 54, 124, 441, 229, 160, 108, 178, 209, 142, 663, 37, 453, 368)
        ShimmerTransformToNPC = factory.create_int_set(-1, 3, 21, 132, 202, 186, 201, 187, 21, 188, 21, 189, 202, 200, 203, 590, 21, 1, 676, 302, 676, 335, 676, 336, 676, 334, 676, 333, 676, 225, 676, 141, 676, 16, 676, 147, 676, 184, 676, 537, 676, 204, 676, 81, 676, 183, 676, 138, 676, 121, 676, 591, 449, 430, 449, 436, 452, 432, 450, 433, 449, 434, 449, 435, 451, 614, 677, 74, 677, 297, 677, 298, 677, 673, 677, 672, 677, 671, 677, 675, 677, 674, 677, 362, 677, 363, 677, 364, 677, 365, 677, 608, 677, 609, 677, 602, 677, 603, 677, 611, 677, 689, 677, 148, 677, 149, 677, 46, 677, 303, 677, 337, 677, 299, 677, 538, 677, 55, 677, 607, 677, 615, 677, 625, 677, 626, 677, 688, 677, 361, 677, 687, 677, 484, 677, 604, 677, 358, 677, 355, 677, 616, 677, 617, 677, 654, 677, 653, 677, 655, 677, 585, 677, 584, 677, 583, 677, 595, 677, 596, 677, 600, 677, 597, 677, 598, 677, 599, 677, 357, 677, 377, 677, 606, 677, 359, 677, 360, 677, 367, 677, 366, 677, 300, 677, 610, 677, 612, 677, 487, 677, 486, 677, 485, 677, 669, 677, 356, 677, 661, 677, 374, 677, 442, 677, 443, 677, 444, 677, 601, 677, 445, 677, 592, 677, 446, 677, 605, 677, 447, 677, 627, 677, 539, 677, 613, 677)
        AttackTime = factory.create_int_set(-1, 38, 34, 17, 34, 107, 60, 19, 40, 22, 30, 124, 34, 228, 40, 178, 24, 18, 34, 229, 60, 209, 60, 54, 60, 108, 30, 160, 60, 20, 600, 369, 34, 453, 34, 368, 60, 207, 15, 227, 60, 208, 34, 142, 34, 441, 15, 353, 12, 633, 12, 550, 34, 588, 20, 663, 60, 638, -1, 637, -1, 656, -1, 670, -1, 678, -1, 679, -1, 680, -1, 681, -1, 682, -1, 683, -1, 684, -1)
        AttackAverageChance = factory.create_int_set(1, 38, 40, 17, 30, 107, 60, 19, 30, 22, 30, 124, 30, 228, 50, 178, 50, 18, 60, 229, 40, 209, 30, 54, 30, 108, 30, 160, 60, 20, 60, 369, 50, 453, 30, 368, 40, 207, 1, 227, 30, 208, 50, 142, 50, 441, 1, 353, 1, 633, 1, 550, 40, 588, 20, 663, 1, 638, 1, 637, 1, 656, 1, 670, 1, 678, 1, 679, 1, 680, 1, 681, 1, 682, 1, 683, 1, 684, 1)
        AttackType = factory.create_int_set(-1, 38, 0, 17, 0, 107, 0, 19, 1, 22, 1, 124, 0, 228, 1, 178, 1, 18, 0, 229, 1, 209, 1, 54, 2, 108, 2, 160, 2, 20, 2, 369, 0, 453, 0, 368, 1, 207, 3, 227, 1, 208, 0, 142, 0, 441, 3, 353, 3, 633, 0, 550, 0, 588, 0, 663, 2, 638, -1, 637, -1, 656, -1, 670, -1, 678, -1, 679, -1, 680, -1, 681, -1, 682, -1, 683, -1, 684, -1)
        PrettySafe = factory.create_int_set(-1, 19, 300, 22, 200, 124, 200, 228, 300, 178, 300, 229, 300, 209, 300, 54, 100, 108, 100, 160, 100, 20, 200, 368, 200, 227, 200)
        DemonEyes = factory.create_bool_set(False, 2, 190, 192, 193, 191, 194, 317, 318)
        Zombies = factory.create_bool_set(False, 3, 132, 186, 187, 188, 189, 200, 223, 161, 254, 255, 52, 53, 536, 319, 320, 321, 332, 436, 431, 432, 433, 434, 435, 331, 430, 590)
        Skeletons = factory.create_bool_set(False, 77, 449, 450, 451, 452, 481, 201, 202, 203, 21, 324, 110, 323, 293, 291, 322, 292, 197, 167, 44, 635)
        BossHeadTextures = factory.create_int_set(-1, 4, 0, 13, 2, 344, 3, 370, 4, 246, 5, 249, 5, 345, 6, 50, 7, 396, 8, 395, 9, 325, 10, 262, 11, 327, 13, 222, 14, 125, 15, 126, 20, 346, 17, 127, 18, 35, 19, 68, 19, 113, 22, 266, 23, 439, 24, 440, 24, 134, 25, 491, 26, 517, 27, 422, 28, 507, 29, 493, 30, 549, 35, 564, 32, 565, 32, 576, 33, 577, 33, 551, 34, 548, 36, 636, 37, 657, 38, 668, 39)
        PositiveNPCTypesExcludedFromDeathTally = factory.create_bool_set(False, 121, 384, 478, 479, 410, 472, 378)
        ShouldBeCountedAsBossForBestiary = factory.create_bool_set(False, 517, 422, 507, 493, 13, 664)
        ShouldBeCountedAsBossForRainbowBoulders = factory.create_bool_set(False, 517, 422, 507, 493, 13, 14, 15, 267, 36, 114, 664, 134, 135, 136, 128, 129, 130, 131, 245, 247, 248, 246, 491, 492, 392, 395, 394, 393, 564, 565, 576, 577, 551, 325, 327, 344, 345, 346)
        DangerThatPreventsOtherDangers = factory.create_bool_set(False, 517, 422, 507, 493, 399, 13, 14, 15)
        MustAlwaysDraw = factory.create_bool_set(False, 113, 114, 115, 116, 126, 125)
        NPCFramingGroup = factory.create_int_set(0, 18, 1, 20, 1, 208, 1, 178, 1, 124, 1, 353, 1, 633, 1, 369, 2, 160, 3, 637, 4, 638, 5, 656, 6, 670, 7, 678, 7, 679, 7, 680, 7, 681, 7, 682, 7, 683, 7, 684, 7)
        CanHitPastShimmer = factory.create_bool_set(False, 535, 5, 13, 14, 15, 666, 267, 36, 210, 211, 115, 116, 117, 118, 119, 658, 659, 660, 134, 135, 136, 139, 128, 131, 129, 130, 263, 264, 246, 249, 247, 248, 371, 372, 373, 566, 567, 440, 522, 523, 521, 454, 455, 456, 457, 458, 459, 397, 396, 400)
        TownNPCsFramingGroups = [[0, 0, 0, -2, -2, -2, 0, 0, 0, 0, -2, -2, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -2, -2, -2, 0, 0, 0, -2, -2, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -2, -2, -2, 0, 0, -2, -2, -2, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -2, 0, 0, 0, 0, -2, -2, -2, 0, 0, 0, 0, -2, -2, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 4, 6, 4, 2, 2, -2, -4, -6, -4, -2, -4, -4, -6, -6, -6, -4], [0, 0, 0, 0, 0, 0, 0, 0, -2, -2, -2, 0, 0, -2, -2, 0, 0, 4, 6, 6, 6, 6, 4, 4, 4, 4, 4, 4], [0, 0, -2, -4, -4, -2, 0, -2, 0, 0, 2, 4, 6, 4, 2, 0, -2, -4, -6, -6, -6, -6, -6, -6, -4, -2], [0, -2, 0, -2, -4, -6, -4, -2, 0, 0, 2, 2, 4, 2]]
