"""
InvasionID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class InvasionID(IntEnum):
    NoneValue = 0
    CachedFrostMoon = 1
    GoblinArmy = 1
    CachedPumpkinMoon = 2
    SnowLegion = 2
    CachedInvasions = 3
    CachedOldOnesArmy = 3
    PirateInvasion = 3
    MartianMadness = 4

