"""
GameEventClearedID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class GameEventClearedID(IntEnum):
    DefeatedGoblinArmy = 0
    DefeatedFrostArmy = 1
    DefeatedPirates = 2
    DefeatedMartians = 3
    DefeatedHalloweenTree = 4
    DefeatedHalloweenKing = 5
    DefeatedGolem = 6
    DefeatedFishron = 7
    DefeatedQueenBee = 8
    DefeatedAncientCultist = 9
    DefeatedMoonlord = 10
    DefeatedSlimeKing = 11
    DefeatedPlantera = 12
    DefeatedEyeOfCthulu = 13
    DefeatedEaterOfWorldsOrBrainOfChtulu = 14
    DefeatedSkeletron = 15
    DefeatedDestroyer = 16
    DefeatedTheTwins = 17
    DefeatedSkeletronPrime = 18
    DefeatedWallOfFleshAndStartedHardmode = 19
    DefeatedIceQueen = 20
    DefeatedChristmassTree = 21
    DefeatedSantank = 22
    DefeatedEmpressOfLight = 23
    DefeatedQueenSlime = 24
    DefeatedDeerclops = 25

