from enum import IntEnum


class TeleportType(IntEnum):
    TeleporterTile = 0
    RodOfDiscord = 1
    TeleportationPotion = 2
    RecallPotion = 3
    Portal = 4
    MagicConch = 5
    DebugTeleport = 6
    DemonConch = 7
    PotionOfReturn = 8
    TeleportationPylon = 9
    QueenSlimeHook = 10
    ShellphoneSpawn = 11
    ShimmerTownNPCTransform = 12
    MysticFrog = 13
    NoEffect = 14
