from terrex.packet.base import Packet
from terrex.id import MessageID


class TShockPlaceholder(Packet):
    # Placeholder for TShock
    id = MessageID.TShockPlaceholder

    def read(self, reader):
        pass

    def write(self, writer):
        pass
