"""
ProjectileID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from terrex.id.set_factory import SetFactory
from enum import IntEnum, auto


class ProjectileID(IntEnum):
    NoneValue = 0
    WoodenArrowFriendly = 1
    FireArrow = 2
    Shuriken = 3
    UnholyArrow = 4
    JestersArrow = 5
    EnchantedBoomerang = 6
    VilethornBase = 7
    VilethornTip = 8
    Starfury = 9
    PurificationPowder = 10
    VilePowder = 11
    FallingStar = 12
    Hook = 13
    Bullet = 14
    BallofFire = 15
    MagicMissile = 16
    DirtBall = 17
    ShadowOrb = 18
    Flamarang = 19
    GreenLaser = 20
    Bone = 21
    WaterStream = 22
    Harpoon = 23
    SpikyBall = 24
    BallOHurt = 25
    BlueMoon = 26
    WaterBolt = 27
    Bomb = 28
    Dynamite = 29
    Grenade = 30
    SandBallFalling = 31
    IvyWhip = 32
    ThornChakram = 33
    Flamelash = 34
    Sunfury = 35
    MeteorShot = 36
    StickyBomb = 37
    HarpyFeather = 38
    MudBall = 39
    AshBallFalling = 40
    HellfireArrow = 41
    SandBallGun = 42
    Tombstone = 43
    DemonSickle = 44
    DemonScythe = 45
    DarkLance = 46
    Trident = 47
    ThrowingKnife = 48
    Spear = 49
    Glowstick = 50
    Seed = 51
    WoodenBoomerang = 52
    StickyGlowstick = 53
    PoisonedKnife = 54
    Stinger = 55
    EbonsandBallFalling = 56
    CobaltChainsaw = 57
    MythrilChainsaw = 58
    CobaltDrill = 59
    MythrilDrill = 60
    AdamantiteChainsaw = 61
    AdamantiteDrill = 62
    TheDaoofPow = 63
    MythrilHalberd = 64
    EbonsandBallGun = 65
    AdamantiteGlaive = 66
    PearlSandBallFalling = 67
    PearlSandBallGun = 68
    HolyWater = 69
    UnholyWater = 70
    SiltBall = 71
    BlueFairy = 72
    DualHookBlue = 73
    DualHookRed = 74
    HappyBomb = 75
    QuarterNote = 76
    EighthNote = 77
    TiedEighthNote = 78
    RainbowRodBullet = 79
    IceBlock = 80
    WoodenArrowHostile = 81
    FlamingArrow = 82
    EyeLaser = 83
    PinkLaser = 84
    Flames = 85
    PinkFairy = 86
    GreenFairy = 87
    PurpleLaser = 88
    CrystalBullet = 89
    CrystalShard = 90
    HolyArrow = 91
    HallowStar = 92
    MagicDagger = 93
    CrystalStorm = 94
    CursedFlameFriendly = 95
    CursedFlameHostile = 96
    CobaltNaginata = 97
    PoisonDart = 98
    Boulder = 99
    DeathLaser = 100
    EyeFire = 101
    BombSkeletronPrime = 102
    CursedArrow = 103
    CursedBullet = 104
    Gungnir = 105
    LightDisc = 106
    Hamdrax = 107
    Explosives = 108
    SnowBallHostile = 109
    BulletSnowman = 110
    Bunny = 111
    Penguin = 112
    IceBoomerang = 113
    UnholyTridentFriendly = 114
    UnholyTridentHostile = 115
    SwordBeam = 116
    BoneArrow = 117
    IceBolt = 118
    FrostBoltSword = 119
    FrostArrow = 120
    AmethystBolt = 121
    TopazBolt = 122
    SapphireBolt = 123
    EmeraldBolt = 124
    RubyBolt = 125
    DiamondBolt = 126
    Turtle = 127
    FrostBlastHostile = 128
    RuneBlast = 129
    MushroomSpear = 130
    Mushroom = 131
    TerraBeam = 132
    GrenadeI = 133
    RocketI = 134
    ProximityMineI = 135
    GrenadeII = 136
    RocketII = 137
    ProximityMineII = 138
    GrenadeIII = 139
    RocketIII = 140
    ProximityMineIII = 141
    GrenadeIV = 142
    RocketIV = 143
    ProximityMineIV = 144
    PureSpray = 145
    HallowSpray = 146
    CorruptSpray = 147
    MushroomSpray = 148
    CrimsonSpray = 149
    NettleBurstRight = 150
    NettleBurstLeft = 151
    NettleBurstEnd = 152
    TheRottedFork = 153
    TheMeatball = 154
    BeachBall = 155
    LightBeam = 156
    NightBeam = 157
    CopperCoin = 158
    SilverCoin = 159
    GoldCoin = 160
    PlatinumCoin = 161
    CannonballFriendly = 162
    Flare = 163
    Landmine = 164
    WebSlingerHook = 165
    SnowBallFriendly = 166
    RocketFireworkRed = 167
    RocketFireworkGreen = 168
    RocketFireworkBlue = 169
    RocketFireworkYellow = 170
    RopeCoil = 171
    FrostburnArrow = 172
    EnchantedBeam = 173
    IceSpike = 174
    BabyEater = 175
    JungleSpike = 176
    IcewaterSpit = 177
    ConfettiGun = 178
    SlushBall = 179
    BulletDeadeye = 180
    Bee = 181
    PossessedHatchet = 182
    Beenade = 183
    PoisonDartTrap = 184
    SpikyBallTrap = 185
    SpearTrap = 186
    FlamethrowerTrap = 187
    FlamesTrap = 188
    Wasp = 189
    MechanicalPiranha = 190
    Pygmy = 191
    Pygmy2 = 192
    Pygmy3 = 193
    Pygmy4 = 194
    PygmySpear = 195
    SmokeBomb = 196
    BabySkeletronHead = 197
    BabyHornet = 198
    TikiSpirit = 199
    PetLizard = 200
    GraveMarker = 201
    CrossGraveMarker = 202
    Headstone = 203
    Gravestone = 204
    Obelisk = 205
    Leaf = 206
    ChlorophyteBullet = 207
    Parrot = 208
    Truffle = 209
    Sapling = 210
    Wisp = 211
    PalladiumPike = 212
    PalladiumDrill = 213
    PalladiumChainsaw = 214
    OrichalcumHalberd = 215
    OrichalcumDrill = 216
    OrichalcumChainsaw = 217
    TitaniumTrident = 218
    TitaniumDrill = 219
    TitaniumChainsaw = 220
    FlowerPetal = 221
    ChlorophytePartisan = 222
    ChlorophyteDrill = 223
    ChlorophyteChainsaw = 224
    ChlorophyteArrow = 225
    CrystalLeaf = 226
    CrystalLeafShot = 227
    SporeCloud = 228
    ChlorophyteOrb = 229
    GemHookAmethyst = 230
    GemHookTopaz = 231
    GemHookSapphire = 232
    GemHookEmerald = 233
    GemHookRuby = 234
    GemHookDiamond = 235
    BabyDino = 236
    RainCloudMoving = 237
    RainCloudRaining = 238
    RainFriendly = 239
    CannonballHostile = 240
    CrimsandBallFalling = 241
    BulletHighVelocity = 242
    BloodCloudMoving = 243
    BloodCloudRaining = 244
    BloodRain = 245
    Stynger = 246
    FlowerPow = 247
    FlowerPowPetal = 248
    StyngerShrapnel = 249
    RainbowFront = 250
    RainbowBack = 251
    ChlorophyteJackhammer = 252
    BallofFrost = 253
    MagnetSphereBall = 254
    MagnetSphereBolt = 255
    SkeletronHand = 256
    FrostBeam = 257
    Fireball = 258
    EyeBeam = 259
    HeatRay = 260
    BoulderStaffOfEarth = 261
    GolemFist = 262
    IceSickle = 263
    RainNimbus = 264
    PoisonFang = 265
    BabySlime = 266
    PoisonDartBlowgun = 267
    EyeSpring = 268
    BabySnowman = 269
    Skull = 270
    BoxingGlove = 271
    Bananarang = 272
    ChainKnife = 273
    DeathSickle = 274
    SeedPlantera = 275
    PoisonSeedPlantera = 276
    ThornBall = 277
    IchorArrow = 278
    IchorBullet = 279
    GoldenShowerFriendly = 280
    ExplosiveBunny = 281
    VenomArrow = 282
    VenomBullet = 283
    PartyBullet = 284
    NanoBullet = 285
    ExplosiveBullet = 286
    GoldenBullet = 287
    GoldenShowerHostile = 288
    ConfettiMelee = 289
    ShadowBeamHostile = 290
    InfernoHostileBolt = 291
    InfernoHostileBlast = 292
    LostSoulHostile = 293
    ShadowBeamFriendly = 294
    InfernoFriendlyBolt = 295
    InfernoFriendlyBlast = 296
    LostSoulFriendly = 297
    SpiritHeal = 298
    Shadowflames = 299
    PaladinsHammerHostile = 300
    PaladinsHammerFriendly = 301
    SniperBullet = 302
    RocketSkeleton = 303
    VampireKnife = 304
    VampireHeal = 305
    EatersBite = 306
    TinyEater = 307
    FrostHydra = 308
    FrostBlastFriendly = 309
    BlueFlare = 310
    CandyCorn = 311
    JackOLantern = 312
    Spider = 313
    Squashling = 314
    BatHook = 315
    Bat = 316
    Raven = 317
    RottenEgg = 318
    BlackCat = 319
    BloodyMachete = 320
    FlamingJack = 321
    WoodHook = 322
    Stake = 323
    CursedSapling = 324
    FlamingWood = 325
    GreekFire1 = 326
    GreekFire2 = 327
    GreekFire3 = 328
    FlamingScythe = 329
    StarAnise = 330
    CandyCaneHook = 331
    ChristmasHook = 332
    FruitcakeChakram = 333
    Puppy = 334
    OrnamentFriendly = 335
    PineNeedleFriendly = 336
    Blizzard = 337
    RocketSnowmanI = 338
    RocketSnowmanII = 339
    RocketSnowmanIII = 340
    RocketSnowmanIV = 341
    NorthPoleWeapon = 342
    NorthPoleSpear = 343
    NorthPoleSnowflake = 344
    PineNeedleHostile = 345
    OrnamentHostile = 346
    OrnamentHostileShrapnel = 347
    FrostWave = 348
    FrostShard = 349
    Missile = 350
    Present = 351
    Spike = 352
    BabyGrinch = 353
    CrimsandBallGun = 354
    VenomFang = 355
    SpectreWrath = 356
    PulseBolt = 357
    WaterGun = 358
    FrostBoltStaff = 359
    BobberWooden = 360
    BobberReinforced = 361
    BobberFiberglass = 362
    BobberFisherOfSouls = 363
    BobberGolden = 364
    BobberMechanics = 365
    BobbersittingDuck = 366
    ObsidianSwordfish = 367
    Swordfish = 368
    SawtoothShark = 369
    LovePotion = 370
    FoulPotion = 371
    FishHook = 372
    Hornet = 373
    HornetStinger = 374
    FlyingImp = 375
    ImpFireball = 376
    SpiderHiver = 377
    SpiderEgg = 378
    BabySpider = 379
    ZephyrFish = 380
    BobberFleshcatcher = 381
    BobberHotline = 382
    Anchor = 383
    Sharknado = 384
    SharknadoBolt = 385
    Cthulunado = 386
    Retanimini = 387
    Spazmamini = 388
    MiniRetinaLaser = 389
    VenomSpider = 390
    JumperSpider = 391
    DangerousSpider = 392
    OneEyedPirate = 393
    SoulscourgePirate = 394
    PirateCaptain = 395
    SlimeHook = 396
    StickyGrenade = 397
    MiniMinotaur = 398
    MolotovCocktail = 399
    MolotovFire = 400
    MolotovFire2 = 401
    MolotovFire3 = 402
    TrackHook = 403
    Flairon = 404
    FlaironBubble = 405
    SlimeGun = 406
    Tempest = 407
    MiniSharkron = 408
    Typhoon = 409
    Bubble = 410
    CopperCoinsFalling = 411
    SilverCoinsFalling = 412
    GoldCoinsFalling = 413
    PlatinumCoinsFalling = 414
    RocketFireworksBoxRed = 415
    RocketFireworksBoxGreen = 416
    RocketFireworksBoxBlue = 417
    RocketFireworksBoxYellow = 418
    FireworkFountainYellow = 419
    FireworkFountainRed = 420
    FireworkFountainBlue = 421
    FireworkFountainRainbow = 422
    UFOMinion = 423
    Meteor1 = 424
    Meteor2 = 425
    Meteor3 = 426
    VortexChainsaw = 427
    VortexDrill = 428
    NebulaChainsaw = 429
    NebulaDrill = 430
    SolarFlareChainsaw = 431
    SolarFlareDrill = 432
    UFOLaser = 433
    ScutlixLaserFriendly = 434
    MartianTurretBolt = 435
    BrainScramblerBolt = 436
    GigaZapperSpear = 437
    RayGunnerLaser = 438
    LaserMachinegun = 439
    LaserMachinegunLaser = 440
    ScutlixLaserCrosshair = 441
    ElectrosphereMissile = 442
    Electrosphere = 443
    Xenopopper = 444
    LaserDrill = 445
    AntiGravityHook = 446
    SaucerDeathray = 447
    SaucerMissile = 448
    SaucerLaser = 449
    SaucerScrap = 450
    InfluxWaver = 451
    PhantasmalEye = 452
    DrillMountCrosshair = 453
    PhantasmalSphere = 454
    PhantasmalDeathray = 455
    MoonLeech = 456
    PhasicWarpEjector = 457
    PhasicWarpDisc = 458
    ChargedBlasterOrb = 459
    ChargedBlasterCannon = 460
    ChargedBlasterLaser = 461
    PhantasmalBolt = 462
    ViciousPowder = 463
    CultistBossIceMist = 464
    CultistBossLightningOrb = 465
    CultistBossLightningOrbArc = 466
    CultistBossFireBall = 467
    CultistBossFireBallClone = 468
    BeeArrow = 469
    StickyDynamite = 470
    SkeletonBone = 471
    WebSpit = 472
    SpelunkerGlowstick = 473
    BoneArrowFromMerchant = 474
    VineRopeCoil = 475
    SoulDrain = 476
    CrystalDart = 477
    CursedDart = 478
    IchorDart = 479
    CursedDartFlame = 480
    ChainGuillotine = 481
    ClingerStaff = 482
    SeedlerNut = 483
    SeedlerThorn = 484
    Hellwing = 485
    TendonHook = 486
    ThornHook = 487
    IlluminantHook = 488
    WormHook = 489
    CultistRitual = 490
    FlyingKnife = 491
    MagicLantern = 492
    CrystalVileShardHead = 493
    CrystalVileShardShaft = 494
    ShadowFlameArrow = 495
    ShadowFlame = 496
    ShadowFlameKnife = 497
    Nail = 498
    BabyFaceMonster = 499
    CrimsonHeart = 500
    DrManFlyFlask = 501
    Meowmere = 502
    StarWrath = 503
    Spark = 504
    SilkRopeCoil = 505
    WebRopeCoil = 506
    JavelinFriendly = 507
    JavelinHostile = 508
    ButchersChainsaw = 509
    ToxicFlask = 510
    ToxicCloud = 511
    ToxicCloud2 = 512
    ToxicCloud3 = 513
    NailFriendly = 514
    BouncyGlowstick = 515
    BouncyBomb = 516
    BouncyGrenade = 517
    CoinPortal = 518
    BombFish = 519
    FrostDaggerfish = 520
    CrystalPulse = 521
    CrystalPulse2 = 522
    ToxicBubble = 523
    IchorSplash = 524
    FlyingPiggyBank = 525
    CultistBossParticle = 526
    RichGravestone1 = 527
    RichGravestone2 = 528
    RichGravestone3 = 529
    RichGravestone4 = 530
    RichGravestone5 = 531
    BoneGloveProj = 532
    DeadlySphere = 533
    Code1 = 534
    MedusaHead = 535
    MedusaHeadRay = 536
    StardustSoldierLaser = 537
    Twinkle = 538
    StardustJellyfishSmall = 539
    StardustTowerMark = 540
    WoodYoyo = 541
    CorruptYoyo = 542
    CrimsonYoyo = 543
    JungleYoyo = 544
    Cascade = 545
    Chik = 546
    Code2 = 547
    Rally = 548
    Yelets = 549
    RedsYoyo = 550
    ValkyrieYoyo = 551
    Amarok = 552
    HelFire = 553
    Kraken = 554
    TheEyeOfCthulhu = 555
    BlackCounterweight = 556
    BlueCounterweight = 557
    GreenCounterweight = 558
    PurpleCounterweight = 559
    RedCounterweight = 560
    YellowCounterweight = 561
    FormatC = 562
    Gradient = 563
    Valor = 564
    BrainOfConfusion = 565
    GiantBee = 566
    SporeTrap = 567
    SporeTrap2 = 568
    SporeGas = 569
    SporeGas2 = 570
    SporeGas3 = 571
    SalamanderSpit = 572
    NebulaBolt = 573
    NebulaEye = 574
    NebulaSphere = 575
    NebulaLaser = 576
    VortexLaser = 577
    VortexVortexLightning = 578
    VortexVortexPortal = 579
    VortexLightning = 580
    VortexAcid = 581
    MechanicWrench = 582
    NurseSyringeHurt = 583
    NurseSyringeHeal = 584
    ClothiersCurse = 585
    DryadsWardCircle = 586
    PainterPaintball = 587
    PartyGirlGrenade = 588
    SantaBombs = 589
    TruffleSpore = 590
    MinecartMechLaser = 591
    MartianWalkerLaser = 592
    AncientDoomProjectile = 593
    BlowupSmoke = 594
    Arkhalis = 595
    DesertDjinnCurse = 596
    AmberBolt = 597
    BoneJavelin = 598
    BoneDagger = 599
    PortalGun = 600
    PortalGunBolt = 601
    PortalGunGate = 602
    Terrarian = 603
    TerrarianBeam = 604
    SpikedSlimeSpike = 605
    ScutlixLaser = 606
    SolarFlareRay = 607
    SolarCounter = 608
    StardustDrill = 609
    StardustChainsaw = 610
    SolarWhipSword = 611
    SolarWhipSwordExplosion = 612
    StardustCellMinion = 613
    StardustCellMinionShot = 614
    VortexBeater = 615
    VortexBeaterRocket = 616
    NebulaArcanum = 617
    NebulaArcanumSubshot = 618
    NebulaArcanumExplosionShot = 619
    NebulaArcanumExplosionShotShard = 620
    BloodWater = 621
    BlowupSmokeMoonlord = 622
    StardustGuardian = 623
    StardustGuardianExplosion = 624
    StardustDragon1 = 625
    StardustDragon2 = 626
    StardustDragon3 = 627
    StardustDragon4 = 628
    TowerDamageBolt = 629
    Phantasm = 630
    PhantasmArrow = 631
    LastPrismLaser = 632
    LastPrism = 633
    NebulaBlaze1 = 634
    NebulaBlaze2 = 635
    Daybreak = 636
    BouncyDynamite = 637
    MoonlordBullet = 638
    MoonlordArrow = 639
    MoonlordArrowTrail = 640
    MoonlordTurret = 641
    MoonlordTurretLaser = 642
    RainbowCrystal = 643
    RainbowCrystalExplosion = 644
    LunarFlare = 645
    LunarHookSolar = 646
    LunarHookVortex = 647
    LunarHookNebula = 648
    LunarHookStardust = 649
    SuspiciousTentacle = 650
    WireKite = 651
    StaticHook = 652
    CompanionCube = 653
    GeyserTrap = 654
    BeeHive = 655
    SandnadoFriendly = 656
    SandnadoHostile = 657
    SandnadoHostileMark = 658
    SpiritFlame = 659
    SkyFracture = 660
    BlackBolt = 661
    DD2JavelinHostile = 662
    DD2FlameBurstTowerT1 = 663
    DD2FlameBurstTowerT1Shot = 664
    DD2FlameBurstTowerT2 = 665
    DD2FlameBurstTowerT2Shot = 666
    DD2FlameBurstTowerT3 = 667
    DD2FlameBurstTowerT3Shot = 668
    Ale = 669
    DD2OgreStomp = 670
    DD2DrakinShot = 671
    DD2ElderWins = 672
    DD2DarkMageRaise = 673
    DD2DarkMageHeal = 674
    DD2DarkMageBolt = 675
    DD2OgreSpit = 676
    DD2BallistraTowerT1 = 677
    DD2BallistraTowerT2 = 678
    DD2BallistraTowerT3 = 679
    DD2BallistraProj = 680
    DD2GoblinBomb = 681
    DD2LightningBugZap = 682
    DD2OgreSmash = 683
    DD2SquireSonicBoom = 684
    DD2JavelinHostileT3 = 685
    DD2BetsyFireball = 686
    DD2BetsyFlameBreath = 687
    DD2LightningAuraT1 = 688
    DD2LightningAuraT2 = 689
    DD2LightningAuraT3 = 690
    DD2ExplosiveTrapT1 = 691
    DD2ExplosiveTrapT2 = 692
    DD2ExplosiveTrapT3 = 693
    DD2ExplosiveTrapT1Explosion = 694
    DD2ExplosiveTrapT2Explosion = 695
    DD2ExplosiveTrapT3Explosion = 696
    MonkStaffT1 = 697
    MonkStaffT1Explosion = 698
    MonkStaffT2 = 699
    MonkStaffT2Ghast = 700
    DD2PetDragon = 701
    DD2PetGhost = 702
    DD2PetGato = 703
    DD2ApprenticeStorm = 704
    DD2PhoenixBow = 705
    DD2PhoenixBowShot = 706
    MonkStaffT3 = 707
    MonkStaffT3_Alt = 708
    MonkStaffT3_AltShot = 709
    DD2BetsyArrow = 710
    ApprenticeStaffT3Shot = 711
    BookStaffShot = 712
    DD2Win = 713
    Celeb2Weapon = 714
    Celeb2Rocket = 715
    Celeb2RocketExplosive = 716
    Celeb2RocketLarge = 717
    Celeb2RocketExplosiveLarge = 718
    QueenBeeStinger = 719
    FallingStarSpawner = 720
    DirtGolfBall = 721
    GolfClubHelper = 722
    ManaCloakStar = 723
    BeeCloakStar = 724
    StarVeilStar = 725
    StarCloakStar = 726
    RollingCactus = 727
    SuperStar = 728
    SuperStarSlash = 729
    ThunderSpear = 730
    ThunderStaffShot = 731
    ThunderSpearShot = 732
    ToiletEffect = 733
    VoidLens = 734
    Terragrim = 735
    BlueDungeonDebris = 736
    GreenDungeonDebris = 737
    PinkDungeonDebris = 738
    GolfBallDyedBlack = 739
    GolfBallDyedBlue = 740
    GolfBallDyedBrown = 741
    GolfBallDyedCyan = 742
    GolfBallDyedGreen = 743
    GolfBallDyedLimeGreen = 744
    GolfBallDyedOrange = 745
    GolfBallDyedPink = 746
    GolfBallDyedPurple = 747
    GolfBallDyedRed = 748
    GolfBallDyedSkyBlue = 749
    GolfBallDyedTeal = 750
    GolfBallDyedViolet = 751
    GolfBallDyedYellow = 752
    AmberHook = 753
    MysticSnakeCoil = 754
    BatOfLight = 755
    SharpTears = 756
    DripplerFlail = 757
    VampireFrog = 758
    BabyBird = 759
    BobberBloody = 760
    PaperAirplaneA = 761
    PaperAirplaneB = 762
    RollingCactusSpike = 763
    UpbeatStar = 764
    SugarGlider = 765
    KiteBlue = 766
    KiteBlueAndYellow = 767
    KiteRed = 768
    KiteRedAndYellow = 769
    KiteYellow = 770
    KiteWyvern = 771
    Geode = 772
    ScarabBomb = 773
    SharkPup = 774
    BobberScarab = 775
    ClusterRocketI = 776
    ClusterGrenadeI = 777
    ClusterMineI = 778
    ClusterFragmentsI = 779
    ClusterRocketII = 780
    ClusterGrenadeII = 781
    ClusterMineII = 782
    ClusterFragmentsII = 783
    WetRocket = 784
    WetGrenade = 785
    WetMine = 786
    LavaRocket = 787
    LavaGrenade = 788
    LavaMine = 789
    HoneyRocket = 790
    HoneyGrenade = 791
    HoneyMine = 792
    MiniNukeRocketI = 793
    MiniNukeGrenadeI = 794
    MiniNukeMineI = 795
    MiniNukeRocketII = 796
    MiniNukeGrenadeII = 797
    MiniNukeMineII = 798
    DryRocket = 799
    DryGrenade = 800
    DryMine = 801
    GladiusStab = 802
    ClusterSnowmanRocketI = 803
    ClusterSnowmanRocketII = 804
    WetSnowmanRocket = 805
    LavaSnowmanRocket = 806
    HoneySnowmanRocket = 807
    MiniNukeSnowmanRocketI = 808
    MiniNukeSnowmanRocketII = 809
    DrySnowmanRocket = 810
    BloodShot = 811
    ShellPileFalling = 812
    BloodNautilusTears = 813
    BloodNautilusShot = 814
    LilHarpy = 815
    FennecFox = 816
    GlitteryButterfly = 817
    WhiteTigerPounce = 818
    BloodArrow = 819
    ChumBucket = 820
    BabyImp = 821
    KiteBoneSerpent = 822
    KiteWorldFeeder = 823
    KiteBunny = 824
    BabyRedPanda = 825
    KitePigron = 826
    KiteManEater = 827
    KiteJellyfishBlue = 828
    KiteJellyfishPink = 829
    KiteShark = 830
    StormTigerGem = 831
    StormTigerAttack = 832
    StormTigerTier1 = 833
    StormTigerTier2 = 834
    StormTigerTier3 = 835
    DandelionSeed = 836
    BookOfSkullsSkull = 837
    KiteSandShark = 838
    KiteBunnyCorrupt = 839
    KiteBunnyCrimson = 840
    BlandWhip = 841
    RulerStab = 842
    KiteGoldfish = 843
    KiteAngryTrapper = 844
    KiteKoi = 845
    KiteCrawltipede = 846
    SwordWhip = 847
    MaceWhip = 848
    ScytheWhip = 849
    KiteSpectrum = 850
    ReleaseDoves = 851
    KiteWanderingEye = 852
    KiteUnicorn = 853
    Plantero = 854
    ReleaseLantern = 855
    SparkleGuitar = 856
    FirstFractal = 857
    DynamiteKitten = 858
    BabyWerewolf = 859
    ShadowMimic = 860
    Football = 861
    ClusterSnowmanFragmentsI = 862
    ClusterSnowmanFragmentsII = 863
    Smolstar = 864
    SquirrelHook = 865
    BouncingShield = 866
    Shroomerang = 867
    TreeGlobe = 868
    WorldGlobe = 869
    FairyGlowstick = 870
    HallowBossSplitShotCore = 871
    HallowBossLastingRainbow = 872
    HallowBossRainbowStreak = 873
    HallowBossDeathAurora = 874
    VoltBunny = 875
    ZapinatorLaser = 876
    JoustingLance = 877
    ShadowJoustingLance = 878
    HallowJoustingLance = 879
    ZoologistStrikeGreen = 880
    KingSlimePet = 881
    EyeOfCthulhuPet = 882
    EaterOfWorldsPet = 883
    BrainOfCthulhuPet = 884
    SkeletronPet = 885
    QueenBeePet = 886
    DestroyerPet = 887
    TwinsPet = 888
    SkeletronPrimePet = 889
    PlanteraPet = 890
    GolemPet = 891
    DukeFishronPet = 892
    LunaticCultistPet = 893
    MoonLordPet = 894
    FairyQueenPet = 895
    PumpkingPet = 896
    EverscreamPet = 897
    IceQueenPet = 898
    MartianPet = 899
    DD2OgrePet = 900
    DD2BetsyPet = 901
    CombatWrench = 902
    WetBomb = 903
    LavaBomb = 904
    HoneyBomb = 905
    DryBomb = 906
    OrnamentStar = 907
    TitaniumStormShard = 908
    RockGolemRock = 909
    DirtBomb = 910
    DirtStickyBomb = 911
    CoolWhip = 912
    FireWhip = 913
    ThornWhip = 914
    RainbowWhip = 915
    ScytheWhipProj = 916
    CoolWhipProj = 917
    FireWhipProj = 918
    FairyQueenLance = 919
    QueenSlimeMinionBlueSpike = 920
    QueenSlimeMinionPinkBall = 921
    QueenSlimeSmash = 922
    FairyQueenSunDance = 923
    FairyQueenHymn = 924
    StardustPunch = 925
    QueenSlimeGelAttack = 926
    PiercingStarlight = 927
    DripplerFlailExtraBall = 928
    ZoologistStrikeRed = 929
    SantankMountRocket = 930
    FairyQueenMagicItemShot = 931
    FairyQueenRangedItemShot = 932
    FinalFractal = 933
    QueenSlimePet = 934
    QueenSlimeHook = 935
    GelBalloon = 936
    VolatileGelatinBall = 937
    CopperShortswordStab = 938
    TinShortswordStab = 939
    IronShortswordStab = 940
    LeadShortswordStab = 941
    SilverShortswordStab = 942
    TungstenShortswordStab = 943
    GoldShortswordStab = 944
    PlatinumShortswordStab = 945
    EmpressBlade = 946
    Mace = 947
    FlamingMace = 948
    TorchGod = 949
    PrincessWeapon = 950
    FlinxMinion = 951
    BoneWhip = 952
    DaybreakExplosion = 953
    WandOfSparkingSpark = 954
    StarCannonStar = 955
    BerniePet = 956
    GlommerPet = 957
    DeerclopsPet = 958
    PigPet = 959
    ChesterPet = 960
    DeerclopsIceSpike = 961
    DeerclopsRangedProjectile = 962
    AbigailMinion = 963
    InsanityShadowFriendly = 964
    InsanityShadowHostile = 965
    HoundiusShootius = 966
    HoundiusShootiusFireball = 967
    PewMaticHornShot = 968
    WeatherPainShot = 969
    AbigailCounter = 970
    TentacleSpike = 971
    NightsEdge = 972
    TrueNightsEdge = 973
    LightsBane = 974
    BloodButcherer = 975
    BladeOfGrass = 976
    Muramasa = 977
    Volcano = 978
    WandOfFrostingFrost = 979
    VenomDartTrap = 980
    SilverBullet = 981
    Excalibur = 982
    TrueExcalibur = 983
    TerraBlade2 = 984
    TerraBlade2Shot = 985
    FishingBobber = 986
    FishingBobberGlowingStar = 987
    FishingBobberGlowingLava = 988
    FishingBobberGlowingKrypton = 989
    FishingBobberGlowingXenon = 990
    FishingBobberGlowingArgon = 991
    FishingBobberGlowingViolet = 992
    FishingBobberGlowingRainbow = 993
    JunimoPet = 994
    JuminoStardropAnimation = 995
    MoonGlobe = 996
    TheHorsemansBlade = 997
    BlueChickenPet = 998
    HiveFive = 999
    Trimarang = 1000
    HorsemanPumpkin = 1001
    TNTBarrel = 1002
    Spiffo = 1003
    CavelingGardener = 1004
    MiniBoulder = 1005
    ShimmerArrow = 1006
    GasTrap = 1007
    SpelunkerFlare = 1008
    CursedFlare = 1009
    RainbowFlare = 1010
    ShimmerFlare = 1011
    Waffle = 1012
    BouncyBoulder = 1013
    LifeCrystalBoulder = 1014
    SandSpray = 1015
    SnowSpray = 1016
    DirtSpray = 1017
    DirtiestBlock = 1018
    Fertilizer = 1019
    JimsDrone = 1020
    MoonBoulder = 1021
    DeadCellsMushroomBoiMinion = 1022
    DeadCellsBarrel = 1023
    DeadCellsKillingDeckCard = 1024
    DeadCellsBarnacle = 1025
    DeadCellsBarnacleShot = 1026
    DeadCellsSwarmBiter = 1027
    CobWhip = 1028
    CorruptWhip = 1029
    CrimsonWhip = 1030
    MeteorWhip = 1031
    FlowerWhip = 1032
    EelWhip = 1033
    ConstellationWhip = 1034
    MoonLordWhip = 1035
    CobWhipSpider = 1036
    MeteorWhipMeteor = 1037
    FlowerWhipPetal = 1038
    ConstellationStar = 1039
    DeadCellsFlint = 1040
    DeadCellsFlintShot = 1041
    ShimmerGunStream = 1042
    DeadCellsFlintSlash = 1043
    DeadCellsMushroomBoiMinionExplosion = 1044
    MoonLordWhipProc = 1045
    Pufferfish = 1046
    RainbowBoulder = 1047
    Poulder = 1048
    MeteorStormMeteor = 1049
    AxeFairyPet = 1050
    SuperFertilizer = 1051
    Axearang = 1052
    LavaBoulder = 1053
    SpiderBoulder = 1054
    Ghoulder = 1055
    BoulderPet = 1056
    BoulderThatSpawnsPet = 1057
    FlaironFlail = 1058
    BluePhaseblade = 1059
    RedPhaseblade = 1060
    GreenPhaseblade = 1061
    PurplePhaseblade = 1062
    WhitePhaseblade = 1063
    YellowPhaseblade = 1064
    BluePhasesaber = 1065
    RedPhasesaber = 1066
    GreenPhasesaber = 1067
    PurplePhasesaber = 1068
    WhitePhasesaber = 1069
    YellowPhasesaber = 1070
    OrangePhaseblade = 1071
    OrangePhasesaber = 1072
    PoisonDartShotFromSlimes = 1073
    Keybrand = 1074
    PinkPhaseblade = 1075
    PinkPhasesaber = 1076
    FreezeBomb = 1077
    MeteorOre = 1078
    PinkCounterweight = 1079
    BirdDroppings = 1080
    MudBallPlayer = 1081
    AntlionClaw = 1082
    StylistKilLaKillScissorsIWish = 1083
    TorchGodHelper = 1084
    PrettyMirror = 1085
    SuperBomb = 1086
    SuperStickyBomb = 1087
    AcornSlingshotAcorn = 1088
    RainbowGlowstick = 1089
    RainbowBoulderPet = 1090
    StormLightning = 1091
    LibrarianSkeletonBook = 1092
    PalworldMinionCattiva = 1093
    PalworldMinionFoxsparks = 1094
    PalworldPetChillet = 1095
    PalworldPetChilletIgnis = 1096
    PalworldMinionFoxsparksFireball = 1097
    PalworldDigtoise = 1098
    SoundGun = 1099
    TrueCopperShortsword = 1100
    RainbowPhaseblade = 1101
    RainbowPhasesaber = 1102
    SlimeSpear = 1103
    SlimeWhip = 1104
    RemoteControlCar = 1105
    PalworldMinionFoxsparksFlames = 1106
    ObsidianFire = 1107
    ObsidianFire2 = 1108
    ObsidianFire3 = 1109
    SkyDragonsFuryElectrosphere = 1110
    Count = 1


class ProjectileIDSets:
    class Main:
        factory = SetFactory(ProjectileID.Count)
        DontApplyParryDamageBuff = factory.create_bool_set(False, 524, 321, 181, 566)
        BreaksFromToyBreaker = factory.create_bool_set(False, 1020, 1105, 861, 155, 855, 50, 53, 515, 473, 1089, 870, 721, 739, 740, 741, 742, 743, 744, 745, 746, 747, 748, 749, 750, 751, 752, 844, 766, 767, 822, 824, 839, 840, 846, 843, 828, 829, 845, 827, 826, 768, 769, 838, 830, 850, 853, 852, 823, 771, 770)
        IsAGravestone = factory.create_bool_set(False, 202, 201, 204, 43, 203, 205, 527, 528, 529, 530, 531)
        CopiesOwnerAttackCDToLocalImmunityOnSpawn = factory.create_bool_set(False, 1059, 1060, 1061, 1062, 1063, 1064, 1065, 1066, 1067, 1068, 1069, 1070, 1071, 1072, 1075, 1076, 1101, 1102, 1074)
        IsAPhaseblade = factory.create_bool_set(False, 1059, 1060, 1061, 1062, 1063, 1064, 1065, 1066, 1067, 1068, 1069, 1070, 1071, 1072, 1075, 1076, 1101, 1102, 1074)
        IsAWhip = factory.create_bool_set(False, 847, 841, 848, 849, 912, 913, 914, 915, 952, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1104)
        AllowsContactDamageFromJellyfish = factory.create_bool_set(False, 972, 982, 984, 997, 1043)
        ImmediatelyUpdatesNPCBuffFlags = factory.create_bool_set(False, 636)
        IsAnNPCAttachedExplosive = factory.create_bool_set(False, 636)
        RocketsSkipDamageForPlayers = factory.create_bool_set(False, 338, 339, 340, 341, 803, 804, 862, 863, 805, 806, 807, 808, 809, 810, 930, 1088)
        IsABombWithFuse = factory.create_bool_set(False, 28, 37, 516, 519, 910, 911, 1086, 1087, 906, 905, 904, 903, 773, 1077, 75, 102, 681, 470, 29, 637)
        IsAGolfBall = factory.create_bool_set(False, 721, 739, 740, 741, 742, 743, 744, 745, 746, 747, 748, 749, 750, 751, 752)
        IsDestroyedByWater = factory.create_bool_set(False, 85, 15, 188, 34, 1097, 1106)
        CanDistortWater = factory.create_bool_set(True, 7, 8, 152, 151, 150, 493, 494)
        MinionShot = factory.create_bool_set(False, 374, 376, 389, 195, 408, 433, 614, 818, 1044, 1097, 1106)
        SentryShot = factory.create_bool_set(False, 680, 664, 666, 668, 694, 695, 696, 644, 642, 378, 379, 309, 967, 1026)
        FallingBlockDoesNotFallThroughPlatforms = factory.create_bool_set(False, 71, 179, 40, 39, 17, 812, 411, 412, 413, 414, 31, 67, 56, 241, 42, 68, 65, 354)
        TrailingMode = factory.create_int_set(-1, 94, 0, 301, 0, 388, 0, 385, 0, 408, 0, 409, 0, 435, 0, 436, 0, 437, 0, 438, 0, 452, 0, 459, 0, 462, 0, 502, 0, 503, 0, 466, 1, 532, 0, 533, 0, 573, 0, 580, 1, 582, 0, 585, 0, 592, 0, 601, 0, 617, 0, 636, 0, 638, 0, 639, 0, 640, 0, 424, 0, 425, 0, 426, 0, 1037, 0, 660, 0, 661, 0, 671, 2, 664, 0, 666, 0, 668, 0, 675, 0, 680, 2, 682, 0, 684, 0, 686, 2, 700, 0, 706, 0, 709, 0, 710, 2, 711, 2, 712, 0, 715, 2, 716, 2, 717, 2, 718, 2, 261, 0, 721, 0, 729, 2, 732, 0, 731, 0, 739, 0, 740, 0, 741, 0, 742, 0, 743, 0, 744, 0, 745, 0, 746, 0, 747, 0, 748, 0, 749, 0, 750, 0, 751, 0, 752, 0, 755, 2, 766, 2, 767, 2, 768, 2, 769, 2, 770, 2, 771, 2, 811, 2, 814, 2, 822, 2, 823, 2, 824, 2, 826, 2, 827, 2, 828, 2, 829, 2, 830, 2, 838, 2, 839, 2, 840, 2, 843, 2, 844, 2, 845, 2, 846, 2, 850, 2, 852, 2, 853, 2, 856, 0, 857, 0, 864, 2, 873, 2, 872, 2, 833, 2, 834, 2, 835, 2, 818, 2, 902, 0, 883, 0, 887, 0, 893, 0, 894, 0, 909, 0, 916, 2, 34, 3, 16, 3, 79, 3, 931, 2, 933, 4, 946, 2, 964, 0, 965, 0, 977, 2, 976, 2, 973, 2, 106, 5, 85, 3, 1001, 3, 1020, 2, 1024, 2, 1039, 2, 1026, 0, 1045, 2, 1047, 0, 1055, 0, 1089, 0, 1090, 0, 1100, 4, 1097, 2, 1106, 3)
        TrailCacheLength = factory.create_int_set(10, 466, 20, 502, 25, 580, 20, 636, 20, 640, 20, 686, 20, 711, 20, 715, 20, 716, 20, 717, 20, 718, 20, 261, 20, 721, 20, 729, 20, 731, 20, 739, 20, 740, 20, 741, 20, 742, 20, 743, 20, 744, 20, 745, 20, 746, 20, 747, 20, 748, 20, 749, 20, 750, 20, 751, 20, 752, 20, 766, 60, 767, 60, 768, 60, 769, 60, 770, 60, 771, 80, 814, 40, 822, 80, 823, 80, 824, 60, 826, 60, 827, 65, 828, 60, 829, 60, 830, 80, 838, 80, 839, 60, 840, 60, 843, 60, 844, 65, 845, 80, 846, 80, 850, 80, 852, 60, 853, 60, 856, 2, 857, 2, 864, 60, 873, 60, 872, 120, 833, 20, 834, 20, 835, 20, 818, 20, 883, 41, 887, 51, 893, 71, 894, 10, 909, 5, 916, 20, 34, 30, 16, 30, 79, 60, 931, 20, 933, 60, 946, 20, 977, 30, 976, 60, 973, 20, 106, 15, 85, 60, 1001, 12, 1020, 20, 1024, 40, 1039, 20, 1026, 10, 1045, 30, 1047, 25, 1089, 25, 1090, 10, 1100, 60, 1097, 20, 1106, 60)
        LightPet = factory.create_bool_set(False, 18, 500, 72, 87, 86, 211, 492, 650, 702, 891, 896, 895)
        DontCancelChannelOnKill = factory.create_bool_set(False, 190)
        CultistIsResistantTo = factory.create_bool_set(False, 207, 182, 338, 339, 340, 341, 266, 390, 391, 392, 307, 316, 190, 227, 255, 297, 317, 321, 356, 407, 376, 374, 379, 408, 389, 388, 533, 405, 409, 535, 536, 484, 477, 16, 34, 79, 634, 635, 616, 189, 181, 566, 837, 659, 803, 804, 805, 806, 807, 808, 809, 810, 856, 931, 248, 393, 394, 395, 378, 379, 664, 666, 668, 680, 625, 626, 627, 628, 613, 614, 309, 195, 433, 755, 864, 758, 759, 832, 833, 834, 835, 951, 644, 642, 946, 930, 937, 225, 285, 917, 700, 916, 640, 221, 606, 567, 568, 569, 570, 571, 617, 618, 619, 620, 963, 967, 1022, 1026, 1036, 1038, 1037, 1039, 1093, 1097)
        IsADD2Turret = factory.create_bool_set(False, 663, 665, 667, 677, 678, 679, 688, 689, 690, 691, 692, 693)
        TurretFeature = factory.create_bool_set(False)
        MinionTargettingFeature = factory.create_bool_set(False, 191, 192, 193, 194, 266, 317, 373, 375, 387, 388, 390, 393, 407, 423, 533, 613, 625, 755, 758, 759, 831, 833, 834, 835, 864, 946, 951, 963, 970, 1022, 1093, 1094, 377, 308, 643, 641, 663, 665, 667, 677, 678, 679, 688, 689, 690, 691, 692, 693, 966, 1025)
        MinionSacrificable = factory.create_bool_set(False, 191, 192, 193, 194, 266, 317, 373, 375, 387, 388, 390, 393, 407, 423, 533, 613, 755, 758, 759, 831, 970, 864, 946, 951, 963, 1022, 1093, 1094, 625, 626, 627, 628)
        NeedsUUID = factory.create_bool_set(False, 625, 626, 627, 628)
        StardustDragon = factory.create_bool_set(False, 625, 626, 627, 628)
        StormTiger = factory.create_bool_set(False, 833, 834, 835)
        StormTigerIds = [833, 834, 835]
        IsARocketThatDealsDoubleDamageToPrimaryEnemy = factory.create_bool_set(False, 134, 137, 140, 143, 776, 780, 793, 796, 799, 784, 787, 790, 246)
        IsAMineThatDealsTripleDamageWhenStationary = factory.create_bool_set(False, 135, 138, 141, 144, 778, 782, 795, 798, 801, 786, 789, 792)
        NoLiquidDistortion = factory.create_bool_set(False, 511, 512, 513)
        DismountsPlayersOnHit = factory.create_bool_set(False, 877, 878, 879)
        NoMeleeSpeedVelocityScaling = factory.create_bool_set(False, 699, 707, 877, 878, 879, 985, 973)
        DrawScreenCheckFluff = factory.create_int_set(480, 461, 1600, 632, 1600, 447, 1600, 455, 2400, 754, 1600, 872, 1600, 873, 1600, 871, 1600, 919, 2400, 923, 2400, 931, 960, 16, 960, 34, 960, 79, 960, 933, 480, 642, 2400, 106, 960, 1020, 960, 1024, 960, 1039, 960, 1026, 960, 1100, 480, 23, 960, 262, 960, 271, 960, 273, 960, 481, 960)
        CanHitPastShimmer = factory.create_bool_set(False, 605, 270, 719, 961, 962, 926, 922, 100, 84, 83, 96, 101, 102, 275, 276, 277, 258, 259, 384, 385, 386, 874, 872, 873, 871, 683, 676, 670, 675, 686, 687, 467, 468, 464, 465, 466, 526, 456, 462, 455, 452, 454, 949, 1041)
        TrackMinionSpawnFromItemUse = factory.create_bool_set(True, 388, 625, 627, 628)
