"""
BuffID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from terrex.id.set_factory import SetFactory
from enum import IntEnum, auto


class BuffID(IntEnum):
    ObsidianSkin = 1
    Regeneration = 2
    Swiftness = 3
    Gills = 4
    Ironskin = 5
    ManaRegeneration = 6
    MagicPower = 7
    Featherfall = 8
    Spelunker = 9
    Invisibility = 10
    Shine = 11
    NightOwl = 12
    Battle = 13
    Thorns = 14
    WaterWalking = 15
    Archery = 16
    Hunter = 17
    Gravitation = 18
    ShadowOrb = 19
    Poisoned = 20
    PotionSickness = 21
    Darkness = 22
    Cursed = 23
    OnFire = 24
    Tipsy = 25
    WellFed = 26
    FairyBlue = 27
    Werewolf = 28
    Clairvoyance = 29
    Bleeding = 30
    Confused = 31
    Slow = 32
    Weak = 33
    Merfolk = 34
    Silenced = 35
    BrokenArmor = 36
    Horrified = 37
    TheTongue = 38
    CursedInferno = 39
    PetBunny = 40
    BabyPenguin = 41
    PetTurtle = 42
    PaladinsShield = 43
    Frostburn = 44
    BabyEater = 45
    Chilled = 46
    Frozen = 47
    Honey = 48
    Pygmies = 49
    BabySkeletronHead = 50
    BabyHornet = 51
    TikiSpirit = 52
    PetLizard = 53
    PetParrot = 54
    BabyTruffle = 55
    PetSapling = 56
    Wisp = 57
    RapidHealing = 58
    ShadowDodge = 59
    LeafCrystal = 60
    BabyDinosaur = 61
    IceBarrier = 62
    Panic = 63
    BabySlime = 64
    EyeballSpring = 65
    BabySnowman = 66
    Burning = 67
    Suffocation = 68
    Ichor = 69
    Venom = 70
    WeaponImbueVenom = 71
    Midas = 72
    WeaponImbueCursedFlames = 73
    WeaponImbueFire = 74
    WeaponImbueGold = 75
    WeaponImbueIchor = 76
    WeaponImbueNanites = 77
    WeaponImbueConfetti = 78
    WeaponImbuePoison = 79
    Blackout = 80
    PetSpider = 81
    Squashling = 82
    Ravens = 83
    BlackCat = 84
    CursedSapling = 85
    WaterCandle = 86
    Campfire = 87
    ChaosState = 88
    HeartLamp = 89
    Rudolph = 90
    Puppy = 91
    BabyGrinch = 92
    AmmoBox = 93
    ManaSickness = 94
    BeetleEndurance1 = 95
    BeetleEndurance2 = 96
    BeetleEndurance3 = 97
    BeetleMight1 = 98
    BeetleMight2 = 99
    BeetleMight3 = 100
    FairyRed = 101
    FairyGreen = 102
    Wet = 103
    Mining = 104
    Heartreach = 105
    Calm = 106
    Builder = 107
    Titan = 108
    Flipper = 109
    Summoning = 110
    Dangersense = 111
    AmmoReservation = 112
    Lifeforce = 113
    Endurance = 114
    Rage = 115
    Inferno = 116
    Wrath = 117
    Minecart = 118
    Lovestruck = 119
    Stinky = 120
    Fishing = 121
    Sonar = 122
    Crate = 123
    Warmth = 124
    HornetMinion = 125
    ImpMinion = 126
    ZephyrFish = 127
    BunnyMount = 128
    PigronMount = 129
    SlimeMount = 130
    TurtleMount = 131
    BeeMount = 132
    SpiderMinion = 133
    TwinEyesMinion = 134
    PirateMinion = 135
    MiniMinotaur = 136
    Slimed = 137
    MinecartLegacyUnused = 138
    SharknadoMinion = 139
    UFOMinion = 140
    UFOMount = 141
    DrillMount = 142
    ScutlixMount = 143
    Electrified = 144
    MoonLeech = 145
    Sunflower = 146
    MonsterBanner = 147
    Rabies = 148
    Webbed = 149
    Bewitched = 150
    SoulDrain = 151
    MagicLantern = 152
    ShadowFlame = 153
    BabyFaceMonster = 154
    CrimsonHeart = 155
    Stoned = 156
    PeaceCandle = 157
    StarInBottle = 158
    Sharpened = 159
    Dazed = 160
    DeadlySphere = 161
    UnicornMount = 162
    Obstructed = 163
    VortexDebuff = 164
    DryadsWard = 165
    MinecartMech = 166
    MinecartMechLegacyUnused = 167
    CuteFishronMount = 168
    BoneJavelin = 169
    SolarShield1 = 170
    SolarShield2 = 171
    SolarShield3 = 172
    NebulaUpLife1 = 173
    NebulaUpLife2 = 174
    NebulaUpLife3 = 175
    NebulaUpMana1 = 176
    NebulaUpMana2 = 177
    NebulaUpMana3 = 178
    NebulaUpDmg1 = 179
    NebulaUpDmg2 = 180
    NebulaUpDmg3 = 181
    StardustMinion = 182
    StardustMinionBleed = 183
    MinecartWood = 184
    MinecartWoodLegacyUnused = 185
    DryadsWardDebuff = 186
    StardustGuardianMinion = 187
    StardustDragonMinion = 188
    Daybreak = 189
    SuspiciousTentacle = 190
    CompanionCube = 191
    SugarRush = 192
    BasiliskMount = 193
    WindPushed = 194
    WitheredArmor = 195
    WitheredWeapon = 196
    OgreSpit = 197
    ParryDamageBuff = 198
    NoBuilding = 199
    PetDD2Gato = 200
    PetDD2Ghost = 201
    PetDD2Dragon = 202
    BetsysCurse = 203
    Oiled = 204
    BallistaPanic = 205
    WellFed2 = 206
    WellFed3 = 207
    DesertMinecart = 208
    DesertMinecartLegacyUnused = 209
    FishMinecart = 210
    FishMinecartLegacyUnused = 211
    GolfCartMount = 212
    BatOfLight = 213
    VampireFrog = 214
    CatBast = 215
    BabyBird = 216
    UpbeatStar = 217
    SugarGlider = 218
    SharkPup = 219
    BeeMinecart = 220
    BeeMinecartLegacyUnused = 221
    LadybugMinecart = 222
    LadybugMinecartLegacyUnused = 223
    PigronMinecart = 224
    PigronMinecartLegacyUnused = 225
    SunflowerMinecart = 226
    SunflowerMinecartLegacyUnused = 227
    HellMinecart = 228
    HellMinecartLegacyUnused = 229
    WitchBroom = 230
    ShroomMinecart = 231
    ShroomMinecartLegacyUnused = 232
    AmethystMinecart = 233
    AmethystMinecartLegacyUnused = 234
    TopazMinecart = 235
    TopazMinecartLegacyUnused = 236
    SapphireMinecart = 237
    SapphireMinecartLegacyUnused = 238
    EmeraldMinecart = 239
    EmeraldMinecartLegacyUnused = 240
    RubyMinecart = 241
    RubyMinecartLegacyUnused = 242
    DiamondMinecart = 243
    DiamondMinecartLegacyUnused = 244
    AmberMinecart = 245
    AmberMinecartLegacyUnused = 246
    BeetleMinecart = 247
    BeetleMinecartLegacyUnused = 248
    MeowmereMinecart = 249
    MeowmereMinecartLegacyUnused = 250
    PartyMinecart = 251
    PartyMinecartLegacyUnused = 252
    PirateMinecart = 253
    PirateMinecartLegacyUnused = 254
    SteampunkMinecart = 255
    SteampunkMinecartLegacyUnused = 256
    Lucky = 257
    LilHarpy = 258
    FennecFox = 259
    GlitteryButterfly = 260
    BabyImp = 261
    BabyRedPanda = 262
    StormTiger = 263
    Plantero = 264
    Flamingo = 265
    DynamiteKitten = 266
    BabyWerewolf = 267
    ShadowMimic = 268
    CoffinMinecart = 269
    CoffinMinecartLegacyUnused = 270
    Smolstar = 271
    DiggingMoleMinecart = 272
    DiggingMoleMinecartLegacyUnused = 273
    VoltBunny = 274
    PaintedHorseMount = 275
    MajesticHorseMount = 276
    DarkHorseMount = 277
    PogoStickMount = 278
    PirateShipMount = 279
    SpookyWoodMount = 280
    SantankMount = 281
    WallOfFleshGoatMount = 282
    DarkMageBookMount = 283
    KingSlimePet = 284
    EyeOfCthulhuPet = 285
    EaterOfWorldsPet = 286
    BrainOfCthulhuPet = 287
    SkeletronPet = 288
    QueenBeePet = 289
    DestroyerPet = 290
    TwinsPet = 291
    SkeletronPrimePet = 292
    PlanteraPet = 293
    GolemPet = 294
    DukeFishronPet = 295
    LunaticCultistPet = 296
    MoonLordPet = 297
    FairyQueenPet = 298
    PumpkingPet = 299
    EverscreamPet = 300
    IceQueenPet = 301
    MartianPet = 302
    DD2OgrePet = 303
    DD2BetsyPet = 304
    LavaSharkMount = 305
    TitaniumStorm = 306
    # BlandWhipEnemyDebuff = 307
    SwordWhipPlayerBuff = 308
    # SwordWhipNPCDebuff = 309
    ScytheWhipEnemyDebuff = 310
    ScytheWhipPlayerBuff = 311
    CoolWhipPlayerBuff = 312
    # FlameWhipEnemyDebuff = 313
    ThornWhipPlayerBuff = 314
    # ThornWhipNPCDebuff = 315
    # RainbowWhipNPCDebuff = 316
    QueenSlimePet = 317
    QueenSlimeMount = 318
    # MaceWhipNPCDebuff = 319
    GelBalloonBuff = 320
    BrainOfConfusionBuff = 321
    EmpressBlade = 322
    OnFire3 = 323
    Frostburn2 = 324
    FlinxMinion = 325
    # BoneWhipNPCDebuff = 326
    BerniePet = 327
    GlommerPet = 328
    DeerclopsPet = 329
    PigPet = 330
    ChesterPet = 331
    NeutralHunger = 332
    Hunger = 333
    Starving = 334
    AbigailMinion = 335
    HeartyMeal = 336
    TentacleSpike = 337
    FartMinecart = 338
    FartMinecartLegacyUnused = 339
    # CoolWhipNPCDebuff = 340
    DualSlimePet = 341
    WolfMount = 342
    BiomeSight = 343
    BloodButcherer = 344
    JunimoPet = 345
    TerraFartMinecart = 346
    TerraFartMinecartLegacyUnused = 347
    WarTable = 348
    BlueChickenPet = 349
    ShadowCandle = 350
    Spiffo = 351
    CavelingGardener = 352
    Shimmer = 353
    DirtiestBlock = 354
    DeadCellsMushroomBoiMinion = 355
    DeadCellsSwarmBiter = 356
    # CobWhipNPCDebuff = 357
    # CorruptWhipNPCDebuff = 358
    # CrimsonWhipNPCDebuff = 359
    # MeteorWhipNPCDebuff = 360
    # FlowerWhipNPCDebuff = 361
    EelWhipNPCDebuff = 362
    # ConstellationWhipNPCDebuff = 363
    # MoonLordWhipNPCDebuff = 364
    CobWhipPlayerBuff = 365
    DeadCellsPotionStation = 366
    # FlowerWhipNPCDebuffProc = 367
    # MoonLordWhipNPCDebuffProc = 368
    # MeteorWhipNPCDebuffProc = 369
    VelociraptorMount = 370
    Pufferfish = 371
    AxeFairyPet = 372
    BoulderPet = 373
    RatMount = 374
    Hemorrhage = 375
    TorchGodPotion = 376
    BatMount = 377
    RollerSkatesMount = 378
    RollerSkatesGreenMount = 379
    RollerSkatesWhiteMount = 380
    RollerSkatesPinkMount = 381
    RainbowBoulderPet = 382
    Kite = 383
    PixieMount = 384
    PalworldMinionCattiva = 385
    PalworldMinionFoxsparks = 386
    PalworldPetChillet = 387
    PalworldPetChilletIgnis = 388
    Count = 389


class BuffIDSets:
    class Main:
        factory = SetFactory(BuffID.Count)
        IsWellFed = factory.create_bool_set(False, 26, 206, 207)
        IsFedState = factory.create_bool_set(False, 26, 206, 207, 332, 333, 334)
        SortingPriorityFoodBuffs = factory.create_int_set(-1, 207, 4, 206, 3, 26, 2, 25, 1)
        IsAnNPCWhipDebuff = factory.create_bool_set(False, 310, 362)
        TimeLeftDoesNotDecrease = factory.create_bool_set(False, 28, 334, 29, 159, 150, 93, 348, 366)
        CanBeRemovedByNetMessage = factory.create_bool_set(False)
        IsAFlaskBuff = factory.create_bool_set(False, 71, 72, 73, 74, 75, 76, 77, 78, 79)
        BuffTimeIsExtendedWithGameDifficulty = factory.create_bool_set(False, 20, 22, 23, 24, 323, 30, 31, 32, 33, 35, 36, 39, 44, 324, 46, 47, 69, 70, 80)
        BuffTimeIsExtendedByDeadCellsPotionStationBuff = factory.create_bool_set(False, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 121, 122, 123, 124, 257, 343)
        NurseCannotRemoveDebuff = factory.create_bool_set(False, 28, 34, 87, 89, 21, 86, 199, 332, 333, 334, 165, 146, 48, 158, 157, 350, 215, 147, 321, 43)
        AddBuffTimeAdditivelyToCap = factory.create_int_set(0, 94, 600, 383, 43200)
        MountType = factory.create_int_set(-1, 118, 6, 184, 13, 166, 11, 208, 15, 210, 16, 220, 18, 222, 19, 224, 20, 226, 21, 228, 22, 231, 24, 233, 25, 235, 26, 237, 27, 239, 28, 241, 29, 243, 30, 245, 31, 247, 32, 249, 33, 251, 34, 253, 35, 255, 36, 269, 38, 272, 39, 338, 51, 346, 53, 90, 0, 128, 1, 129, 2, 130, 3, 131, 4, 132, 5, 168, 12, 141, 7, 142, 8, 143, 9, 162, 10, 193, 14, 212, 17, 230, 23, 265, 37, 275, 40, 276, 41, 277, 42, 278, 43, 279, 44, 280, 45, 281, 46, 282, 47, 283, 48, 305, 49, 318, 50, 342, 52, 370, 54, 374, 55, 377, 56, 378, 57, 379, 58, 380, 59, 381, 60, 384, 61, 387, 62, 388, 63)
