"""
PlayerVoiceOverrideID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class PlayerVoiceOverrideID(IntEnum):
    NoOverride = 0
    Male = 1
    Female = 2
    DontStarveMale = 3
    DontStarveFemale = 4
    Cow = 5
    Chicken = 6
    Frog = 7
    Goat = 8
    Retro = 9
    Cat = 10
    Dog = 11
    Turkey = 12
    Goblin = 13
    Crow = 14
    Balloon = 15
    Undead = 16
    Vampire = 17
    Fairy = 18
    WhoopieCushion = 19
    Other = 20

