"""
ItemUseStyleID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class ItemUseStyleID(IntEnum):
    NoneValue = 0
    Swing = 1
    EatFood = 2
    Thrust = 3
    HoldUp = 4
    Shoot = 5
    DrinkLong = 6
    DrinkOld = 7
    GolfPlay = 8
    DrinkLiquid = 9
    HiddenAnimation = 10
    MowTheLawn = 11
    Guitar = 12
    Rapier = 13
    RaiseLamp = 14
    HoldOrb = 15
    PlaySound = 16

