"""
ArmorIDs - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from terrex.id.set_factory import SetFactory
from enum import IntEnum, auto


class ArmorIDs:
    Count = 293

    class Back(IntEnum):
        BeeCloak = 1
        StarCloak = 2
        CrimsonCloak = 3
        MysteriousCape = 4
        RedCape = 5
        WinterCape = 6
        MagicQuiver = 7
        ArchitectGizmoPack = 8
        HivePack = 9
        AnglerTackleBag = 10
        ApprenticeDark = 11
        RedRidingHuntress = 12
        ShinobiInfiltrator = 13
        ManaCloak = 14
        MoltenQuiver = 15
        StalkersQuiver = 16
        ClothiersJacket = 17
        SpaceCreatureShirt = 18
        FoxShirt = 19
        VampireShirt = 20
        CatShirt = 21
        SuperHeroCostumeMale = 22
        SuperHeroCostumeFemale = 23
        HunterCloak = 24
        DogTail = 25
        FoxTail = 26
        LizardTail = 27
        BunnyTail = 28
        HallowedCape = 29
        PlaguebringerCloak = 30
        RoninCloak = 31
        FloretProtecterChestplate = 32
        LavaproofTackleBag = 33
        PrinceCape = 34
        HandOfCreation = 35
        ShimmerCloak = 36
        ChickenBonesRobe = 37
        ChippysWings = 38
        LunasCloak = 39
        Count = 40

    class Balloon(IntEnum):
        BlizzardinaBalloon = 1
        BlueHorseshoeBalloon = 2
        BundleofBalloons = 3
        CloudinaBalloon = 4
        FartinaBalloon = 5
        SandstorminaBalloon = 6
        HoneyBalloon = 7
        ShinyRedBalloon = 8
        WhiteHorseshoeBalloon = 9
        YellowHorseshoeBalloon = 10
        BalloonPufferfish = 11
        SharkronBalloon = 12
        GreenHorseshoeBalloon = 13
        AmberHorseshoeBalloon = 14
        PinkHorseshoeBalloon = 15
        BundledPartyBalloons = 16
        BalloonAnimal = 17
        RoyalScepter = 18
        HorseshoeBundle = 19
        Count = 20

    class Beard(IntEnum):
        GingerBeard = 1
        WilsonBeardShort = 2
        WilsonBeardLong = 3
        WilsonBeardMagnificent = 4
        Count = 5

    class Body(IntEnum):
        FamiliarShirt = 0
        CopperChainmail = 1
        IronChainmail = 2
        SilverChainmail = 3
        GoldChainmail = 4
        ShadowScalemail = 5
        MeteorSuit = 6
        NecroBreastplate = 7
        JungleShirt = 8
        MoltenBreastplate = 9
        TuxedoShirt = 10
        PlumbersShirt = 11
        HerosShirt = 12
        ArchaeologistsJacket = 13
        NinjaShirt = 14
        Robe = 15
        TheDoctorsShirt = 16
        CobaltBreastplate = 17
        MythrilChainmail = 18
        AdamantiteBreastplate = 19
        MiningShirt = 20
        Werewolf = 21
        Merman = 22
        ClownShirt = 23
        HallowedPlateMail = 24
        SantaShirt = 25
        RedsBreastplate = 26
        FrostBreastplate = 27
        TinChainmail = 28
        LeadChainmail = 29
        TungstenChainmail = 30
        PlatinumChainmail = 31
        WoodBreastplate = 32
        EbonwoodBreastplate = 33
        RichMahoganyBreastplate = 34
        PearlwoodBreastplate = 35
        RuneRobe = 36
        CrimsonScalemail = 37
        EskimoCoat = 38
        SteampunkShirt = 39
        BeeShirt = 40
        PrincessCostume = 41
        PharaohsRobe = 42
        MummyShirt = 43
        CowboyJacket = 44
        PirateShirt = 45
        CactusBreastplate = 46
        ShadewoodBreastplate = 47
        AncientShadowScalemail = 48
        AncientCobaltBreastplate = 49
        PinkEskimoCoat = 50
        ChlorophytePlateMail = 51
        RainCoat = 52
        TikiShirt = 53
        PalladiumBreastplate = 54
        OrichalcumBreastplate = 55
        TitaniumBreastplate = 56
        SailorShirt = 57
        AmethystRobe = 58
        TopazRobe = 59
        SapphireRobe = 60
        EmeraldRobe = 61
        RubyRobe = 62
        DiamondRobe = 63
        WhiteTuxedoShirt = 64
        TurtleScaleMail = 65
        SpectreRobe = 66
        ShroomiteBreastplate = 67
        CenxsBreastplate = 68
        CrownosBreastplate = 69
        WillsBreastplate = 70
        JimsBreastplate = 71
        AaronsBreastplate = 72
        DTownsBreastplate = 73
        CenxsDress = 74
        PumpkinBreastplate = 75
        NurseShirt = 76
        DyeTraderRobe = 77
        CyborgShirt = 78
        CreeperShirt = 79
        CatShirt = 80
        GhostShirt = 81
        PumpkinShirt = 82
        RobotShirt = 83
        UnicornShirt = 84
        VampireShirt = 85
        LeprechaunShirt = 86
        PixieShirt = 87
        PrincessDress = 88
        WitchDress = 89
        BrideofFrankensteinDress = 90
        KarateTortoiseShirt = 91
        ScarecrowShirt = 92
        ReaperRobe = 93
        FoxShirt = 94
        SpookyBreastplate = 95
        SpaceCreatureShirt = 96
        WolfShirt = 97
        TreasureHunterShirt = 98
        DryadCoverings = 99
        MrsClausShirt = 100
        TreeShirt = 101
        ParkaCoat = 102
        UglySweater = 103
        ElfShirt = 104
        BeetleScaleMail = 105
        BeetleShell = 106
        Gi = 165
        Kimono = 166
        GypsyRobe = 167
        BeeBreastplate = 168
        AnglerVest = 169
        SpiderBreastplate = 170
        MermaidAdornment = 171
        FishCostumeShirt = 172
        BorealWoodBreastplate = 173
        PalmWoodBreastplate = 174
        VortexBreastplate = 175
        NebulaBreastplate = 176
        SolarFlareBreastplate = 177
        MartianCostumeShirt = 178
        MartianUniformTorso = 179
        SolarCultistRobe = 180
        LunarCultistRobe = 181
        GladiatorBreastplate = 182
        LazuresValkyrieCloak = 183
        TaxCollectorsSuit = 184
        ClothiersJacket = 185
        BuccaneerTunic = 186
        ObsidianLongcoat = 187
        FallenTuxedoShirt = 188
        FossilPlate = 189
        StardustPlate = 190
        WeddingDress = 191
        Yoraiz0rsUniform = 192
        SkiphssSkin = 193
        LokisBreastplate = 194
        SillySunflowerTops = 195
        PedguinsJacket = 196
        AncientArmor = 197
        AncientBattleArmor = 198
        Lamia = 199
        ApprenticeRobe = 200
        SquirePlating = 201
        HuntressJerkin = 202
        MonkShirt = 203
        ValhallaKnight = 204
        ApprenticeDark = 205
        RedRidingHuntress = 206
        ShinobiInfiltrator = 207
        ArkhalisShirt = 208
        LeinforsShirt = 209
        Maid = 210
        MaidAlt = 211
        Golf = 212
        AmberRobe = 213
        GameMasterShirt = 214
        StarPrincessDress = 215
        ChefOutfit = 216
        SuperHeroCostume = 217
        PrettyPinkDress = 218
        UndertakerCoat = 219
        FuneralCoat = 220
        VictorianGothDress = 221
        GhostarShirt = 222
        DrManFlyLabCoat = 223
        ButcherApron = 224
        SafemanSunDress = 225
        FoodBarbarianArmor = 226
        GroxTheGreatArmor = 227
        MushroomVest = 228
        AncientHallowedPlateMail = 229
        CrystalNinjaChestplate = 230
        GraduationGownBlue = 231
        GraduationGownMaroon = 232
        GraduationGownBlack = 233
        DeadMansSweater = 234
        PlaguebringerChestplate = 235
        RoninShirt = 236
        TimelessTravelerRobe = 237
        FloretProtectorChestplate = 238
        CapricornChestplate = 239
        TVHeadSuit = 240
        FlinxFurCoat = 241
        RoyalDressTop = 242
        PrinceUniform = 243
        WilsonShirt = 244
        WillowShirt = 245
        AshWoodBreastplate = 246
        LincolnsHoodie = 247
        DeadCellsBeheadedBody = 248
        MoonLordBody = 249
        ChickenBonesBody = 250
        ChickenBonesRobe = 251
        UpgradedMiningBody = 252
        UpgradedFishingBody = 253
        ChippysBody = 254
        BlueBikiniBody = 255
        RedSwimsuitBody = 256
        HeroicisBody = 257
        LilacDuskBody = 258
        KazzymodusChestpiece = 259
        PalworldPalMetalArmorBody = 260
        LunasBody = 261
        Count = 262

    class Face(IntEnum):
        NaturesGift = 1
        ArcticDivingGear = 2
        JellyfishDivingGear = 3
        DivingGear = 4
        Blindfold = 5
        ObsidianRose = 6
        AngelHalo = 7
        JungleRose = 8
        ArcaneFlower = 9
        LavaSkull = 10
        MoltenSkullRose = 11
        ObsidianSkull = 12
        ObsidianSkullRose = 13
        SpectreGoggles = 14
        LavaSkullAlt = 15
        MoltenSkullRoseAlt = 16
        ObsidianSkullAlt = 17
        ObsidianSkullRoseAlt = 18
        BoneHelm = 19
        ReflectiveShades = 20
        JimsDroneVisor = 21
        WeldingMask = 22
        ChippysHeadband = 23
        Count = 24

    class Front(IntEnum):
        CrimsonCloak = 1
        MysteriousCape = 2
        RedCape = 3
        WinterCape = 4
        ManaCloak = 5
        TaxCollectorsSuit = 6
        VampireShirt = 7
        HunterCloak = 8
        PlaguebringerCloak = 9
        RoninCloak = 10
        PrinceCape = 11
        ShimmerCloak = 12
        DeadCellsBeheadedBody = 13
        ChickenBonesRobe = 14
        ChippysWings = 15
        LunasCloak = 16
        Count = 17

    class HandOff(IntEnum):
        FireGauntlet = 1
        HandWarmer = 2
        MagicCuffs = 3
        MechanicalGlove = 4
        PowerGlove = 5
        ClimbingClaws = 6
        MasterNinjaGear = 6
        TigerClimbingGear = 6
        Shackle = 7
        TitanGlove = 8
        FeralClaws = 9
        CelestialCuffs = 10
        YoyoGlove = 11
        BersekerGlove = 12
        FrogWebbing = 13
        BoneGlove = 14
        HandOfCreation = 15
        Count = 16

    class HandOn(IntEnum):
        ManaRegenerationBand = 1
        BandofRegeneration = 2
        BandofStarpower = 3
        CharmofMyths = 4
        FeralClaws = 5
        FireGauntlet = 6
        HandWarmer = 7
        MagicCuffs = 8
        MechanicalGlove = 9
        PowerGlove = 10
        ClimbingClaws = 11
        MasterNinjaGear = 11
        TigerClimbingGear = 11
        Shackle = 12
        SunStone = 13
        MoonStone = 14
        TitanGlove = 15
        DiamondRing = 16
        CelestialCuffs = 17
        YoyoGlove = 18
        HuntressBuckler = 19
        BersekerGlove = 20
        FrogWebbing = 21
        BoneGlove = 22
        HandOfCreation = 23
        LavaCharm = 24
        Count = 25

    class Head(IntEnum):
        FamiliarWig = 0
        CopperHelmet = 1
        IronHelmet = 2
        SilverHelmet = 3
        GoldHelmet = 4
        ShadowHelmet = 5
        MeteorHelmet = 6
        NecroHelmet = 7
        JungleHat = 8
        MoltenHelmet = 9
        Goggles = 10
        MiningHelmet = 11
        Sunglasses = 12
        EmptyBucket = 13
        WizardHat = 14
        TopHat = 15
        SummerHat = 16
        BunnyHood = 17
        PlumbersHat = 18
        HerosHat = 19
        FishBowl = 20
        ArchaeologistsHat = 21
        NinjaHood = 22
        Unused = 23
        RedHat = 24
        RobotHat = 25
        GoldCrown = 26
        DivingHelmet = 27
        MimeMask = 28
        CobaltHat = 29
        CobaltHelmet = 30
        CobaltMask = 31
        MythrilHood = 32
        MythrilHelmet = 33
        MythrilHat = 34
        AdamantiteHeadgear = 35
        AdamantiteHelmet = 36
        AdamantiteMask = 37
        Werewolf = 38
        Merman = 39
        ClownHat = 40
        HallowedHelmet = 41
        HallowedHeadgear = 42
        HallowedMask = 43
        SantaHat = 44
        RedsHelmet = 45
        FrostHelmet = 46
        TinHelmet = 47
        LeadHelmet = 48
        TungstenHelmet = 49
        PlatinumHelmet = 50
        PlatinumCrown = 51
        WoodHelmet = 52
        EbonwoodHelmet = 53
        RichMahoganyHelmet = 54
        PearlwoodHelmet = 55
        RuneHat = 56
        CrimsonHelmet = 57
        EskimoHood = 58
        SteampunkHat = 59
        BeeHat = 60
        PharaohsMask = 61
        Tiara = 62
        GreenCap = 63
        MushroomCap = 64
        TamOShanter = 65
        MummyMask = 66
        CowboyHat = 67
        PirateHat = 68
        VikingHelmet = 69
        CactusHelmet = 70
        ShadewoodHelmet = 71
        AncientIronHelmet = 72
        AncientGoldHelmet = 73
        AncientShadowHelmet = 74
        AncientNecroHelmet = 75
        AncientCobaltHelmet = 76
        PinkEskimoHood = 77
        ChlorophyteMask = 78
        ChlorophyteHelmet = 79
        ChlorophyteHeadgear = 80
        RainHat = 81
        TikiMask = 82
        PalladiumMask = 83
        PalladiumHelmet = 84
        PalladiumHeadgear = 85
        OrichalcumMask = 86
        OrichalcumHelmet = 87
        OrichalcumHeadgear = 88
        TitaniumMask = 89
        TitaniumHelmet = 90
        TitaniumHeadgear = 91
        UmbrellaHat = 92
        Skull = 93
        BallaHat = 94
        GangstaHat = 95
        SailorHat = 96
        EyePatch = 97
        SkeletronMask = 98
        TurtleHelmet = 99
        Beanie = 100
        SpectreHood = 101
        SWATHelmet = 102
        ShroomiteHeadgear = 103
        ShroomiteMask = 104
        ShroomiteHelmet = 105
        CenxsTiara = 106
        CrownosMask = 107
        WillsHelmet = 108
        JimsHelmet = 109
        AaronsHelmet = 110
        DTownsHelmet = 111
        PumpkinHelmet = 112
        NurseHat = 113
        WizardsHat = 114
        GuyFawkesMask = 115
        SteampunkGoggles = 116
        CyborgHelmet = 117
        CreeperMask = 118
        CatMask = 119
        GhostMask = 120
        PumpkinMask = 121
        RobotMask = 122
        UnicornMask = 123
        VampireMask = 124
        WitchHat = 125
        LeprechaunHat = 126
        PrincessHat = 127
        BrideofFrankensteinMask = 128
        KarateTortoiseMask = 129
        ScarecrowHat = 130
        ReaperHood = 131
        FoxMask = 132
        CatEars = 133
        SpookyHelmet = 134
        SpaceCreatureMask = 135
        WolfMask = 136
        JackOLanternMask = 137
        GiantBow = 138
        ReindeerAntlers = 139
        MrsClausHat = 140
        TreeMask = 141
        ParkaHood = 142
        SnowHat = 143
        ElfHat = 144
        Fez = 145
        BrainofCthulhuMask = 146
        WallofFleshMask = 147
        TwinMask = 148
        SkeletronPrimeMask = 149
        QueenBeeMask = 150
        PlanteraMask = 151
        GolemMask = 152
        EaterofWorldsMask = 153
        EyeofCthulhuMask = 154
        DestroyerMask = 155
        SpectreMask = 156
        BeetleHelmet = 157
        PeddlersHat = 158
        MagicHat = 159
        BeeHeadgear = 160
        AnglerHat = 161
        SpiderMask = 162
        SeashellHairpin = 163
        KingSlimeMask = 164
        FishCostumeMask = 165
        BorealWoodHelmet = 166
        PalmWoodHelmet = 167
        DukeFishronMask = 168
        VortexHelmet = 169
        NebulaHelmet = 170
        SolarFlareHelmet = 171
        MoonMask = 172
        SunMask = 173
        MartianCostumeMask = 174
        MartianUniformHelmet = 175
        SolarCultistHood = 176
        LunarCultistHood = 177
        HiTekSunglasses = 178
        NightVisionHelmet = 179
        GladiatorHelmet = 180
        LazuresValkyrieCirclet = 181
        TaxCollectorsHat = 182
        DyeTradersTurban = 183
        BuccaneerBandana = 184
        ObsidianOutlawHat = 185
        AncientCultistMask = 186
        MoonLordMask = 187
        FossilHelmet = 188
        StardustHelmet = 189
        WeddingVeil = 190
        Yoraiz0rsRecoloredGoggles = 191
        SkiphssMask = 192
        LokisHelmet = 193
        EngineeringHelmet = 194
        PartyHat = 195
        SillySunflowerPetals = 196
        PedguinsHood = 197
        _0x33sAviators = 198
        AncientArmor = 199
        AncientBattleArmor = 200
        LamiaMale = 201
        LamiaFemale = 202
        ApprenticeHat = 203
        SquireGreatHelm = 204
        HuntressWig = 205
        MonkBrows = 206
        MaskBetsy = 207
        MaskDarkMage = 208
        MaskOgre = 209
        ValhallaKnight = 210
        ApprenticeDark = 211
        RedRidingHuntress = 212
        ShinobiInfiltrator = 213
        ArkhalisHat = 214
        LeinforsHat = 215
        UltraBrightHelmet = 216
        Maid = 217
        MaidAlt = 218
        GolfHat = 219
        GolfVisor = 220
        GoldGoldfishBowl = 221
        StarPrincessCrown = 222
        DemonHorns = 223
        BunnyEars = 224
        DevilHorns = 225
        Fedora = 226
        ChefHat = 227
        StarHairpin = 228
        HeartHairpin = 229
        SuperHeroMask = 230
        UndertakerHat = 231
        PrettyPinkRibbon = 232
        FuneralHat = 233
        VictorianGothHat = 234
        GhostarSkullPin = 235
        DrManFlyMask = 236
        ButcherMask = 237
        SafemanSunHair = 238
        FoodBarbarianHelm = 239
        GroxTheGreatHelm = 240
        RockGolemHead = 241
        DogEars = 242
        FoxEars = 243
        LizardEars = 244
        PandaEars = 245
        DogEarsBack = 246
        FoxEarsBack = 247
        LizardEarsBack = 248
        PandaEarsBack = 249
        MushroomHat = 250
        FairyQueenMask = 251
        CatEarsBack = 252
        BunnyEarsBack = 253
        HallowedHood = 254
        AncientHallowedMask = 255
        AncientHallowedHelmet = 256
        AncientHallowedHeadgear = 257
        AncientHallowedHood = 258
        RabbitOrder = 259
        QueenSlimeMask = 260
        CrystalNinjaHelmet = 261
        GraduationCapBlue = 262
        GraduationCapMaroon = 263
        GraduationCapBlack = 264
        BadgersHat = 265
        PlaguebringerHelmet = 266
        RoninHat = 267
        TimelessTravelerHood = 268
        FloretProtectorHelmet = 269
        CapricornMask = 270
        TVHeadMask = 271
        RoyalTiara = 272
        GarlandHat = 273
        VulkelfEars = 274
        Eyebrella = 275
        DeerclopsMask = 276
        GoblorcEars = 277
        AshWoodHelmet = 278
        JimsCap = 279
        DizzyHat = 280
        LincolnsHood = 281
        DeadCellsBeheadedHead = 282
        ChlorophyteVisor = 283
        ChickenBonesHead = 284
        UpgradedMiningHead = 285
        UpgradedFishingHead = 286
        ChippysHead = 287
        HeroicisHead = 288
        HallowedCrown = 289
        LilacDuskHead = 290
        KazzymodusHood = 291
        LunasHead = 292
        Count = 293

    class Legs(IntEnum):
        FamiliarPants = 0
        CopperGreaves = 1
        IronGreaves = 2
        SilverGreaves = 3
        GoldGreaves = 4
        ShadowGreaves = 5
        MeteorLeggings = 6
        NecroGreaves = 7
        JunglePants = 8
        MoltenGreaves = 9
        TuxedoPants = 10
        PlumbersPants = 11
        HerosPants = 12
        ArchaeologistsPants = 13
        NinjaPants = 14
        TheDoctorsPants = 15
        CobaltLeggings = 16
        MythrilGreaves = 17
        AdamantiteLeggings = 18
        MiningPants = 19
        Werewolf = 20
        Merman = 21
        ClownPants = 22
        HallowedGreaves = 23
        SantaPants = 24
        RedsLeggings = 25
        FrostLeggings = 26
        TinGreaves = 27
        LeadGreaves = 28
        TungstenGreaves = 29
        PlatinumGreaves = 30
        WoodGreaves = 31
        EbonwoodGreaves = 32
        RichMahoganyGreaves = 33
        PearlwoodGreaves = 34
        CrimsonGreaves = 35
        EskimoPants = 36
        SteampunkPants = 37
        BeePants = 38
        MummyPants = 39
        CowboyPants = 40
        PiratePants = 41
        CactusLeggings = 42
        ShadewoodGreaves = 43
        AncientShadowGreaves = 44
        AncientCobaltLeggings = 45
        PinkEskimoPants = 46
        ChlorophyteGreaves = 47
        TikiPants = 48
        PalladiumLeggings = 49
        OrichalcumLeggings = 50
        TitaniumLeggings = 51
        SailorPants = 52
        WhiteTuxedoPants = 53
        TurtleLeggings = 54
        SpectrePants = 55
        ShroomiteLeggings = 56
        CenxsLeggings = 57
        CrownosLeggings = 58
        WillsLeggings = 59
        JimsLeggings = 60
        AaronsLeggings = 61
        DTownsLeggings = 62
        CenxsDressPants = 63
        PumpkinLeggings = 64
        NursePants = 65
        CyborgPants = 66
        CreeperPants = 67
        CatPants = 68
        PumpkinPants = 69
        RobotPants = 70
        UnicornPants = 71
        VampirePants = 72
        LeprechaunPants = 73
        PixiePants = 74
        WitchBoots = 75
        KarateTortoisePants = 76
        ScarecrowPants = 77
        FoxPants = 78
        SpookyLeggings = 79
        SpaceCreaturePants = 80
        WolfPants = 81
        TreasureHunterPants = 82
        DryadLoincloth = 83
        MrsClausHeels = 84
        TreeTrunks = 85
        ParkaPants = 86
        ElfPants = 87
        BeetleLeggings = 98
        GiFemaleExtension = 99
        GypsyRobeMaleExtension = 101
        GypsyRobeFemaleExtension = 102
        BeeGreaves = 103
        AnglerPants = 104
        SpiderGreaves = 105
        MermaidTail = 106
        FishCostumeFinskirt = 107
        BorealWoodGreaves = 108
        PalmWoodGreaves = 109
        VortexLeggings = 110
        NebulaLeggings = 111
        SolarFlareLeggings = 112
        MartianCostumePants = 113
        MartianUniformPants = 114
        GiMaleExtension = 118
        GladiatorLeggings = 122
        TaxCollectorsPants = 124
        ClothiersPants = 125
        BuccaneerPantaloons = 126
        ObsidianPants = 127
        FallenTuxedoPants = 128
        FossilGreaves = 129
        StardustLeggings = 130
        Yoraiz0rsSkirt = 132
        SkiphssBearButt = 133
        LokisGreaves = 134
        SillySunflowerBottoms = 138
        PedguinsTrousers = 139
        DjinnsCurse = 140
        AncientArmor = 141
        AncientBattleArmor = 142
        Lamia = 143
        ApprenticeTrousers = 144
        SquireGreaves = 145
        HuntressPantsMale = 146
        HuntressPantsFemale = 147
        MonkPants = 148
        ApprenticeRobeExtension = 149
        SquirePlatingExtension = 150
        HuntressJerkinExtension = 151
        ValhallaKnight = 152
        ApprenticeDark = 153
        RedRidingHuntress = 154
        RedRidingHuntress_Male = 155
        ShinobiInfiltrator = 156
        ArkhalisPants_Male = 157
        ArkhalisPants_Female = 158
        LeinforsPants = 159
        LeinforsPantsCoat = 160
        ShinobiInfiltratorBodyExtension = 161
        ForbiddenArmorBodyExtension = 162
        GladiatorBreastplateBodyExtension = 163
        BeeBreastplateBodyExtension = 164
        ReaperRobe = 165
        BrideOfFrankensteinDress = 166
        WitchDress = 167
        PrincessDress = 168
        GhostShirt = 169
        DTownBreastplateBodyExtension = 170
        RaincoatMaleBodyExtension = 171
        RaincoatFemaleBodyExtension = 172
        ObsidianLongcoatBodyExtension = 173
        ApprenticeDarkBodyExtension = 174
        TikiShirtBodyExtensionMale = 175
        TikiShirtBodyExtensionFemale = 176
        MaidBodyExtensionFemale = 177
        MaidBodyExtensionMale = 178
        MaidFemale = 179
        MaidMale = 180
        MaidAltBodyExtensionFemale = 181
        MaidAltBodyExtensionMale = 182
        MaidAltFemale = 183
        MaidAltMale = 184
        Golf = 185
        WitchDressBodyExtension = 186
        AmberRobe = 187
        GameMasterPants = 188
        StarPrincessDress = 189
        ChefPants = 190
        SuperHeroTightsMale = 191
        SuperHeroTightsFemale = 192
        PrettyPinkDressPantsMale = 193
        PrettyPinkDressPantsFemale = 194
        PrettyPinkDressSkirt = 195
        UndertakerCoat = 196
        FuneralPantsMale = 197
        FuneralPantsFemale = 198
        VictorianGothDressExtension = 199
        GhostarShirtExtensionFemale = 200
        GhostarShirtExtensionMale = 201
        GhostarLegsFemale = 202
        GhostarLegsMale = 203
        DrManFlyLabCoatLegs = 204
        ButcherPants = 205
        SafemanSunDressExtension = 206
        SafemanDressLeggingsFemale = 207
        SafemanDressLeggingsMale = 208
        FoodBarbarianGreaves = 209
        GroxTheGreatGreaves = 210
        MushroomPants = 211
        AncientHallowedGreaves = 212
        CrystalNinjaLeggings = 213
        GraduationGownBlueExtension = 214
        GraduationGownMaroonExtension = 215
        GraduationGownBlackExtension = 216
        MoonLordLegs = 217
        PlaguebringerGreaves = 218
        RoninPantsMale = 219
        RoninPantsFemale = 220
        RoninShirtExtension = 221
        TimelessTravelerBottom = 222
        TimelessTravelerRobeExtension = 223
        FloretProtectorLegs = 224
        CapricornLegs = 225
        CapricornTail = 226
        TVHeadPants = 227
        RoyalDressBottom = 228
        FlinxFurCoatExtension = 229
        PrincePants = 230
        WilsonPants = 231
        WillowSkirtMale = 232
        WillowSkirtFemale = 233
        AshWoodGreaves = 234
        LincolnsPants = 235
        DeadCellsBeheadedLegsMale = 236
        ChickenBonesLegs = 237
        ChickenBonesRobeExtension = 238
        ChickenBonesRobeExtensionBack = 239
        UpgradedMiningLegs = 240
        UpgradedFishingLegs = 241
        ChippysLegs = 242
        BlueBikiniLegs = 243
        RedSwimsuitExtension = 244
        GreenSwimshorts = 245
        GraySwimshorts = 246
        HeroicisLegs = 247
        DeadCellsBeheadedLegsFemale = 248
        LilacDuskLegsMale = 249
        LilacDuskLegsFemale = 250
        KazzymodusLeggings = 251
        PalworldPalMetalArmorLegs = 252
        LunasLegs = 253
        Count = 254

    class Neck(IntEnum):
        JellyfishNecklace = 1
        CrossNecklace = 2
        PanicNecklace = 3
        PygmyNecklace = 4
        StarVeil = 5
        SweetheartNecklace = 6
        SharkToothNecklace = 7
        WormScarf = 8
        ApprenticeScarf = 9
        Stinger = 10
        Magiluminescence = 11
        MoltenCharm = 12
        Count = 13

    class RocketBoots(IntEnum):
        NoneValue = 0
        SimpleRocketBoots = 1
        SpectreBoots = 2
        FrostsparkBoots = 3
        TerrasparkBoots = 4
        HellfireTreads = 5
        RedsLeggings = 6

    class Shield(IntEnum):
        CobaltShield = 1
        PaladinsShield = 2
        ObsidianShield = 3
        AnkhShield = 4
        ShieldofCthulhu = 5
        SquireShield = 6
        Frozen = 7
        Hero = 8
        BouncingShield = 9
        Count = 10

    class Shoe(IntEnum):
        Flipper = 1
        WaterWalkingBoots = 2
        Tabi = 3
        ShoeSpikes = 4
        TigerClimbingGear = 4
        FlurryBoots = 5
        HermesBoots = 6
        IceSkates = 7
        LavaWaders = 8
        FrostsparkBoots = 9
        LightningBoots = 10
        ObsidianWaterWalkingBoots = 11
        RocketBoots = 12
        SpectreBoots = 13
        MasterNinjaGear = 14
        FrogLeg = 15
        FlowerBoots = 16
        SailfishBoots = 17
        AmphibianBoots = 18
        FairyBoots = 19
        FrogFlipper = 20
        SandBoots = 21
        FlameWakerBoots = 22
        HellfireTreads = 23
        TerrasparkBoots = 24
        GlassSlipperMale = 25
        GlassSlipperFemale = 26
        RollerSkates = 27
        RollerSkatesGreen = 28
        RollerSkatesWhite = 29
        RollerSkatesPink = 30
        Count = 31

    class Waist(IntEnum):
        CloudinaBottle = 1
        CopperWatch = 2
        GoldWatch = 3
        PlatinumWatch = 4
        Toolbelt = 5
        ManaFlower = 6
        SilverWatch = 7
        TinWatch = 8
        TungstenWatch = 9
        BlackBelt = 10
        MasterNinjaGear = 10
        TsunamiinaBottle = 11
        MonkBelt = 12
        BlizzardinaBottle = 13
        FartinaJar = 14
        SandstorminaBottle = 15
        TreasureMagnet = 16
        Count = 17

    class Wing(IntEnum):
        DemonWings = 1
        AngelWings = 2
        RedsWings = 3
        Jetpack = 4
        ButterflyWings = 5
        FairyWings = 6
        HarpyWings = 7
        BoneWings = 8
        FlameWings = 9
        FrozenWings = 10
        SpectreWings = 11
        SteampunkWings = 12
        LeafWings = 13
        BatWings = 14
        BeeWings = 15
        DTownsWings = 16
        WillsWings = 17
        CrownosWings = 18
        CenxsWings = 19
        TatteredFairyWings = 20
        SpookyWings = 21
        Hoverboard = 22
        FestiveWings = 23
        BeetleWings = 24
        FinWings = 25
        FishronWings = 26
        MothronWings = 27
        LazuresBarrierPlatform = 28
        SolarWings = 29
        VortexBooster = 30
        NebulaMantle = 31
        StardustWings = 32
        Yoraiz0rsSpell = 33
        JimsWings = 34
        SkiphssPaws = 35
        LokisWings = 36
        BetsyWings = 37
        ArkhalisWings = 38
        LeinforsWings = 39
        GhostarsWings = 40
        SafemanWings = 41
        FoodBarbarianWings = 42
        GroxTheGreatWings = 43
        RainbowWings = 44
        LongTrailRainbowWings = 45
        CreativeWings = 46
        ChickenBonesWings = 47
        ChippysWings = 48
        HeroicisWings = 49
        KazzymodusWings = 50
        LunasWings = 51
        Count = 52


class ArmorIDsSets:
    class Back:
        factory = SetFactory(ArmorIDs.Back.Count)
        DrawInBackpackLayer = factory.create_bool_set(False, 7, 8, 9, 10, 15, 16, 32, 33)
        DrawInTailLayer = factory.create_bool_set(False, 18, 19, 21, 25, 26, 27, 28)
        IsACape = factory.create_bool_set(False, 1, 2, 3, 4, 5, 6, 14, 24, 34, 36, 39)

    class Balloon:
        factory = SetFactory(ArmorIDs.Balloon.Count)
        DrawInFrontOfBackArmLayer = factory.create_bool_set(False, 18)
        UsesTorsoFraming = factory.create_bool_set(False, 18)

    class Beard:
        factory = SetFactory(ArmorIDs.Beard.Count)
        UseHairColor = factory.create_bool_set(False, 2, 3, 4)

    class Body:
        factory = SetFactory(ArmorIDs.Body.Count)
        NeedsToDrawArm = factory.create_bool_set(False, 200, 202, 201, 203, 195, 205, 207, 206, 228, 242, 243, 255, 256)
        IncludedCapeBack = factory.create_int_set(-1, 207, 13, 206, 12, 205, 11, 185, 17, 96, 18, 94, 19, 80, 21, 217, 22, 24, 29, 238, 32)
        IncludedCapeBackFemale = factory.create_int_set(-1, 207, 13, 206, 12, 205, 11, 185, 17, 96, 18, 94, 19, 80, 21, 217, 23, 24, 29, 238, 32)
        IncludedCapeFront = factory.create_int_set(-1, 184, 6, 248, 13)
        UsesNewFramingCode = factory.create_bool_set(False, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261)
        HidesShouldersAsCoat = factory.create_bool_set(False, 251)
        showsShouldersWhileJumping = factory.create_bool_set(False, 177, 190, 95, 46, 73, 92, 24, 54, 55, 56, 65, 66, 67, 69, 70, 71, 75, 105, 106, 175, 176, 182, 183, 187, 194, 197, 198, 201, 204, 226, 227, 229, 239, 259)
        shouldersAreAlwaysInTheBack = factory.create_bool_set(False, 190)
        DisableHandOnAndOffAccDraw = factory.create_bool_set(False, 83)
        DisableBeltAccDraw = factory.create_bool_set(False, 83, 82)

    class Face:
        factory = SetFactory(ArmorIDs.Face.Count)
        PreventHairDraw = factory.create_bool_set(False, 2, 3, 4, 19)
        OverrideHelmet = factory.create_bool_set(False, 2, 3, 4, 19)
        DrawInFaceUnderHairLayer = factory.create_bool_set(False, 5)
        DrawInFaceMaskLayer = factory.create_bool_set(False, 22)
        DrawInFaceFlowerLayer = factory.create_bool_set(False, 1, 6, 9, 8)
        DrawInFaceHeadLayer = factory.create_bool_set(False, 12, 10, 13, 11)
        AltFaceHead = factory.create_int_set(-1, 12, 17, 10, 15, 13, 18, 11, 16)
        CanDrawOnVelociraptorMount = factory.create_bool_set(False, 1, 6, 9, 8, 19, 7, 20, 21, 23)

    class Front:
        factory = SetFactory(ArmorIDs.Front.Count)
        DrawsInNeckLayer = factory.create_bool_set(False, 6)
        DrawsInNeckLayerRegardlessOfPlayerFrame = factory.create_bool_set(False, 13)
        DontDrawIfWearingAScarfOrCape = factory.create_bool_set(False, 13)
        IsACape = factory.create_bool_set(False, 1, 2, 3, 4, 5, 8, 11, 12, 16)
        HidesCompositeShoulders = factory.create_bool_set(False, 8, 11, 15, 16)

    class HandOff:
        factory = SetFactory(ArmorIDs.HandOff.Count)
        UsesNewFramingCode = factory.create_bool_set(False, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15)

    class HandOn:
        factory = SetFactory(ArmorIDs.HandOn.Count)
        UsesNewFramingCode = factory.create_bool_set(False, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 16, 17, 18, 19, 20, 21, 22, 23, 24)
        UsesOldFramingTexturesForWalking = factory.create_bool_set(False, 12, 8, 17)

    class Head:
        factory = SetFactory(ArmorIDs.Head.Count)
        FrontToBackID = factory.create_int_set(-1, 242, 246, 243, 247, 244, 248, 245, 249, 133, 252, 224, 253)
        UseSkinColor = factory.create_bool_set(False, 274, 277)
        HidesHead = factory.create_bool_set(False, 38, 135, 269, 282, 288)
        PreventBeardDraw = factory.create_bool_set(False, 118, 119, 107, 129, 127, 125, 136, 162, 168, 210, 213, 28, 135, 31, 17, 261, 169, 186, 47, 22, 105, 102, 120, 137, 199, 207, 260, 132, 155, 179, 108, 153, 164, 172, 208, 241, 271, 48, 154, 188, 187, 209, 46, 123, 269, 185, 276)
        UseAltFaceHeadDraw = factory.create_bool_set(False, 3, 4, 6, 7, 9, 17, 22, 27, 28, 31, 32, 37, 38, 39, 40, 42, 43, 45, 46, 47, 48, 49, 50, 57, 58, 61, 66, 69, 70, 72, 74, 75, 76, 77, 78, 82, 83, 86, 89, 93, 98, 101, 103, 104, 105, 107, 108, 109, 110, 111, 115, 118, 120, 122, 123, 124, 127, 128, 129, 131, 132, 134, 135, 136, 137, 142, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 162, 164, 165, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 185, 186, 187, 188, 189, 192, 193, 194, 200, 201, 202, 204, 207, 208, 209, 210, 211, 213, 214, 230, 236, 237, 239, 240, 241, 251, 254, 255, 258, 260, 266, 268, 269, 270, 271, 261, 8, 12, 30, 35, 36, 73, 79, 80, 84, 85, 87, 88, 90, 91, 102, 112, 141, 160, 180, 196, 205, 257, 256, 291, 292)
        CanDrawOnVelociraptorMount = factory.create_bool_set(False, 212, 241, 274, 277, 5, 278, 34, 205, 41, 42, 30, 8, 84, 79, 33, 91, 90, 99, 35, 4, 256, 257, 36, 85, 80, 1, 112, 2, 215, 201, 202, 199, 194, 206, 262, 259, 234, 226, 238, 250, 280, 232, 225, 223, 224, 219, 220, 216, 263, 273, 264, 267, 18, 19, 24, 21, 26, 25, 16, 14, 12, 275, 65, 51, 56, 40, 29, 81, 94, 95, 62, 67, 44, 68, 121, 114, 116, 113, 92, 106, 100, 96, 97, 141, 143, 145, 139, 140, 144, 126, 130, 133, 159, 158, 161, 166, 183, 181, 178, 184, 182, 13, 64, 60, 59, 73, 63, 117, 138, 160, 10, 235, 197, 195, 203, 191, 228, 233, 227, 217, 218, 245, 243, 244, 242, 231, 229, 222, 265, 272, 279, 15, 163, 288, 289, 290)

    class Legs:
        factory = SetFactory(ArmorIDs.Legs.Count)
        IncompatibleWithFrogLeg = factory.create_bool_set(False, 106, 143, 217, 222, 226, 228, 138)
        TreatRobeExtensionLikeNormalLegsWhenSitting = factory.create_bool_set(False, 101, 102, 118, 99, 196)

    class Neck:
        factory = SetFactory(ArmorIDs.Neck.Count)
        IsAScarf = factory.create_bool_set(False, 8, 9)

    class Shoe:
        factory = SetFactory(ArmorIDs.Shoe.Count)
        MaleToFemaleID = factory.create_int_set(-1, 25, 26)
        IsARollerSkate = factory.create_bool_set(False, 27, 28, 29, 30)

    class Waist:
        factory = SetFactory(ArmorIDs.Waist.Count)
        UsesTorsoFraming = factory.create_bool_set(False, 5, 10, 10, 12)
        IsABelt = factory.create_bool_set(False, 5, 10, 10, 12)

    class Wing:
        factory = SetFactory(ArmorIDs.Wing.Count)
        AlwaysAnimated = factory.create_bool_set(False, 22, 28, 45, 34, 48, 39, 40, 44)
