"""
GameVersionID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class GameVersionID(IntEnum):
    WorldManifest = 299
    DisplayDollPose = 307
    DisplayDollHeldItem = 308
    OneTimeDialogue = 310
    DisplayDollMount = 311
    DisplayDollMountDye = 312
    WorldManifestV2 = 313
    HostToken = 314
    NPCHomelessDespawn = 315
    Terraria1453Release = 316
    Latest = 317
    Terraria1454Release = 317

