"""
GoreID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from terrex.id.set_factory import SetFactory
from enum import IntEnum, auto


class GoreID(IntEnum):
    Cloud1 = 11
    Cloud2 = 12
    Cloud3 = 13
    FireImpHead = 45
    FireImpArm = 46
    FireImpLeg = 47
    PotLightBrown1 = 51
    PotLightBrown2 = 52
    PotLightBrown3 = 53
    Smoke1 = 61
    Smoke2 = 62
    Smoke3 = 63
    HornetHead = 70
    HornetBody = 71
    PotDarkBrown1 = 166
    PotDarkBrown2 = 167
    PotDarkBrown3 = 168
    PotOrnate1 = 169
    PotOrnate2 = 170
    PotOrnate3 = 171
    PotOrnateBrown1 = 172
    PotOrnateBrown2 = 173
    PotOrnateBrown3 = 174
    PotIcy1 = 197
    PotIcy2 = 198
    PotJungle1 = 199
    PotJungle2 = 200
    PotSkull1 = 201
    PotSkull2 = 202
    PotObsidian1 = 203
    PotObsidian2 = 204
    PotPyramid1 = 217
    PotPyramid2 = 218
    PotPyramid3 = 219
    MossHornetHead = 229
    MossHornetBody = 230
    PotTemple1 = 315
    PotTemple2 = 316
    FartCloud1 = 435
    FartCloud2 = 436
    FartCloud3 = 437
    ChargedBlasterRing = 618
    MoonLordHeart1 = 619
    MoonLordHeart2 = 620
    MoonLordHeart3 = 621
    MoonLordHeart4 = 622
    GoblinArcherHead = 623
    GoblinArcherHand = 624
    GoblinArcherLeg = 625
    GoblinPeonHead = 626
    GoblinPeonHand = 627
    GoblinPeonLeg = 628
    GoblinScoutHead = 629
    GoblinScoutHand = 630
    GoblinScoutLeg = 631
    GoblinThiefHead = 632
    GoblinThiefHand = 633
    GoblinThiefLeg = 634
    GoblinWarriorHead = 635
    GoblinWarriorHand = 636
    GoblinWarriorLeg = 637
    SkeletonMerchantHead = 638
    SkeletonMerchantBag = 639
    SkeletonMerchantChunk1 = 640
    SkeletonMerchantChunk2 = 641
    SkeletonMerchantChunk3 = 642
    ButcherHead = 643
    ButcherSaw = 644
    ButcherArm = 645
    ButcherLeg = 646
    CreatureFromTheDeepHead = 647
    CreatureFromTheDeepArm = 648
    CreatureFromTheDeepLeg = 649
    FritzHead = 650
    FritzArm = 651
    FritzLeg = 652
    NailheadHead = 653
    NailheadArm = 654
    NailheadLeg = 655
    PsychoHead = 656
    PsychoArm = 657
    PsychoLeg = 658
    PsychoKnife = 659
    DeadlySphere1 = 660
    DeadlySphere2 = 661
    DrManFlyHead = 662
    DrManFlyArm = 663
    DrManFlyLeg = 664
    ThePossessedHead = 665
    ThePossessedArm = 666
    ThePossessedLeg = 667
    CrimsonBunnyHead = 668
    CrimsonBunnyLeg = 669
    CrimsonGoldfishHead = 670
    CrimsonGoldfishTail = 671
    CrimsonPenguinBody = 672
    CrimsonPenguinHead = 673
    CrimsonPenguinLeg = 674
    GoblinSummonerHead = 675
    GoblinSummonerArm = 676
    GoblinSummonerItem = 677
    GoblinSummonerLeg = 678
    ShadowflameApparation = 679
    ShadowflameApparation2 = 680
    MothronSpawn1 = 681
    MothronSpawn2 = 682
    MothronSpawn3 = 683
    MothronEgg1 = 684
    MothronEgg2 = 685
    MothronEgg3 = 686
    Mothron1 = 687
    Mothron2 = 688
    Mothron3 = 689
    Mothron4 = 690
    Mothron5 = 691
    MedusaHead = 692
    MedusaArm = 693
    MedusaLeg = 694
    GreekSkeletonHead = 695
    GreekSkeletonArm = 696
    GreekSkeletonLeg = 697
    GreekPot1 = 698
    GreekPot2 = 699
    GreekPot3 = 700
    GreekPot4 = 701
    GreekPot5 = 702
    GreekPot6 = 703
    ToxicFlask = 704
    ToxicFlask2 = 705
    WaterDrip = 706
    WaterDripCorrupt = 707
    WaterDripJungle = 708
    WaterDripHallow = 709
    WaterDripIce = 710
    WaterDripDesert = 711
    WaterDripUnderground = 712
    WaterDripCavern = 713
    WaterDripBlood = 714
    WaterDripCrimson = 715
    LavaDrip = 716
    HoneyDrip = 717
    GraniteGolemHead = 718
    GraniteGolemBody = 719
    GraniteGolemArm = 720
    GraniteGolemLeg = 721
    BloodZombieHead = 722
    BloodZombieChunk = 723
    BloodZombieChunk2 = 724
    DripplerChunk = 725
    DripplerChunk2 = 726
    DripplerChunk3 = 727
    LunarTablet1 = 728
    LunarTablet2 = 729
    LunarTablet3 = 730
    LunarTablet4 = 731
    LunarTablet5 = 732
    LunarTablet6 = 733
    KingSlimeCrown = 734
    CrawDadClaw = 735
    CrawDadEye = 736
    CrawDad2Claw = 737
    CrawDad2Eye = 738
    GiantShelly = 739
    GiantShelly2 = 740
    SalamanderArm = 741
    SalamanderHead = 750
    SalamanderLeg = 759
    TaxCollectorHead = 768
    TaxCollectorArm = 769
    TaxCollectorCane = 770
    TaxCollectorLeg = 771
    StardustSoldier1 = 772
    StardustSoldier2 = 773
    StardustSoldier3 = 774
    StardustSpider1 = 775
    StardustSpider2 = 776
    StardustSpider3 = 777
    StardustJellyfish1 = 778
    StardustJellyfish2 = 779
    StardustJellyfish3 = 780
    StardustJellyfish4 = 781
    NebulaBrain1 = 782
    NebulaBrain2 = 783
    NebulaBrain3 = 784
    NebulaHeadcrab1 = 785
    NebulaHeadcrab2 = 786
    NebulaHeadcrab3 = 787
    NebulaEye1 = 788
    NebulaEye2 = 789
    NebulaBeast1 = 790
    NebulaBeast2 = 791
    NebulaBeast3 = 792
    NebulaSoldier1 = 793
    NebulaSoldier2 = 794
    NebulaSoldier3 = 795
    VortexRifleman1 = 796
    VortexRifleman2 = 797
    VortexRifleman3 = 798
    VortexHornetQueen1 = 799
    VortexHornetQueen2 = 800
    VortexHornetQueen3 = 801
    VortexHornet1 = 802
    VortexHornet2 = 803
    VortexHornet3 = 804
    VortexHornet4 = 805
    VortexLarva1 = 806
    VortexLarve2 = 807
    VortexSoldier1 = 808
    VortexSoldier2 = 809
    VortexSoldier3 = 810
    GiantWalkingAntlion1 = 811
    GiantWalkingAntlion2 = 812
    GiantWalkingAntlion3 = 813
    GiantWalkingAntlion4 = 814
    GiantFlyingAntlion1 = 815
    GiantFlyingAntlion2 = 816
    GiantFlyingAntlion3 = 817
    GiantFlyingAntlion4 = 818
    DuneSplicerHead = 819
    DuneSplicerBody = 820
    DuneSplicerTail = 821
    TombCrawlerHead = 822
    TombCrawlerBody = 823
    TombCrawlerTail = 824
    ChimneySmoke1 = 825
    ChimneySmoke2 = 826
    ChimneySmoke3 = 827
    SolarWormHead = 828
    SolarWormBody = 829
    SolarWormTail = 830
    SolarBeast1 = 831
    SolarBeast2 = 832
    SolarBeast3 = 833
    SolarBeast4 = 834
    SolarSpearman1 = 835
    SolarSpearman2 = 836
    SolarRoller1 = 837
    SolarRoller2 = 838
    SolarRoller3 = 839
    SolarRoller4 = 840
    SolarMeteor1 = 841
    SolarMeteor2 = 842
    SolarMeteor3 = 843
    SolarSoldier1 = 844
    SolarSoldier2 = 845
    SolarSoldier3 = 846
    SolarSoldier4 = 847
    MartianWalker1 = 848
    MartianWalker2 = 849
    MartianWalker3 = 850
    MartianWalker4 = 851
    MartianWalker5 = 852
    PirateShip1 = 853
    PirateShip2 = 854
    PirateShip3 = 855
    PirateShip4 = 856
    PirateShip5 = 857
    PirateShip6 = 858
    PirateShip7 = 859
    PirateShip8 = 860
    PirateShip9 = 861
    PirateShip10 = 862
    DesertGhoul1 = 863
    DesertGhoul2 = 864
    DesertGhoul3 = 865
    DesertGhoul4 = 866
    DesertGhoulCorruption1 = 867
    DesertGhoulCorruption2 = 868
    DesertGhoulCorruption3 = 869
    DesertGhoulCorruption4 = 870
    DesertGhoulCrimson1 = 871
    DesertGhoulCrimson2 = 872
    DesertGhoulCrimson3 = 873
    DesertGhoulCrimson4 = 874
    DesertLamia1 = 875
    DesertLamia2 = 876
    DesertLamia3 = 877
    DesertLamia4 = 878
    DesertGhoulHallow1 = 879
    DesertGhoulHallow2 = 880
    DesertGhoulHallow3 = 881
    DesertGhoulHallow4 = 882
    DesertScorpion1 = 883
    DesertScorpion2 = 884
    DesertScorpion3 = 885
    DesertScorpion4 = 886
    DesertScorpion5 = 887
    DesertBeast1 = 888
    DesertBeast2 = 889
    DesertBeast3 = 890
    DesertBeast4 = 891
    PirateShip11 = 892
    PirateShip12 = 893
    DemonTaxCollectorHead = 894
    DemonTaxCollectorArm = 895
    DemonTaxCollectorLeg = 896
    SquirrelRed = 897
    MartianProbe1 = 898
    MartianProbe2 = 899
    Cultist1 = 900
    Cultist2 = 901
    CultistBoss1 = 902
    CultistBoss2 = 903
    GigaZapperHead = 904
    GigaZapperHand = 905
    GigaZapperLeg = 906
    SillyBallonPink = 907
    SillyBalloonPurple = 908
    SillyBalloonGreen = 909
    TreeLeaf_Normal = 910
    TreeLeaf_Palm = 911
    TreeLeaf_Mushroom = 912
    TreeLeaf_Boreal = 913
    TreeLeaf_Jungle = 914
    TreeLeaf_Corruption = 915
    TreeLeaf_Crimson = 916
    TreeLeaf_Hallow = 917
    TreeLeaf_HallowLast = 925
    PartyHatBlue = 926
    PartyHatDemolitionist = 927
    PartyHatDyeTrader = 928
    PartyHatMerchant = 929
    PartyHatNurse = 930
    PartyHatPainter = 931
    PartyHatPirate = 932
    PartyHatSanta = 933
    PartyHatSkeletonMerchant = 934
    PartyHatSteampunker = 935
    PartyHatStylist = 936
    PartyHatTravellingMerchant = 937
    PartyHatWizard = 938
    PartyHatPink = 939
    PartyHatCyan = 940
    PartyHatPurple = 941
    PartyHatWhite = 942
    SandDrip = 943
    Sandshark1 = 944
    Sandshark2 = 945
    Sandshark3 = 946
    Sandshark4 = 947
    Sandshark1Corrupt = 948
    Sandshark2Corrupt = 949
    Sandshark3Corrupt = 950
    Sandshark4Corrupt = 951
    Sandshark1Crimson = 952
    Sandshark2Crimson = 953
    Sandshark3Crimson = 954
    Sandshark4Crimson = 955
    Sandshark1Hallowed = 956
    Sandshark2Hallowed = 957
    Sandshark3Hallowed = 958
    Sandshark4Hallowed = 959
    SandElemental1 = 960
    SandElemental2 = 961
    SandElemental3 = 962
    SandElemental4 = 963
    Tumbleweed1 = 964
    Tumbleweed2 = 965
    Tumbleweed3 = 966
    Bartender1 = 967
    Bartender2 = 968
    Bartender3 = 969
    DD2Skeleton1 = 970
    DD2Skeleton2 = 971
    DD2Skeleton3 = 972
    DD2Skeleton4 = 973
    DD2WyvernT1_1 = 974
    DD2WyvernT1_2 = 975
    DD2WyvernT1_3 = 976
    DD2WyvernT1_4 = 977
    DD2WyvernT1_5 = 978
    DD2DrakinT3_1 = 979
    DD2DrakinT3_2 = 980
    DD2DrakinT3_3 = 981
    DD2DrakinT3_4 = 982
    DD2GoblinT1_1 = 983
    DD2GoblinT1_2 = 984
    DD2GoblinT1_3 = 985
    DD2GoblinT1_4 = 986
    DD2JavelinThrowerT1_1 = 987
    DD2JavelinThrowerT1_2 = 988
    DD2JavelinThrowerT1_3 = 989
    DD2JavelinThrowerT1_4 = 990
    DD2JavelinThrowerT1_5 = 991
    DD2JavelinThrowerT1_6 = 992
    DD2Kobold1 = 993
    DD2Kobold2 = 994
    DD2Kobold3 = 995
    DD2Kobold4 = 996
    LightningBugT3_1 = 997
    LightningBugT3_2 = 998
    LightningBugT3_3 = 999
    DD2Ogre1 = 1000
    DD2Ogre2 = 1001
    DD2Ogre3 = 1002
    DD2Ogre4 = 1003
    DD2Ogre5 = 1004
    DD2Ogre6 = 1005
    DD2Ogre6Alt = 1006
    Pages = 1007
    PageScrap = 1008
    DD2DarkMageT1_1 = 1009
    DD2DarkMageT1_2 = 1010
    DD2DarkMageT1_3 = 1011
    DD2DarkMageT1_4 = 1012
    DD2DarkMageT1_5 = 1013
    DD2DarkMageT1_6 = 1014
    DD2DarkMageT1_7 = 1015
    DD2DarkMageT1_8 = 1016
    DD2DarkMageT1_9 = 1017
    DD2DarkMageT1_10 = 1018
    DD2DarkMageT1_11 = 1019
    DD2WitherBeast1 = 1020
    DD2WitherBeast2 = 1021
    DD2WitherBeast3 = 1022
    DD2WitherBeast4 = 1023
    OgreSpit1 = 1024
    OgreSpit2 = 1025
    OgreSpit3 = 1026
    DD2Crystal1 = 1027
    DD2Crystal2 = 1028
    DD2Crystal3 = 1029
    DD2Crystal4 = 1030
    DD2GoblinBomberT1_1 = 1031
    DD2GoblinBomberT1_2 = 1032
    DD2GoblinBomberT1_3 = 1033
    DD2GoblinBomberT2_1 = 1034
    DD2GoblinBomberT2_2 = 1035
    DD2GoblinBomberT2_3 = 1036
    DD2GoblinBomberT3_1 = 1037
    DD2GoblinBomberT3_2 = 1038
    DD2GoblinBomberT3_3 = 1039
    DD2WyvernT2_1 = 1040
    DD2WyvernT2_2 = 1041
    DD2WyvernT2_3 = 1042
    DD2WyvernT2_4 = 1043
    DD2WyvernT2_5 = 1044
    DD2WyvernT3_1 = 1045
    DD2WyvernT3_2 = 1046
    DD2WyvernT3_3 = 1047
    DD2WyvernT3_4 = 1048
    DD2WyvernT3_5 = 1049
    DD2KoboldFlyerT2_1 = 1050
    DD2KoboldFlyerT2_2 = 1051
    DD2KoboldFlyerT2_3 = 1052
    DD2KoboldFlyerT2_4 = 1053
    DD2KoboldFlyerT2_5 = 1054
    DD2JavelinThrowerT2_1 = 1055
    DD2JavelinThrowerT2_2 = 1056
    DD2JavelinThrowerT2_3 = 1057
    DD2JavelinThrowerT2_4 = 1058
    DD2JavelinThrowerT2_5 = 1059
    DD2JavelinThrowerT2_6 = 1060
    DD2JavelinThrowerT3_1 = 1061
    DD2JavelinThrowerT3_2 = 1062
    DD2JavelinThrowerT3_3 = 1063
    DD2JavelinThrowerT3_4 = 1064
    DD2JavelinThrowerT3_5 = 1065
    DD2JavelinThrowerT3_6 = 1066
    DD2GoblinT2_1 = 1067
    DD2GoblinT2_2 = 1068
    DD2GoblinT2_3 = 1069
    DD2GoblinT2_4 = 1070
    DD2GoblinT3_1 = 1071
    DD2GoblinT3_2 = 1072
    DD2GoblinT3_3 = 1073
    DD2GoblinT3_4 = 1074
    DD2DrakinT2_1 = 1075
    DD2DrakinT2_2 = 1076
    DD2DrakinT2_3 = 1077
    DD2DrakinT2_4 = 1078
    DD2BetsyTail = 1079
    DD2BetsyFoot = 1080
    DD2BetsyHead = 1081
    DD2BetsyBody = 1082
    DD2BetsyWing1 = 1083
    DD2BetsyWing2 = 1084
    DD2BetsyHand = 1085
    DD2BetsyButt = 1086
    AmbientFloorCloud1 = 1087
    AmbientFloorCloud2 = 1088
    AmbientFloorCloud3 = 1089
    AmbientFloorCloud4 = 1090
    AmbientAirborneCloud1 = 1091
    AmbientAirborneCloud2 = 1092
    AmbientAirborneCloud3 = 1093
    WalkingAntlion1 = 1094
    WalkingAntlion2 = 1095
    WalkingAntlion3 = 1096
    WalkingAntlion4 = 1097
    FlyingAntlion1 = 1098
    FlyingAntlion2 = 1099
    FlyingAntlion3 = 1100
    FlyingAntlion4 = 1101
    LarvaeAntlion1 = 1102
    LarvaeAntlion2 = 1103
    EyeballFlyingFish1 = 1104
    EyeballFlyingFish2 = 1105
    ZombieMerman1 = 1106
    ZombieMerman2 = 1107
    ZombieMerman3 = 1108
    Golfer1 = 1109
    Golfer2 = 1110
    Golfer3 = 1111
    Golfer4 = 1112
    TreeLeaf_HallowJim = 1113
    TreeLeaf_HallowLastJim = 1121
    DesertPot1 = 1122
    DesertPot2 = 1123
    DesertPot3 = 1124
    Balloon_White_1 = 1125
    Balloon_White_2 = 1126
    Balloon_White_3 = 1127
    Balloon_Red_1 = 1128
    Balloon_Red_2 = 1129
    Balloon_Red_3 = 1130
    Balloon_Orange_1 = 1131
    Balloon_Orange_2 = 1132
    Balloon_Orange_3 = 1133
    Balloon_Yellow_1 = 1134
    Balloon_Yellow_2 = 1135
    Balloon_Yellow_3 = 1136
    Balloon_Green_1 = 1137
    Balloon_Green_2 = 1138
    Balloon_Green_3 = 1139
    Balloon_Blue_1 = 1140
    Balloon_Blue_2 = 1141
    Balloon_Blue_3 = 1142
    Balloon_Purple_1 = 1143
    Balloon_Purple_2 = 1144
    Balloon_Purple_3 = 1145
    Balloon_String = 1146
    WaterDripDesert2 = 1147
    Ladybug1 = 1148
    Ladybug2 = 1149
    Seagull1 = 1150
    Seagull2 = 1151
    Pupfish1 = 1152
    Pupfish2 = 1153
    Grebe1 = 1154
    Grebe2 = 1155
    Grebe3 = 1156
    Rat1 = 1157
    Rat2 = 1158
    Rat3 = 1159
    EbonsandDrip = 1160
    CrimsandDrip = 1161
    PearlsandDrip = 1162
    LittleRat1 = 1163
    Owl1 = 1164
    Owl2 = 1165
    Turtle1 = 1166
    Turtle2 = 1167
    Turtle3 = 1168
    TurtleJungle1 = 1169
    TurtleJungle2 = 1170
    TurtleJungle3 = 1171
    BloodNautilus1 = 1172
    BloodNautilus2 = 1173
    BloodNautilus3 = 1174
    BloodNautilus4 = 1175
    BloodNautilus5 = 1176
    BloodNautilus6 = 1177
    BloodNautilus7 = 1178
    BloodSquid1 = 1179
    BloodSquid2 = 1180
    BloodSquid3 = 1181
    BloodSquid4 = 1182
    GoblinShark1 = 1183
    GoblinShark2 = 1184
    GoblinShark3 = 1185
    GoblinShark4 = 1186
    BloodEel1 = 1187
    BloodEel2 = 1188
    BloodEel3 = 1189
    Gnome1 = 1190
    Gnome2 = 1191
    Gnome3 = 1192
    Gnome4 = 1193
    SeaTurtle1 = 1194
    SeaTurtle2 = 1195
    SeaTurtle3 = 1196
    Seahorse1 = 1197
    Dolphin1 = 1198
    Dolphin2 = 1199
    Dolphin3 = 1200
    ChumBucket = 1201
    FogMachineCloud1 = 1202
    FogMachineCloud2 = 1203
    FogMachineCloud3 = 1204
    Dandelion1 = 1205
    Dandelion2 = 1206
    Dandelion3 = 1207
    ChumBucketFloatingChunks = 1208
    SparkleGuitar = 1209
    RockGolem1 = 1210
    RockGolem2 = 1211
    RockGolem3 = 1212
    RockGolem4 = 1213
    MaggotZombie1 = 1214
    MaggotZombie2 = 1215
    MaggotZombie3 = 1216
    MaggotZombieMaggotPieces = 1217
    ShadowMimicCoins = 1218
    BestiaryGirl1 = 1219
    BestiaryGirl2 = 1220
    BestiaryGirl3 = 1221
    BestiaryGirl4 = 1222
    BestiaryGirlFox1 = 1223
    BestiaryGirlFox2 = 1224
    LightningBunnySparks = 1225
    KingSlimePetCrown = 1226
    GemSquirrelAmethyst = 1227
    GemSquirrelTopaz = 1228
    GemSquirrelSapphire = 1229
    GemSquirrelEmerald = 1230
    GemSquirrelRuby = 1231
    GemSquirrelDiamond = 1232
    GemSquirrelAmber = 1233
    GemBunnyAmethystHead = 1234
    GemBunnyAmethystBack = 1235
    GemBunnyTopazHead = 1236
    GemBunnyTopazBack = 1237
    GemBunnySapphireHead = 1238
    GemBunnySapphireBack = 1239
    GemBunnyEmeraldHead = 1240
    GemBunnyEmeraldBack = 1241
    GemBunnyRubyHead = 1242
    GemBunnyRubyBack = 1243
    GemBunnyDiamondHead = 1244
    GemBunnyDiamondBack = 1245
    GemBunnyAmberHead = 1246
    GemBunnyAmberBack = 1247
    TreeLeaf_VanityTreeSakura = 1248
    TreeLeaf_GemTreeTopaz = 1249
    TreeLeaf_GemTreeAmethyst = 1250
    TreeLeaf_GemTreeSapphire = 1251
    TreeLeaf_GemTreeEmerald = 1252
    TreeLeaf_GemTreeRuby = 1253
    TreeLeaf_GemTreeDiamond = 1254
    TreeLeaf_GemTreeAmber = 1255
    MagmaSnailShell = 1256
    TreeLeaf_VanityTreeYellowWillow = 1257
    QueenSlimeCrown = 1258
    QueenSlimeWing = 1259
    QueenSlimeMinionPurpleWing = 1260
    QueenSlimePetCrown = 1261
    HallowBoss1 = 1262
    HallowBoss2 = 1263
    HallowBoss3 = 1264
    HallowBoss4 = 1265
    HallowBoss5 = 1266
    HallowBoss6 = 1267
    HallowBoss7 = 1268
    PlanteroSombrero = 1269
    DeerclopsHead = 1270
    DeerclopsAntler = 1271
    DeerclopsBody = 1272
    DeerclopsArm = 1273
    DeerclopsLeg = 1274
    Stinkbug1 = 1275
    Stinkbug2 = 1276
    ScarletMacaw1 = 1277
    TreeLeaf_TreeAsh = 1278
    ScarletMacaw2 = 1279
    BlueMacaw1 = 1280
    BlueMacaw2 = 1281
    Toucan1 = 1282
    Toucan2 = 1283
    YellowCockatiel1 = 1284
    YellowCockatiel2 = 1285
    GrayCockatiel1 = 1286
    GrayCockatiel2 = 1287
    ArmsDealerShimmeredHead = 1288
    ArmsDealerShimmeredArm = 1289
    ArmsDealerShimmeredLeg = 1290
    ClothierShimmeredHead = 1291
    ClothierShimmeredArm = 1292
    ClothierShimmeredLeg = 1293
    CyborgShimmeredHead = 1294
    CyborgShimmeredArm = 1295
    CyborgShimmeredLeg = 1296
    DemolitionistShimmeredHead = 1297
    DemolitionistShimmeredHeadParty = 1298
    DemolitionistShimmeredArm = 1299
    DemolitionistShimmeredLeg = 1300
    DryadShimmeredHead = 1301
    DryadShimmeredArm = 1302
    DryadShimmeredLeg = 1303
    DyeTraderShimmeredHead = 1304
    DyeTraderShimmeredHeadParty = 1305
    DyeTraderShimmeredArm = 1306
    DyeTraderShimmeredLeg = 1307
    GoblinTinkererShimmeredHead = 1308
    GoblinTinkererShimmeredArm = 1309
    GoblinTinkererShimmeredLeg = 1310
    GolferShimmeredHead = 1311
    GolferShimmeredArm = 1312
    GolferShimmeredLeg = 1313
    GuideShimmeredHead = 1314
    GuideShimmeredArm = 1315
    GuideShimmeredLeg = 1316
    MechanicShimmeredHead = 1317
    MechanicShimmeredArm = 1318
    MechanicShimmeredLeg = 1319
    MerchantShimmeredHead = 1320
    MerchantShimmeredHeadParty = 1321
    MerchantShimmeredArm = 1322
    MerchantShimmeredLeg = 1323
    NurseShimmeredHead = 1324
    NurseShimmeredHeadParty = 1325
    NurseShimmeredArm = 1326
    NurseShimmeredLeg = 1327
    OldManShimmeredHead = 1328
    OldManShimmeredArm = 1329
    OldManShimmeredLeg = 1330
    PainterShimmeredHead = 1331
    PainterShimmeredLeg = 1332
    PainterShimmeredPaintcan = 1333
    PainterShimmeredPaintbrush = 1334
    PartyGirlShimmeredHead = 1335
    PartyGirlShimmeredArm = 1336
    PartyGirlShimmeredLeg = 1337
    SantaClausShimmeredHead = 1338
    SantaClausShimmeredHeadParty = 1339
    SantaClausShimmeredArm = 1340
    SantaClausShimmeredLeg = 1341
    SkeletonMerchantShimmeredHead = 1342
    SkeletonMerchantShimmeredHeadParty = 1343
    SkeletonMerchantShimmeredArm = 1344
    SkeletonMerchantShimmeredLeg = 1345
    SkeletonMerchantShimmeredBag = 1346
    SkeletonMerchantShimmeredScrap = 1347
    SteampunkerShimmeredHead = 1348
    SteampunkerShimmeredArm = 1349
    SteampunkerShimmeredLegs = 1350
    StylistShimmeredHead = 1351
    StylistShimmeredHair = 1352
    StylistShimmeredArm = 1353
    StylistShimmeredLeg = 1354
    TavernkeepShimmeredHead = 1355
    TavernkeepShimmeredArm = 1356
    TavernkeepShimmeredLeg = 1357
    TaxCollectorShimmeredHead = 1358
    TaxCollectorShimmeredArm = 1359
    TaxCollectorShimmeredLeg = 1360
    TaxCollectorShimmeredCane = 1361
    TravelingMerchantShimmeredHead = 1362
    TravelingMerchantShimmeredHeadParty = 1363
    TravelingMerchantShimmeredArm = 1364
    TravelingMerchantShimmeredLeg = 1365
    TruffleShimmeredHead = 1366
    TruffleShimmeredArm = 1367
    TruffleShimmeredLeg = 1368
    WitchDoctorShimmeredHead = 1369
    WitchDoctorShimmeredArm = 1370
    WitchDoctorShimmeredLeg = 1371
    WitchDoctorShimmeredSpear = 1372
    WizardShimmeredHat = 1373
    WizardShimmeredClothScrap1 = 1374
    WizardShimmeredClothScrap2 = 1375
    WizardShimmeredClothScrap3 = 1376
    BestiaryGirlShimmeredHead = 1377
    BestiaryGirlShimmeredHeadTransformed = 1378
    BestiaryGirlShimmeredArm = 1379
    BestiaryGirlShimmeredArmTransformed = 1380
    BestiaryGirlShimmeredLeg = 1381
    BestiaryGirlShimmeredTail = 1382
    ShimmerDrip = 1383
    HornetHeadHoney = 1384
    HornetHeadSpikey = 1385
    PufferfishSmallHead = 1386
    PufferfishSmallTail = 1387
    PufferfishBigChunk1 = 1388
    PufferfishBigChunk2 = 1389
    PufferfishBigTail = 1390
    MossZombieHead = 1391
    MossZombieChunk1 = 1392
    MossZombieChunk2 = 1393
    PrettyMirror1 = 1394
    PrettyMirror2 = 1395
    PrettyMirror3 = 1396
    PrettyMirror4 = 1397
    RedHatSkeletronHead1 = 1398
    RedHatSkeletronHead2 = 1399
    RedHatSkeletronHead3 = 1400
    RedHatSkeletronHand1 = 1401
    RedHatSkeletronHand2 = 1402
    OrcaHead = 1403
    OrcaTail = 1404
    OrcaChunk1 = 1405
    OrcaChunk2 = 1406
    Count = 1407


class GoreIDSets:
    class Main:
        factory = SetFactory(GoreID.Count)
        SpecialAI = factory.create_int_set(0, 860, 1, 892, 1, 893, 1, 825, 2, 826, 2, 827, 2, 1014, 1, 1015, 1, 1016, 1, 910, 3, 911, 3, 912, 3, 913, 3, 914, 3, 915, 3, 916, 3, 917, 3, 918, 3, 919, 3, 920, 3, 921, 3, 922, 3, 923, 3, 924, 3, 925, 3, 1113, 3, 1114, 3, 1115, 3, 1116, 3, 1117, 3, 1118, 3, 1119, 3, 1120, 3, 1121, 3, 1248, 3, 1249, 3, 1250, 3, 1251, 3, 1252, 3, 1253, 3, 1254, 3, 1255, 3, 1257, 3, 1278, 3, 1007, 3, 1008, 3, 1087, 4, 1088, 4, 1089, 4, 1090, 4, 1091, 5, 1092, 5, 1093, 5, 1202, 6, 1203, 6, 1204, 6, 1225, 7)
        DisappearSpeed = factory.create_int_set(1, 1007, 3, 1008, 10, 1024, 7, 1025, 7, 1026, 7)
        DisappearSpeedAlpha = factory.create_int_set(1, 1007, 3, 1008, 10, 1024, 7, 1025, 7, 1026, 7, 1218, 3)
        IsDrip = factory.create_bool_set(False, 706, 714, 713, 707, 715, 711, 1147, 709, 710, 708, 712, 716, 717, 943, 1160, 1161, 1162, 1383)
