"""
ProjectileSourceID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class ProjectileSourceID(IntEnum):
    NoneValue = 0
    SetBonus_SolarExplosion_WhenTakingDamage = 1
    SetBonus_SolarExplosion_WhenDashing = 2
    SetBonus_ForbiddenStorm = 3
    SetBonus_Titanium = 4
    SetBonus_Orichalcum = 5
    SetBonus_Chlorophyte = 6
    SetBonus_Stardust = 7
    WeaponEnchantment_Confetti = 8
    PlayerDeath_TombStone = 9
    TorchGod = 10
    FallingStar = 11
    PlayerHurt_DropFootball = 12
    SetBonus_GhostHeal = 15
    SetBonus_GhostHurt = 16
    VampireKnives = 18
    BoulderRain = 19
    MeteorRain = 20
    MeteorShower = 21
    StormLightning = 22

