"""
MountID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 07:03 UTC
"""

from terrex.id.set_factory import SetFactory
from enum import IntEnum, auto


class MountID(IntEnum):
    NoneValue = -1
    Rudolph = 0
    Bunny = 1
    Pigron = 2
    Slime = 3
    Turtle = 4
    Bee = 5
    Minecart = 6
    UFO = 7
    Drill = 8
    Scutlix = 9
    Unicorn = 10
    MinecartMech = 11
    CuteFishron = 12
    MinecartWood = 13
    Basilisk = 14
    DesertMinecart = 15
    FishMinecart = 16
    GolfCartSomebodySaveMe = 17
    BeeMinecart = 18
    LadybugMinecart = 19
    PigronMinecart = 20
    SunflowerMinecart = 21
    HellMinecart = 22
    WitchBroom = 23
    ShroomMinecart = 24
    AmethystMinecart = 25
    TopazMinecart = 26
    SapphireMinecart = 27
    EmeraldMinecart = 28
    RubyMinecart = 29
    DiamondMinecart = 30
    AmberMinecart = 31
    BeetleMinecart = 32
    MeowmereMinecart = 33
    PartyMinecart = 34
    PirateMinecart = 35
    SteampunkMinecart = 36
    Flamingo = 37
    CoffinMinecart = 38
    DiggingMoleMinecart = 39
    PaintedHorse = 40
    MajesticHorse = 41
    DarkHorse = 42
    PogoStick = 43
    PirateShip = 44
    SpookyWood = 45
    Santank = 46
    WallOfFleshGoat = 47
    DarkMageBook = 48
    LavaShark = 49
    QueenSlime = 50
    FartMinecart = 51
    Wolf = 52
    TerraFartMinecart = 53
    Velociraptor = 54
    Rat = 55
    Bat = 56
    RollerSkates = 57
    RollerSkatesGreen = 58
    RollerSkatesWhite = 59
    RollerSkatesPink = 60
    Pixie = 61
    Chillet = 62
    ChilletIgnis = 63
    Count = 64


class MountIDSets:
    class Main:
        factory = SetFactory(MountID.Count)
        CanUseHooks = factory.create_bool_set(False, 54, 57, 58, 59, 60)
        CanDash = factory.create_bool_set(False, 56, 57, 58, 59, 60, 61, 62, 63)
        DoesNotOverrideBodyFrames = factory.create_bool_set(False, 57, 58, 59, 60)
        DoesNotOverrideLegFrames = factory.create_bool_set(False, 57, 58, 59, 60)
        DoesNotOverrideBackpackDraw = factory.create_bool_set(False, 57, 58, 59, 60)
        IsRollerSkates = factory.create_bool_set(False, 57, 58, 59, 60)
        Cart = factory.create_bool_set(False, 6, 13, 11, 15, 16, 18, 19, 20, 21, 22, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 38, 39, 51, 53)
        PlayerIsHidden = factory.create_bool_set(False, 52, 54, 55, 56, 61)
        DontHoldItems = factory.create_bool_set(False, 55, 56, 61)
        DontDismountWhenCCed = factory.create_bool_set(False, 55, 56, 61)
