"""
AnimationID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class AnimationID(IntEnum):
    MushroomStatueTurningOn = 0
    MushroomStatueTurningOff = 1
    FakeChestOpening = 2
    VolcanosTurningOn = 3
    VolcanosTurningOff = 4

