"""
SurfaceBackgroundID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 07:02 UTC
"""

from terrex.id.set_factory import SetFactory
from enum import IntEnum, auto


class SurfaceBackgroundID(IntEnum):
    Forest1 = 0
    Corruption = 1
    Desert = 2
    Jungle = 3
    Ocean = 4
    CorruptDesert = 5
    Hallow = 6
    Snow = 7
    Crimson = 8
    Mushroom = 9
    Forest2 = 10
    Forest3 = 11
    Forest4 = 12
    HallowDesert = 13
    CrimsonDesert = 14
    Empty = 15
    Count = 16


class SurfaceBackgroundIDSets:
    class Main:
        factory = SetFactory(SurfaceBackgroundID.Count)
        IsDesertVariant = factory.create_bool_set(False, 2, 5, 13, 14)
        IsForest = factory.create_bool_set(False, 0, 10, 11, 12)
