"""
AchievementHelperID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class AchievementHelperID(auto):

    class Events(IntEnum):
        NightStart = 0
        DayStart = 1
        EclipseStart = 2
        EclipseEnd = 3
        BloodMoonStart = 4
        BloodMoonEnd = 5
        SmashDemonAltar = 6
        SmashShadowOrb = 7
        NPCMovedIn = 8
        StartHardmode = 9
        InvasionDefeatedGoblins = 10
        InvasionDefeatedPirates = 11
        InvasionDefeatedSnowman = 12
        InvasionDefeatedMartians = 13
        FrostMoonWave15 = 14
        PumpkinMoonWave15 = 15
        SurvivedSlimeRain = 16
        HousedAllNPCs = 17
        TruffleMovedIn = 18
        UnlockedGoldenChest = 19
        UnlockedBiomeChest = 20
        DefeatedMechaMayhem = 21
        TempleRaider = 22
        DefeatedOldOnesArmyDifficulty3 = 23
        TurnGnomeToStatue = 24
        ThrowAParty = 25
        HousedAllTownSlimes = 26
        TransmuteItem = 27
        DroneDiedInSpace = 28
        CompleteBestiary = 29
        DefeatMoonLordInFTW = 30
        DefeatMechdusa = 31
        RideACoffinCart = 32
        GetSunBurned = 33
        SurviveBoulderRain = 34
        SurviveHardcoreDeath = 35
        GraveMistake = 36
        PlayGuitar = 37
        SpotTheSunOnACoolDay = 38
        SpottedRainbowBoulder = 39
        TrainedTownNPCsForCombat = 40
        WearMoonLordSet = 41
        Terrarist = 42
        ShimmerVillager = 43
        FlyPastSpace = 44
        ResearchedManyItems = 45
        JojaCola = 46

    class Special(IntEnum):
        ConsumeHeart = 0
        ConsumeStar = 1
        ConsumeFruit = 2
        NotTheBees = 3
        HitByTrap = 4
        RainbowShoot = 5
        MinionArmy = 6
        SwingYoyo = 7
        SurviveHugeFall = 8
        Roadkill = 9
        ReachWorldBottom = 10
        ReachWorldTop = 11
        FoundBeeHive = 12
        FoundSpiderCave = 13
        FoundHell = 14
        FoundGlowshroomOverworld = 15
        PeekInGoldenChest = 16
        FlyAKiteOnAWindyDay = 17
        FoundGraveyard = 18
        GoLavaFishing = 19
        TalkToNPCAtMaxHappiness = 20
        PetThePet = 21
        FindAFairy = 22
        DeathByDeadmansChest = 23
        GainTorchGodsFavor = 24
        DrinkBottledWaterWhileDrowning = 25
        PlayOnASpecialSeed = 26
        PurifyEntireWorld = 27

