from enum import IntEnum


class TeleportPylonType(IntEnum):
    SurfacePurity = 0
    Jungle = 1
    Hallow = 2
    Underground = 3
    Beach = 4
    Desert = 5
    Snow = 6
    GlowingMushroom = 7
    Victory = 8
    Underworld = 9
    Shimmer = 10
