"""
TeleportationStyleID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class TeleportationStyleID(IntEnum):
    TeleporterTile = 0
    RodOfDiscord = 1
    TeleportationPotion = 2
    RecallPotion = 3
    Portal = 4
    MagicConch = 5
    DebugTeleport = 6
    DemonConch = 7
    PotionOfReturn = 8
    TeleportationPylon = 9
    QueenSlimeHook = 10
    ShellphoneSpawn = 11
    ShimmerTownNPCTransform = 12
    MysticFrog = 13
    NoEffect = 14

