"""
PaintID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class PaintID(IntEnum):
    NoneValue = 0
    RedPaint = 1
    OrangePaint = 2
    YellowPaint = 3
    LimePaint = 4
    GreenPaint = 5
    TealPaint = 6
    CyanPaint = 7
    SkyBluePaint = 8
    BluePaint = 9
    PurplePaint = 10
    VioletPaint = 11
    PinkPaint = 12
    DeepRedPaint = 13
    DeepOrangePaint = 14
    DeepYellowPaint = 15
    DeepLimePaint = 16
    DeepGreenPaint = 17
    DeepTealPaint = 18
    DeepCyanPaint = 19
    DeepSkyBluePaint = 20
    DeepBluePaint = 21
    DeepPurplePaint = 22
    DeepVioletPaint = 23
    DeepPinkPaint = 24
    BlackPaint = 25
    WhitePaint = 26
    GrayPaint = 27
    BrownPaint = 28
    ShadowPaint = 29
    NegativePaint = 30
    IlluminantPaint = 31
    Old_IlluminantPaint = 31

