"""
ExtrasID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class ExtrasID(IntEnum):
    BrainScrambler = 0
    Raygun = 1
    LaserRuler = 2
    AntiGravityHookChain = 3
    SaucerDeathrayCap = 4
    BGMartianUFOSmall = 5
    BGMartianUFOBig = 6
    EventIconSnowLegion = 7
    EventIconFrostMoon = 8
    EventIconGoblinArmy = 9
    EventIconMartianMadness = 10
    EventIconPirateInvasion = 11
    EventIconPumpkinMoon = 12
    MoonLordRibs = 13
    MoonLordBackarm = 14
    MoonLordForearm = 15
    MoonLordCoreMoss = 16
    MoonLordEyeWhiteHand = 17
    MoonLordEyeWhiteHead = 18
    MoonLordEye = 19
    MartianProbeDiode = 20
    PhantasmalDeathrayBody = 21
    PhantasmalDeathrayEnd = 22
    MoonLeechBody = 23
    MoonLeechTail = 24
    MoonLordMouth = 25
    MoonLordHandMouth = 26
    MartianProbeScanWave = 27
    TEMPORARYChestOpen = 28
    MoonLordEyeMouth = 29
    CultistBossShadow = 30
    WebbedFloor = 31
    WebbedAir = 32
    CultistLightingArc = 33
    CultistRitual = 34
    CultistIceshard = 35
    StarWrath = 36
    PlayerStoned = 37
    BejeweledValkyrieWing = 38
    KingSlimeCrown = 39
    PirateShipFlag = 40
    PirateShipOar = 41
    PirateShipSail1 = 42
    PirateShipSail2 = 43
    PirateShipSail3 = 44
    PirateShipSail4 = 45
    StardustJellyfishSmall = 46
    StardustTowerMark = 47
    EmoteBubble = 48
    ScreenObfuscation = 49
    VortexBlack = 50
    MagicAura = 51
    GuideFrontal = 52
    TravellingMerchantFrontal = 53
    EquipIcons = 54
    MeteorHeadFlame = 55
    MartianWalkerCannon = 56
    AncientLight = 57
    DefenseShield = 58
    PortalGateHalo = 59
    PortalGateHalo2 = 60
    SolarBlaze = 61
    SolarBlaze2 = 62
    SolarBlaze3 = 63
    NebulaArcanumItemHold = 64
    PhantasmMuzzle = 65
    SuspiciousTentacle = 66
    Yoraiz0rDarkness = 67
    LaserGrid2 = 68
    PartyBalloonsSmall = 69
    PartyBalloonsBig = 70
    PartyBalloonsTriplet = 71
    TownNPCHats = 72
    DjinnsCurse = 73
    ForbiddenSign = 74
    BlackBolt = 75
    Tumbleweed = 76
    ElfEars = 77
    DD2ElderEye = 78
    EventIconOldOnesArmy = 79
    DD2SkeletonFlame = 80
    DD2BetsyWingFront = 81
    DD2BetsyWingBack = 82
    DD2BallistraTowerT1 = 83
    DD2BallistraTowerT2 = 84
    DD2BallistraTowerT3 = 85
    DD2LightningAuraT1 = 86
    DD2LightningAuraT2 = 87
    DD2LightningAuraT3 = 88
    ThePerfectGlow = 89
    ArkhalisMask = 90
    FallingStar = 91
    LawnMower = 92
    VoidLensOutline = 93
    MoneyTroughOutline = 94
    AmberHookChain = 95
    GolfCartBody = 96
    GolfCartWheels = 97
    SharpTears = 98
    DripplerFlail = 99
    BirdNestHead = 100
    TombstoneGlow = 101
    PortableStool = 102
    KiteRibbons = 103
    KiteRibbonsWyvern = 104
    FloatingTube = 105
    GolemLights4 = 106
    GolemLights5 = 107
    BeeMinecart = 108
    LadybugMinecart = 109
    PigronMinecart = 110
    SunflowerMinecart = 111
    HellMinecart = 112
    WitchBroom = 113
    WitchBroomTrinket = 114
    ShroomMinecart = 115
    ShroomMinecartGlow = 116
    AmethystMinecart = 117
    TopazMinecart = 118
    SapphireMinecart = 119
    EmeraldMinecart = 120
    RubyMinecart = 121
    DiamondMinecart = 122
    AmberMinecart = 123
    BeetleMinecart = 124
    MeowmereMinecart = 125
    PartyMinecart = 126
    PirateMinecart = 127
    SteampunkMinecart = 128
    BloodNautilusMouth = 129
    MapBiomeIcons = 130
    BloodNautilusCallForHelp = 131
    KiteRibbonsBoneSerpent = 132
    KiteRibbonsWorldFeeder = 133
    LanternSkyLanterns = 134
    KiteRibbonsManEater = 135
    KiteRibbonsJellyfishBlue = 136
    KiteRibbonsJellyfishPink = 137
    KiteRibbonsShark = 138
    KiteRibbonsSandShark = 139
    KiteRibbonsGoldfish = 140
    PartyCartBalloons = 141
    PirateMinecartFlag = 142
    PlayerUnicornHorn = 143
    KiteRibbonsAngryTrapper = 144
    KiteRibbonsKoi = 145
    KiteRibbonsCrawltipede = 146
    KiteRibbonsSpectrum = 147
    KiteRibbonsEyeball = 148
    FlamingoMount = 149
    CoffinMinecart = 150
    CoffinMinecartLid = 151
    SafemanSun = 152
    JimCloak = 153
    SquirrelHookChain = 154
    DiggingMoleMinecart = 155
    HallowBossGradient = 156
    HallowBossWings = 157
    HallowBossArmsLeft = 158
    HallowBossWingsBack = 159
    HallowBossArmsRight = 160
    PaintedHorseMount = 161
    MajesticHorseMount = 162
    DarkHorseMount = 163
    PogoStickMount = 164
    DiggingMoleMinecartArm = 165
    PirateShipMount = 166
    SpookyWoodMount = 167
    SantankMount = 168
    WallOfFleshGoatMount = 169
    DarkMageBookMount = 170
    PlayerRainbowWings = 171
    LavaSharkMount = 172
    PotionOfReturnMinimapIcon = 173
    KeybrandRing = 174
    PotionOfReturnMinimapHome = 175
    GolfBallMinimapOutline = 176
    QueenSlimeCrown = 177
    FairyQueenLance = 178
    Voronoi = 179
    QueenSlimeGradient = 180
    PylonCrystals = 181
    PylonMapIcons = 182
    PotionOfReturnGateIn = 183
    PotionOfReturnGateOut = 184
    QueenSlimeWing = 185
    QueenSlimeCrystalCore = 186
    HallowBossTentacles = 187
    HallowBossSkirt = 188
    FlameLashTrailShape = 189
    FlameLashTrailErosion = 190
    FlameLashTrailColorGradient = 191
    MagicMissileTrailColorGradient = 192
    MagicMissileTrailErosion = 193
    MagicMissileTrailShape = 194
    RainbowRodTrailColorGradient = 195
    RainbowRodTrailErosion = 196
    RainbowRodTrailShape = 197
    MasterTrophyHeads = 198
    WhipMarkers = 199
    IceWhipSlicerBody = 200
    FinalFractal = 201
    EmpressButterflyJar = 202
    SlimeQueenHookChain = 203
    QueenSlimeMount = 204
    QueenSlimeSaddle = 205
    QueenSlimeWingFront = 206
    QueenSlimeWingBack = 207
    QueenSlimeHookRope = 208
    EmpressBladeTrail = 209
    EmpressBladeErosion = 210
    BiomeTorchIconUI = 211
    PlaguebringerFlame = 212
    TimelessTravelerFlame = 213
    FloretProtectorFrontTube = 214
    CreditsRollNPC_DryadTurningToTree = 215
    CreditsRollScene_Mask = 216
    CreditsRollScene_DryadInForest = 217
    CreditsRollScene_GuideDoorClosed = 218
    CreditsRollScene_GuideDoorOpened = 219
    CreditsRollScene_SkeletonMerchantCave = 220
    CreditsRollScene_Hallow = 221
    CreditsRollScene_CampfireBeach = 222
    CreditsRollScene_MerchantsGuild = 223
    CreditsRollScene_GolfCourse = 224
    CreditsRollScene_TruffleHouse = 225
    CreditsRollObject_Campfire = 226
    CreditsRollObject_BonePile = 227
    CreditsRollNPC_SkeletonMerchantScavenging = 228
    CreditsRollNPC_CyborgUnderRepair = 229
    CreditsRollNPC_SteampunkerRepairing = 230
    CreditsRollScene_Jungle = 231
    CreditsRollScene_SteampunkerWorkshop = 232
    CreditsRollScene_SteampunkerWorkshop2 = 233
    CreditsRollScene_ForestBar = 234
    CreditsRollScene_TavernkeepTavern = 235
    CreditsRollScene_ChristmasTree = 236
    CreditsRollScene_TinkererWorkshop = 237
    CreditsRollObject_Balloons = 238
    CreditsRollObject_Fireplace = 239
    CreditsRollObject_MiniPortal = 240
    CreditsRollObject_FinaleScene = 241
    PotionOfReturnGateInOutline = 242
    WorkshopIcon = 243
    ChesterOutline = 244
    DeerclopsEye = 245
    FartMinecart = 246
    StardewValleyPortal = 247
    StardewValleyPortalMask = 248
    StardewValleyPortalAnimation = 249
    TownSlimeRainbowOverlay = 250
    TerraFartMinecart = 251
    LightDisc = 252
    WolfMountBody = 253
    WolfMountHead = 254
    SuperCartEnabled = 255
    SuperCartDisabled = 256
    RubbleMakerIndicator = 257
    UnsafeIndicator = 258
    Loadouts = 259
    ShimmerflyinaBottle = 260
    JimsDroneRadio = 261
    RoamingFly = 262
    ShimmeredMechanicWrench = 263
    GuideShimmerFrontal = 264
    TravellingMerchantShimmerFrontal = 265
    DeadCellsBeheadedHead = 266
    GenericCircle = 267
    ShockIcon = 268
    DeadCellsBarrelExplosion = 269
    MoonlordWhipEye = 270
    VelociraptorMountBody = 271
    VelociraptorMountArm = 272
    RatMountBody = 273
    BatMountBody = 274
    JimCloakShoulder = 275
    JimsHelmetMetal = 276
    JimsBreastplateMetal = 277
    JimsLeggingsMetal = 278
    ChippysHeadbandTassels = 279
    SunSunglasses = 280
    FakeButterfly = 281
    TeamBasedSpawnMapIcons = 282
    RainbowBoulderPetAura = 283
    HeroicisHeadMount = 284
    AcornSlingshotHeldItem = 285
    AuroraNoise = 286
    AuroraShape = 287
    LightningShape = 288
    LibrarianSkeletonCircle = 289
    PixieMountBackLayer = 290
    PixieMountFrontLayer = 291
    HouseCheckBlock = 292
    HouseCheckDot = 293
    HouseCheckMarkerLight = 294
    HouseCheckMarkerChair = 295
    HouseCheckMarkerDoor = 296
    HouseCheckMarkerTable = 297
    HouseCheckHammer = 298
    PylonOffscreenIndicator = 299
    LunaHeadEars = 300
    Chillet = 301
    ChilletIgnis = 302
    FoxsparksHeld = 303

