"""
ItemSourceID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class ItemSourceID(IntEnum):
    NoneValue = 0
    SetBonus_Nebula = 1
    LuckyCoin = 2
    PlayerDeath = 3
    PlayerDrop = 4
    GrandDesignOrMultiColorWrench = 5
    TorchGod = 6
    Shimmer = 8
    Digesting = 9
    InventoryOverflow = 10

