"""
NPCHeadID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from terrex.id.set_factory import SetFactory
from enum import IntEnum, auto


class NPCHeadID(IntEnum):
    HousingQuery = 0
    Guide = 1
    Merchant = 2
    Nurse = 3
    Demolitionist = 4
    Dryad = 5
    ArmsDealer = 6
    Clothier = 7
    Mechanic = 8
    GoblinTinkerer = 9
    Wizard = 10
    SantaClaus = 11
    Truffle = 12
    Steampunker = 13
    DyeTrader = 14
    PartyGirl = 15
    Cyborg = 16
    Painter = 17
    WitchDoctor = 18
    Pirate = 19
    Stylist = 20
    TravellingMerchant = 21
    Angler = 22
    TaxCollector = 23
    Tavernkeep = 24
    Golfer = 25
    BestiaryGirl = 26
    CatSiamese = 27
    CatBlack = 28
    CatOrangeTabby = 29
    CatRussianBlue = 30
    CatSilver = 31
    CatWhite = 32
    DogLabrador = 33
    DogPitBull = 34
    DogBeagle = 35
    DogCorgi = 36
    DogDalmation = 37
    DogHusky = 38
    BunnyWhite = 39
    BunnyAngora = 40
    BunnyDutch = 41
    BunnyFlemish = 42
    BunnyLop = 43
    BunnySilver = 44
    Princess = 45
    SlimeBlue = 46
    SlimeGreen = 47
    SlimeOld = 48
    SlimePurple = 49
    SlimeRainbow = 50
    SlimeRed = 51
    SlimeYellow = 52
    SlimeCopper = 53
    PrincessShimmered = 54
    AnglerShimmered = 55
    BestiaryGirlShimmered = 56
    ClothierShimmered = 57
    CyborgShimmered = 58
    DemolitionistShimmered = 59
    DyeTraderShimmered = 60
    GolferShimmered = 61
    MechanicShimmered = 62
    MerchantShimmered = 63
    NurseShimmered = 64
    PainterShimmered = 65
    PirateShimmered = 66
    SantaClausShimmered = 67
    SteampunkerShimmered = 68
    StylistShimmered = 69
    TaxCollectorShimmered = 70
    WizardShimmered = 71
    GuideShimmered = 72
    DryadShimmered = 73
    ArmsDealerShimmered = 74
    GoblinTinkererShimmered = 75
    TruffleShimmered = 76
    PartyGirlShimmered = 77
    WitchDoctorShimmered = 78
    TavernkeepShimmered = 79
    TravellingMerchantShimmered = 80
    Count = 81


class NPCHeadIDSets:
    class Main:
        factory = SetFactory(NPCHeadID.Count)
        CannotBeDrawnInHousingUI = factory.create_bool_set(False, 21, 80)
        HeadListOrder = [0, 1, 72, 2, 63, 4, 59, 3, 64, 6, 74, 20, 69, 5, 73, 22, 55, 14, 60, 17, 65, 25, 61, 26, 56, 18, 78, 15, 77, 24, 79, 7, 57, 8, 62, 9, 75, 23, 70, 10, 71, 12, 76, 19, 66, 13, 68, 16, 58, 11, 67, 21, 80, 45, 54, 39, 40, 41, 42, 43, 44, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 46, 49, 51, 48, 53, 52, 47, 50]
