from enum import IntEnum


class CultureName(IntEnum):
    English = 1
    German = 2
    Italian = 3
    French = 4
    Spanish = 5
    Russian = 6
    Chinese = 7
    Portuguese = 8
    Polish = 9
    Japanese = 10
    Korean = 11
    ChineseTraditional = 12
    Unknown = 9999
