"""
TileID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from terrex.id.set_factory import SetFactory
from enum import IntEnum, auto


class TileID:
    Count = 753

    class Conversion(IntEnum):
        Dirt = 0
        Stone = 1
        Grass = 2
        Plants = 3
        Torches = 4
        Trees = 5
        Iron = 6
        Copper = 7
        Gold = 8
        Silver = 9
        ClosedDoor = 10
        OpenDoor = 11
        Heart = 12
        Bottles = 13
        Tables = 14
        Chairs = 15
        Anvils = 16
        Furnaces = 17
        WorkBenches = 18
        Platforms = 19
        Saplings = 20
        Containers = 21
        Demonite = 22
        CorruptGrass = 23
        CorruptPlants = 24
        Ebonstone = 25
        DemonAltar = 26
        Sunflower = 27
        Pots = 28
        PiggyBank = 29
        WoodBlock = 30
        ShadowOrbs = 31
        CorruptThorns = 32
        Candles = 33
        Chandeliers = 34
        Jackolanterns = 35
        Presents = 36
        Meteorite = 37
        GrayBrick = 38
        RedBrick = 39
        ClayBlock = 40
        BlueDungeonBrick = 41
        HangingLanterns = 42
        GreenDungeonBrick = 43
        PinkDungeonBrick = 44
        GoldBrick = 45
        SilverBrick = 46
        CopperBrick = 47
        Spikes = 48
        WaterCandle = 49
        Books = 50
        Cobweb = 51
        Vines = 52
        Sand = 53
        Glass = 54
        Signs = 55
        Obsidian = 56
        Ash = 57
        Hellstone = 58
        Mud = 59
        JungleGrass = 60
        JunglePlants = 61
        JungleVines = 62
        Sapphire = 63
        Ruby = 64
        Emerald = 65
        Topaz = 66
        Amethyst = 67
        Diamond = 68
        JungleThorns = 69
        MushroomGrass = 70
        MushroomPlants = 71
        MushroomTrees = 72
        Plants2 = 73
        JunglePlants2 = 74
        ObsidianBrick = 75
        HellstoneBrick = 76
        Hellforge = 77
        ClayPot = 78
        Beds = 79
        Cactus = 80
        Coral = 81
        ImmatureHerbs = 82
        MatureHerbs = 83
        BloomingHerbs = 84
        Tombstones = 85
        Loom = 86
        Pianos = 87
        Dressers = 88
        Benches = 89
        Bathtubs = 90
        Banners = 91
        Lampposts = 92
        Lamps = 93
        Kegs = 94
        ChineseLanterns = 95
        CookingPots = 96
        Safes = 97
        SkullLanterns = 98
        TrashCan = 99
        Candelabras = 100
        Bookcases = 101
        Thrones = 102
        Bowls = 103
        GrandfatherClocks = 104
        Statues = 105
        Sawmill = 106
        Cobalt = 107
        Mythril = 108
        HallowedGrass = 109
        HallowedPlants = 110
        Adamantite = 111
        Ebonsand = 112
        HallowedPlants2 = 113
        TinkerersWorkbench = 114
        HallowedVines = 115
        Pearlsand = 116
        Pearlstone = 117
        PearlstoneBrick = 118
        IridescentBrick = 119
        Mudstone = 120
        CobaltBrick = 121
        MythrilBrick = 122
        Silt = 123
        WoodenBeam = 124
        CrystalBall = 125
        DiscoBall = 126
        MagicalIceBlock = 127
        Mannequin = 128
        Crystals = 129
        ActiveStoneBlock = 130
        InactiveStoneBlock = 131
        Lever = 132
        AdamantiteForge = 133
        MythrilAnvil = 134
        PressurePlates = 135
        Switches = 136
        Traps = 137
        Boulder = 138
        MusicBoxes = 139
        DemoniteBrick = 140
        Explosives = 141
        InletPump = 142
        OutletPump = 143
        Timers = 144
        CandyCaneBlock = 145
        GreenCandyCaneBlock = 146
        SnowBlock = 147
        SnowBrick = 148
        HolidayLights = 149
        AdamantiteBeam = 150
        SandstoneBrick = 151
        EbonstoneBrick = 152
        RedStucco = 153
        YellowStucco = 154
        GreenStucco = 155
        GrayStucco = 156
        Ebonwood = 157
        RichMahogany = 158
        Pearlwood = 159
        RainbowBrick = 160
        IceBlock = 161
        BreakableIce = 162
        CorruptIce = 163
        HallowedIce = 164
        Stalactite = 165
        Tin = 166
        Lead = 167
        Tungsten = 168
        Platinum = 169
        PineTree = 170
        ChristmasTree = 171
        Sinks = 172
        PlatinumCandelabra = 173
        PlatinumCandle = 174
        TinBrick = 175
        TungstenBrick = 176
        PlatinumBrick = 177
        ExposedGems = 178
        GreenMoss = 179
        BrownMoss = 180
        RedMoss = 181
        BlueMoss = 182
        PurpleMoss = 183
        LongMoss = 184
        SmallPiles = 185
        LargePiles = 186
        LargePiles2 = 187
        CactusBlock = 188
        Cloud = 189
        MushroomBlock = 190
        LivingWood = 191
        LeafBlock = 192
        SlimeBlock = 193
        BoneBlock = 194
        FleshBlock = 195
        RainCloud = 196
        FrozenSlimeBlock = 197
        Asphalt = 198
        CrimsonGrass = 199
        FleshIce = 200
        CrimsonPlants = 201
        Sunplate = 202
        Crimstone = 203
        Crimtane = 204
        CrimsonVines = 205
        IceBrick = 206
        WaterFountain = 207
        Shadewood = 208
        Cannon = 209
        LandMine = 210
        Chlorophyte = 211
        SnowballLauncher = 212
        Rope = 213
        Chain = 214
        Campfire = 215
        Firework = 216
        Blendomatic = 217
        MeatGrinder = 218
        Extractinator = 219
        Solidifier = 220
        Palladium = 221
        Orichalcum = 222
        Titanium = 223
        Slush = 224
        Hive = 225
        LihzahrdBrick = 226
        DyePlants = 227
        DyeVat = 228
        HoneyBlock = 229
        CrispyHoneyBlock = 230
        Larva = 231
        WoodenSpikes = 232
        PlantDetritus = 233
        Crimsand = 234
        Teleporter = 235
        LifeFruit = 236
        LihzahrdAltar = 237
        PlanteraBulb = 238
        MetalBars = 239
        Painting3X3 = 240
        Painting4X3 = 241
        Painting6X4 = 242
        ImbuingStation = 243
        BubbleMachine = 244
        Painting2X3 = 245
        Painting3X2 = 246
        Autohammer = 247
        PalladiumColumn = 248
        BubblegumBlock = 249
        Titanstone = 250
        PumpkinBlock = 251
        HayBlock = 252
        SpookyWood = 253
        Pumpkins = 254
        AmethystGemsparkOff = 255
        TopazGemsparkOff = 256
        SapphireGemsparkOff = 257
        EmeraldGemsparkOff = 258
        RubyGemsparkOff = 259
        DiamondGemsparkOff = 260
        AmberGemsparkOff = 261
        AmethystGemspark = 262
        TopazGemspark = 263
        SapphireGemspark = 264
        EmeraldGemspark = 265
        RubyGemspark = 266
        DiamondGemspark = 267
        AmberGemspark = 268
        Womannequin = 269
        FireflyinaBottle = 270
        LightningBuginaBottle = 271
        Cog = 272
        StoneSlab = 273
        SandStoneSlab = 274
        BunnyCage = 275
        SquirrelCage = 276
        MallardDuckCage = 277
        DuckCage = 278
        BirdCage = 279
        BlueJay = 280
        CardinalCage = 281
        FishBowl = 282
        HeavyWorkBench = 283
        CopperPlating = 284
        SnailCage = 285
        GlowingSnailCage = 286
        AmmoBox = 287
        MonarchButterflyJar = 288
        PurpleEmperorButterflyJar = 289
        RedAdmiralButterflyJar = 290
        UlyssesButterflyJar = 291
        SulphurButterflyJar = 292
        TreeNymphButterflyJar = 293
        ZebraSwallowtailButterflyJar = 294
        JuliaButterflyJar = 295
        ScorpionCage = 296
        BlackScorpionCage = 297
        FrogCage = 298
        MouseCage = 299
        BoneWelder = 300
        FleshCloningVat = 301
        GlassKiln = 302
        LihzahrdFurnace = 303
        LivingLoom = 304
        SkyMill = 305
        IceMachine = 306
        SteampunkBoiler = 307
        HoneyDispenser = 308
        PenguinCage = 309
        WormCage = 310
        DynastyWood = 311
        RedDynastyShingles = 312
        BlueDynastyShingles = 313
        MinecartTrack = 314
        Coralstone = 315
        BlueJellyfishBowl = 316
        GreenJellyfishBowl = 317
        PinkJellyfishBowl = 318
        ShipInABottle = 319
        SeaweedPlanter = 320
        BorealWood = 321
        PalmWood = 322
        PalmTree = 323
        BeachPiles = 324
        TinPlating = 325
        Waterfall = 326
        Lavafall = 327
        Confetti = 328
        ConfettiBlack = 329
        CopperCoinPile = 330
        SilverCoinPile = 331
        GoldCoinPile = 332
        PlatinumCoinPile = 333
        WeaponsRack = 334
        FireworksBox = 335
        LivingFire = 336
        AlphabetStatues = 337
        FireworkFountain = 338
        GrasshopperCage = 339
        LivingCursedFire = 340
        LivingDemonFire = 341
        LivingFrostFire = 342
        LivingIchor = 343
        LivingUltrabrightFire = 344
        Honeyfall = 345
        ChlorophyteBrick = 346
        CrimtaneBrick = 347
        ShroomitePlating = 348
        MushroomStatue = 349
        MartianConduitPlating = 350
        ChimneySmoke = 351
        CrimsonThorns = 352
        VineRope = 353
        BewitchingTable = 354
        AlchemyTable = 355
        Sundial = 356
        MarbleBlock = 357
        GoldBirdCage = 358
        GoldBunnyCage = 359
        GoldButterflyCage = 360
        GoldFrogCage = 361
        GoldGrasshopperCage = 362
        GoldMouseCage = 363
        GoldWormCage = 364
        SilkRope = 365
        WebRope = 366
        Marble = 367
        Granite = 368
        GraniteBlock = 369
        MeteoriteBrick = 370
        PinkSlimeBlock = 371
        PeaceCandle = 372
        WaterDrip = 373
        LavaDrip = 374
        HoneyDrip = 375
        FishingCrate = 376
        SharpeningStation = 377
        TargetDummy = 378
        Bubble = 379
        PlanterBox = 380
        LavaMoss = 381
        VineFlowers = 382
        LivingMahogany = 383
        LivingMahoganyLeaves = 384
        CrystalBlock = 385
        TrapdoorOpen = 386
        TrapdoorClosed = 387
        TallGateClosed = 388
        TallGateOpen = 389
        LavaLamp = 390
        CageEnchantedNightcrawler = 391
        CageBuggy = 392
        CageGrubby = 393
        CageSluggy = 394
        ItemFrame = 395
        Sandstone = 396
        HardenedSand = 397
        CorruptHardenedSand = 398
        CrimsonHardenedSand = 399
        CorruptSandstone = 400
        CrimsonSandstone = 401
        HallowHardenedSand = 402
        HallowSandstone = 403
        DesertFossil = 404
        Fireplace = 405
        Chimney = 406
        FossilOre = 407
        LunarOre = 408
        LunarBrick = 409
        LunarMonolith = 410
        Detonator = 411
        LunarCraftingStation = 412
        SquirrelOrangeCage = 413
        SquirrelGoldCage = 414
        LunarBlockSolar = 415
        LunarBlockVortex = 416
        LunarBlockNebula = 417
        LunarBlockStardust = 418
        LogicGateLamp = 419
        LogicGate = 420
        ConveyorBeltLeft = 421
        ConveyorBeltRight = 422
        LogicSensor = 423
        WirePipe = 424
        AnnouncementBox = 425
        TeamBlockRed = 426
        TeamBlockRedPlatform = 427
        WeightedPressurePlate = 428
        WireBulb = 429
        TeamBlockGreen = 430
        TeamBlockBlue = 431
        TeamBlockYellow = 432
        TeamBlockPink = 433
        TeamBlockWhite = 434
        TeamBlockGreenPlatform = 435
        TeamBlockBluePlatform = 436
        TeamBlockYellowPlatform = 437
        TeamBlockPinkPlatform = 438
        TeamBlockWhitePlatform = 439
        GemLocks = 440
        FakeContainers = 441
        ProjectilePressurePad = 442
        GeyserTrap = 443
        BeeHive = 444
        PixelBox = 445
        SillyBalloonPink = 446
        SillyBalloonPurple = 447
        SillyBalloonGreen = 448
        SillyStreamerBlue = 449
        SillyStreamerGreen = 450
        SillyStreamerPink = 451
        SillyBalloonMachine = 452
        SillyBalloonTile = 453
        Pigronata = 454
        PartyMonolith = 455
        PartyBundleOfBalloonTile = 456
        PartyPresent = 457
        SandFallBlock = 458
        SnowFallBlock = 459
        SnowCloud = 460
        SandDrip = 461
        DjinnLamp = 462
        DefendersForge = 463
        WarTable = 464
        WarTableBanner = 465
        ElderCrystalStand = 466
        Containers2 = 467
        FakeContainers2 = 468
        Tables2 = 469
        DisplayDoll = 470
        WeaponsRack2 = 471
        IronBrick = 472
        LeadBrick = 473
        LesionBlock = 474
        HatRack = 475
        GolfHole = 476
        GolfGrass = 477
        CrimstoneBrick = 478
        SmoothSandstone = 479
        BloodMoonMonolith = 480
        CrackedBlueDungeonBrick = 481
        CrackedGreenDungeonBrick = 482
        CrackedPinkDungeonBrick = 483
        RollingCactus = 484
        AntlionLarva = 485
        DrumSet = 486
        PicnicTable = 487
        FallenLog = 488
        PinWheel = 489
        WeatherVane = 490
        VoidVault = 491
        GolfGrassHallowed = 492
        GolfCupFlag = 493
        GolfTee = 494
        ShellPile = 495
        AntiPortalBlock = 496
        Toilets = 497
        Spider = 498
        LesionStation = 499
        SolarBrick = 500
        VortexBrick = 501
        NebulaBrick = 502
        StardustBrick = 503
        MysticSnakeRope = 504
        GoldGoldfishBowl = 505
        CatBast = 506
        GoldStarryGlassBlock = 507
        BlueStarryGlassBlock = 508
        VoidMonolith = 509
        ArrowSign = 510
        PaintedArrowSign = 511
        GreenMossBrick = 512
        BrownMossBrick = 513
        RedMossBrick = 514
        BlueMossBrick = 515
        PurpleMossBrick = 516
        LavaMossBrick = 517
        LilyPad = 518
        Cattail = 519
        FoodPlatter = 520
        BlackDragonflyJar = 521
        BlueDragonflyJar = 522
        GreenDragonflyJar = 523
        OrangeDragonflyJar = 524
        RedDragonflyJar = 525
        YellowDragonflyJar = 526
        GoldDragonflyJar = 527
        MushroomVines = 528
        SeaOats = 529
        OasisPlants = 530
        BoulderStatue = 531
        MaggotCage = 532
        RatCage = 533
        KryptonMoss = 534
        KryptonMossBrick = 535
        XenonMoss = 536
        XenonMossBrick = 537
        LadybugCage = 538
        ArgonMoss = 539
        ArgonMossBrick = 540
        EchoBlock = 541
        OwlCage = 542
        PupfishBowl = 543
        GoldLadybugCage = 544
        LawnFlamingo = 545
        Grate = 546
        PottedPlants1 = 547
        PottedPlants2 = 548
        Seaweed = 549
        TurtleCage = 550
        TurtleJungleCage = 551
        Sandcastles = 552
        GrebeCage = 553
        SeagullCage = 554
        WaterStriderCage = 555
        GoldWaterStriderCage = 556
        GrateClosed = 557
        SeahorseCage = 558
        GoldSeahorseCage = 559
        GolfTrophies = 560
        MarbleColumn = 561
        BambooBlock = 562
        LargeBambooBlock = 563
        PlasmaLamp = 564
        FogMachine = 565
        AmberStoneBlock = 566
        GardenGnome = 567
        PinkFairyJar = 568
        GreenFairyJar = 569
        BlueFairyJar = 570
        Bamboo = 571
        SoulBottles = 572
        TatteredWoodSign = 573
        BorealBeam = 574
        RichMahoganyBeam = 575
        GraniteColumn = 576
        SandstoneColumn = 577
        MushroomBeam = 578
        RockGolemHead = 579
        HellButterflyJar = 580
        LavaflyinaBottle = 581
        MagmaSnailCage = 582
        TreeTopaz = 583
        TreeAmethyst = 584
        TreeSapphire = 585
        TreeEmerald = 586
        TreeRuby = 587
        TreeDiamond = 588
        TreeAmber = 589
        GemSaplings = 590
        PotsSuspended = 591
        BrazierSuspended = 592
        VolcanoSmall = 593
        VolcanoLarge = 594
        VanityTreeSakuraSaplings = 595
        VanityTreeSakura = 596
        TeleportationPylon = 597
        LavafishBowl = 598
        AmethystBunnyCage = 599
        TopazBunnyCage = 600
        SapphireBunnyCage = 601
        EmeraldBunnyCage = 602
        RubyBunnyCage = 603
        DiamondBunnyCage = 604
        AmberBunnyCage = 605
        AmethystSquirrelCage = 606
        TopazSquirrelCage = 607
        SapphireSquirrelCage = 608
        EmeraldSquirrelCage = 609
        RubySquirrelCage = 610
        DiamondSquirrelCage = 611
        AmberSquirrelCage = 612
        PottedLavaPlants = 613
        PottedLavaPlantTendrils = 614
        VanityTreeWillowSaplings = 615
        VanityTreeYellowWillow = 616
        MasterTrophyBase = 617
        AccentSlab = 618
        TruffleWormCage = 619
        EmpressButterflyJar = 620
        SliceOfCake = 621
        TeaKettle = 622
        PottedCrystalPlants = 623
        AbigailsFlower = 624
        VioletMoss = 625
        VioletMossBrick = 626
        RainbowMoss = 627
        RainbowMossBrick = 628
        StinkbugCage = 629
        StinkbugHousingBlocker = 630
        StinkbugHousingBlockerEcho = 631
        ScarletMacawCage = 632
        AshGrass = 633
        TreeAsh = 634
        AshWood = 635
        CorruptVines = 636
        AshPlants = 637
        AshVines = 638
        ManaCrystal = 639
        BlueMacawCage = 640
        ReefBlock = 641
        ChlorophyteExtractinator = 642
        ToucanCage = 643
        YellowCockatielCage = 644
        GrayCockatielCage = 645
        ShadowCandle = 646
        LargePilesEcho = 647
        LargePiles2Echo = 648
        SmallPiles2x1Echo = 649
        SmallPiles1x1Echo = 650
        PlantDetritus3x2Echo = 651
        PlantDetritus2x2Echo = 652
        PotsEcho = 653
        TNTBarrel = 654
        PlanteraThorns = 655
        GlowTulip = 656
        EchoMonolith = 657
        ShimmerMonolith = 658
        ShimmerBlock = 659
        ShimmerflyinaBottle = 660
        CorruptJungleGrass = 661
        CrimsonJungleGrass = 662
        Moondial = 663
        BouncyBoulder = 664
        LifeCrystalBoulder = 665
        PoopBlock = 666
        ShimmerBrick = 667
        DirtiestBlock = 668
        LunarRustBrick = 669
        DarkCelestialBrick = 670
        AstraBrick = 671
        CosmicEmberBrick = 672
        CryocoreBrick = 673
        MercuryBrick = 674
        StarRoyaleBrick = 675
        HeavenforgeBrick = 676
        AncientBlueBrick = 677
        AncientGreenBrick = 678
        AncientPinkBrick = 679
        AncientGoldBrick = 680
        AncientSilverBrick = 681
        AncientCopperBrick = 682
        AncientObsidianBrick = 683
        AncientHellstoneBrick = 684
        AncientCobaltBrick = 685
        AncientMythrilBrick = 686
        LavaMossBlock = 687
        ArgonMossBlock = 688
        KryptonMossBlock = 689
        XenonMossBlock = 690
        VioletMossBlock = 691
        RainbowMossBlock = 692
        Stalactite1x1Echo = 693
        Stalactite1x2Echo = 694
        DemonAltarReplica = 695
        ShadowOrbsReplica = 696
        CobwebReplica = 697
        DeadCellsDisplayJar = 698
        DeadCellsPotionStation = 699
        AbigailsFlowerReplica = 700
        GlowTulipReplica = 701
        LifeFruitReplica = 702
        JunglePlantsEcho = 703
        FallenLogEcho = 704
        OasisPlantsEcho = 705
        TerragrimShrineEcho = 706
        BooksEcho = 707
        Shimmerfall = 708
        ShimmerDrip = 709
        PufferfishCage = 710
        RainbowBoulder = 711
        Poulder = 712
        LavaBoulder = 713
        SpiderBoulder = 714
        Ghoulder = 715
        BoulderThatSpawnsPet = 716
        LavaCloud = 717
        StarCloud = 718
        RainbowCloud = 719
        CRTMonolith = 720
        RetroMonolith = 721
        FallenStarBlock = 722
        KiteAnchor = 723
        CritterAnchor = 724
        NoirMonolith = 725
        CannonBall = 726
        TeamBlockRedVariant = 727
        TeamBlockGreenVariant = 728
        TeamBlockBlueVariant = 729
        TeamBlockYellowVariant = 730
        TeamBlockPinkVariant = 731
        TeamBlockWhiteVariant = 732
        RadioThingMonolith = 733
        Feywood = 734
        HallowedBrick = 735
        EasterBlock = 736
        GothicBrick = 737
        FlinxFurBlock = 738
        JellyfishBlock = 739
        ToyBreakerBlock = 740
        PineWoodBlock = 741
        HarpyBlock = 742
        MoonplateBlock = 743
        LibrarianBlock = 744
        SpikeBlock = 745
        OfficeBlock = 746
        ForbiddenBlock = 747
        WaterBlock = 748
        BoulderBlock = 749
        DamagingSpikeBlock = 750
        PalworldDigtoiseSleeping = 751
        PalworldChilletEgg = 752
        Count = 753


class TileIDSets:
    class Conversion:
        factory = SetFactory(TileID.Count)
        MergesWithDirtInASpecialWay = factory.create_bool_set(False, 2, 23, 109, 199, 477, 492)
        JungleGrass = factory.create_bool_set(False, 60, 661, 662)
        MushroomGrass = factory.create_bool_set(False, 70)
        Grass = factory.create_bool_set(False, 2, 23, 199, 109, 477, 492)
        GolfGrass = factory.create_bool_set(False, 477, 492)
        Dirt = factory.create_bool_set(False)
        Snow = factory.create_bool_set(False, 147)
        Stone = factory.create_bool_set(False, 1, 25, 117, 203)
        Ice = factory.create_bool_set(False, 161, 163, 164, 200)
        Sand = factory.create_bool_set(False, 53, 112, 116, 234)
        HardenedSand = factory.create_bool_set(False, 397, 398, 402, 399)
        Sandstone = factory.create_bool_set(False, 396, 400, 403, 401)
        Thorn = factory.create_bool_set(False, 32, 352, 69, 655)
        Moss = factory.create_bool_set(False, 182, 180, 179, 381, 183, 181, 534, 536, 539, 625, 627)
        MossBrick = factory.create_bool_set(False, 512, 513, 514, 515, 516, 517, 535, 537, 540, 626, 628)

    class ForAdvancedCollision:
        factory = SetFactory(TileID.Count)
        ForSandshark = factory.create_bool_set(False, 397, 398, 402, 399, 396, 400, 403, 401, 53, 112, 116, 234, 407, 404)
        ClosedDoors = factory.create_bool_set(False, 10, 388)

    class Main:
        factory = SetFactory(TileID.Count)
        BreaksToys = factory.create_bool_set(False, 740)
        MakesRubbleDust = factory.create_bool_set(False, 0, 668, 40, 59, 123, 224, 1, 25, 203, 117, 2, 60, 70, 23, 661, 199, 662, 109, 477, 492, 633, 53, 112, 234, 116, 397, 398, 399, 402, 396, 400, 401, 403, 57, 147, 161, 163, 200, 164, 539, 182, 180, 179, 534, 381, 183, 181, 625, 536, 627, 191, 192, 383, 384, 315, 367, 368, 495, 56, 666, 229, 230, 189, 196, 460, 717, 718, 719)
        IceSkateSlippery = factory.create_bool_set(False, 161, 162, 127, 163, 164, 200, 659)
        DontDrawTileSliced = factory.create_bool_set(False, 137, 235, 388, 476, 160, 138, 664, 665, 630, 631, 711, 712, 713, 714, 715, 716, 723, 726)
        DontDrawTileSlopes = factory.create_bool_set(False, 137, 235, 388, 476, 138, 664, 665, 630, 631, 711, 712, 713, 714, 715, 716, 723, 726)
        AllowsSaveCompressionBatching = factory.create_bool_set(True, 520, 423, 723, 724)
        IsADripTile = factory.create_bool_set(False, 373, 374, 375, 461, 709)
        CountsAsGemTree = factory.create_bool_set(False, 583, 584, 585, 586, 587, 588, 589)
        IsATreeTrunk = factory.create_bool_set(False, 5, 72, 583, 584, 585, 586, 587, 588, 589, 596, 616, 634)
        IsShakeable = factory.create_bool_set(False, 5, 72, 323, 583, 584, 585, 586, 587, 588, 589, 596, 616, 634)
        GetsDestroyedForMeteors = factory.create_bool_set(False, 5, 32, 352, 583, 584, 585, 586, 587, 588, 589, 596, 616, 634)
        GetsCheckedForLeaves = factory.create_bool_set(False, 5, 323, 72, 583, 584, 585, 586, 587, 588, 589, 596, 616, 634)
        PreventsTileRemovalIfOnTopOfIt = factory.create_bool_set(False, 5, 323, 72, 488, 26, 583, 584, 585, 586, 587, 588, 589, 596, 616, 470, 475, 634)
        PreventsTileReplaceIfOnTopOfIt = factory.create_bool_set(False, 5, 323, 72, 583, 584, 585, 586, 587, 588, 589, 596, 616, 634)
        CommonSapling = factory.create_bool_set(False, 20, 590, 595, 615)
        AllBlocksWithSmoothBordersToResolveHalfBlockIssue = factory.create_bool_set(False, 321, 157, 208, 159, 190, 80, 251, 202, 229, 56, 38, 39, 152, 118, 151, 148, 206, 119, 175, 46, 176, 45, 140, 347, 370, 121, 122, 680, 681, 682, 685, 686, 346, 687, 688, 689, 690, 691, 692, 160, 226, 54, 156, 155, 153, 154, 150, 250, 198, 273, 274, 325, 284, 348, 385, 327, 326, 345, 328, 329, 357, 369, 268, 261, 262, 255, 267, 260, 265, 258, 266, 259, 264, 257, 263, 256, 311, 426, 430, 431, 432, 433, 434, 727, 728, 729, 730, 731, 732, 272, 145, 146, 350, 127, 472, 473, 477, 478, 479, 492, 496, 507, 508, 563, 618, 708, 722, 735, 748)
        CanBeDugByShovel = factory.create_bool_set(False, 0, 668, 59, 57, 123, 224, 147, 2, 109, 23, 661, 199, 662, 60, 70, 477, 492, 53, 116, 112, 234, 40, 495, 633)
        NonSolidSaveSlopes = factory.create_bool_set(False, 131, 351, 336, 340, 342, 341, 343, 344)
        ResetsHalfBrickPlacementAttempt = factory.create_bool_set(True, 2, 23, 661, 60, 70, 199, 662, 109, 477, 492, 179, 512, 180, 513, 181, 514, 182, 515, 183, 516, 381, 517, 534, 535, 536, 537, 539, 540, 625, 626, 627, 628, 633)
        CrackedBricks = factory.create_bool_set(False, 481, 482, 483)
        ForcedDirtMerging = factory.create_bool_set(False, 75, 76, 508, 507, 226, 409, 669, 670, 671, 672, 673, 674, 675, 676, 683, 684, 273, 274, 459, 458, 326, 327, 345, 328, 329, 192, 384, 284, 325, 272, 268, 262, 267, 265, 266, 264, 263, 261, 255, 260, 258, 259, 257, 256, 54, 357, 708, 385, 735, 736, 737, 738, 741, 742, 743, 745, 746, 747, 748, 749)
        Paintings = factory.create_bool_set(False, 245, 246, 240, 241, 242)
        isDesertBiomeSand = factory.create_bool_set(False, 53, 397, 396, 400, 403, 401)
        MergesWithClouds = factory.create_bool_set(False, 196, 460, 717, 718, 719)
        DontMergeWithSnow = factory.create_bool_set(False, 161, 200, 163, 164, 224, 170, 738)
        Boulders = factory.create_bool_set(False, 138, 484, 664, 665, 711, 712, 713, 714, 715, 716)
        Clouds = factory.create_bool_set(False, 189, 196, 460, 717, 718, 719)
        CritterCageLidStyle = factory.create_int_set(-1, 275, 0, 276, 0, 277, 0, 278, 0, 279, 0, 280, 0, 281, 0, 558, 0, 554, 0, 553, 0, 551, 0, 550, 0, 542, 0, 413, 0, 309, 0, 297, 0, 296, 0, 645, 0, 643, 0, 644, 0, 632, 0, 640, 0, 710, 0, 559, 1, 414, 1, 359, 1, 358, 1, 605, 2, 604, 2, 603, 2, 602, 2, 601, 2, 599, 2, 600, 2, 612, 2, 611, 2, 610, 2, 609, 2, 608, 2, 606, 2, 607, 2, 285, 3, 286, 3, 582, 3, 555, 3, 538, 3, 533, 3, 532, 3, 394, 3, 393, 3, 392, 3, 391, 3, 339, 3, 310, 3, 299, 3, 298, 3, 629, 3, 619, 3, 556, 4, 544, 4, 364, 4, 363, 4, 362, 4, 361, 4)
        SmartCursorPickaxePriorityOverride = factory.create_int_set(0, 12, 1, 665, 1, 639, 1)
        IgnoreSmartCursorPriorityAxe = factory.create_bool_set(False, 488)
        CanBeSatOnForNPCs = factory.create_bool_set(False, 15, 497)
        CanBeSatOnForPlayers = factory.create_bool_set(False, 15, 497, 89, 102, 487)
        CanBeSleptIn = factory.create_bool_set(False, 79)
        IgnoresTileReplacementDropCheckWhenBeingPlaced = factory.create_bool_set(False, 158, 30)
        DoesntPlaceWithTileReplacement = factory.create_bool_set(False, 2, 60, 70, 109, 199, 23, 661, 662, 633)
        DoesntGetReplacedWithTileReplacement = factory.create_bool_set(False, 58, 225, 171, 127, 481, 482, 483, 423)
        IsVine = factory.create_bool_set(False, 52, 382, 62, 115, 205, 528, 636, 638)
        IsBeam = factory.create_bool_set(False, 124, 561, 574, 575, 576, 577, 578)
        IsLivingFire = factory.create_bool_set(False, 336, 340, 342, 341, 343, 344)
        Platforms = factory.create_bool_set(False, 19, 427, 435, 436, 437, 438, 439)
        ReplaceTileBreakUp = factory.create_bool_set(False, 27, 20, 227, 24, 201, 110, 113, 61, 703, 74, 71, 3, 73, 186, 187, 185, 233, 530, 705, 236, 702, 238, 254, 484, 485, 84, 82, 83, 529, 549, 590, 595, 615, 624, 700, 637)
        ReplaceTileBreakDown = factory.create_bool_set(False, 205, 115, 62, 52, 382, 444, 528, 638, 636)
        SlowlyDiesInWater = factory.create_bool_set(False, 3, 20, 24, 27, 73, 201, 80, 110, 529, 530, 590, 595, 615, 637)
        SpawnsNatureFlies = factory.create_bool_set(False, 3, 20, 24, 27, 73, 201, 80, 110, 529, 530, 595, 615, 637)
        DoNotAdjustDrawPositionBasedOnTileWidth = factory.create_bool_set(False, 711)
        DrawsWalls = factory.create_bool_set(False, 54, 191, 328, 162, 48, 232, 127, 459, 541, 546, 748, 750)
        TeamTiles = factory.create_bool_set(False, 426, 430, 431, 432, 433, 434, 427, 435, 436, 437, 438, 439, 727, 728, 729, 730, 731, 732)
        ConveyorDirection = factory.create_int_set(0, 421, 1, 422, -1)
        VineThreads = factory.create_bool_set(False, 382, 62, 115, 205, 52, 528, 636, 638)
        ReverseVineThreads = factory.create_bool_set(False, 549)
        HasSlopeFrames = factory.create_bool_set(False, 421, 422)
        TileInteractRead = factory.create_bool_set(False, 55, 85, 425, 573)
        IgnoresNearbyHalfbricksWhenDrawn = factory.create_bool_set(False, 380, 476, 235, 138, 664, 137, 484, 421, 422, 711, 712, 713, 714, 715, 716)
        SwaysInWindBasic = factory.create_bool_set(False, 3, 20, 24, 61, 703, 71, 73, 74, 83, 84, 110, 113, 201, 227, 529, 590, 595, 615, 624, 700, 656, 701, 637)
        DrawFlipMode = factory.create_int_set(0, 3, 1, 13, 1, 20, 1, 24, 1, 49, 1, 372, 1, 646, 1, 50, 1, 52, 1, 61, 1, 62, 1, 71, 1, 73, 1, 74, 1, 81, 1, 82, 1, 83, 1, 84, 1, 91, 1, 92, 1, 93, 1, 110, 1, 113, 1, 115, 1, 135, 1, 141, 1, 165, 1, 174, 1, 201, 1, 205, 1, 227, 1, 270, 1, 271, 1, 382, 1, 184, 2, 185, 3, 528, 1, 529, 1, 590, 1, 595, 1, 615, 1, 624, 1, 700, 1, 638, 1, 636, 1, 656, 1, 701, 1)
        HasOutlines = factory.create_bool_set(False, 10, 11, 15, 21, 29, 55, 79, 85, 88, 89, 97, 102, 104, 125, 132, 136, 139, 144, 207, 209, 212, 215, 216, 237, 287, 335, 338, 354, 356, 377, 386, 387, 388, 389, 410, 411, 425, 441, 455, 463, 467, 468, 470, 475, 487, 480, 494, 497, 509, 510, 511, 621, 464, 657, 658, 663, 699, 720, 721, 725, 733, 16, 17, 18, 26, 77, 86, 94, 96, 101, 106, 114, 133, 134, 217, 218, 220, 228, 243, 247, 283, 300, 301, 302, 303, 304, 305, 306, 307, 308, 412, 499, 622, 355, 172)
        DoesNotOpenCraftingMenuOnInteract = factory.create_bool_set(False, 215, 207)
        CountsAsWaterForCrafting = factory.create_bool_set(False, 172, 207)
        AllTiles = factory.create_bool_set(True)
        Dirt = factory.create_bool_set(False, 0, 668)
        Mud = factory.create_bool_set(False, 59)
        Ash = factory.create_bool_set(False, 57)
        Snow = factory.create_bool_set(False, 147)
        Ices = factory.create_bool_set(False, 161, 200, 163, 164)
        IcesSlush = factory.create_bool_set(False, 161, 200, 163, 164, 224)
        IcesSnow = factory.create_bool_set(False, 161, 200, 163, 164, 147)
        GrassSpecial = factory.create_bool_set(False, 70, 60, 661, 662)
        JungleSpecial = factory.create_bool_set(False, 226, 225, 211)
        HellSpecial = factory.create_bool_set(False, 58, 76, 75)
        Leaves = factory.create_bool_set(False, 384, 192)
        bonusCutTiles = factory.create_bool_set(False, 233)
        tileMossBrick = factory.create_bool_set(False, 512, 513, 514, 515, 516, 517, 535, 537, 540, 626, 628)
        GeneralPlacementTiles = factory.create_bool_set(True, 225, 41, 481, 43, 482, 44, 483, 226, 203, 112, 25, 70, 151, 21, 31, 696, 467, 12, 665, 639, 138, 664, 711, 712, 713, 714, 715, 716)
        PreventsActuationUnder = factory.create_bool_set(False, 21, 467, 26, 77, 88, 470, 475, 237, 597, 441, 468)
        BasicChest = factory.create_bool_set(False, 21, 467)
        BasicChestFake = factory.create_bool_set(False, 441, 468)
        BasicDresser = factory.create_bool_set(False, 88)
        CanBeClearedDuringGeneration = factory.create_bool_set(True, 396, 400, 401, 397, 398, 399, 404, 368, 367, 41, 43, 44, 481, 482, 483, 226, 237)
        PreventsSlopesDuringGeneration = factory.create_bool_set(False, 48, 137, 232, 191, 151, 274, 135, 442, 428)
        CorruptBiomeSight = factory.create_bool_set(False, 23, 661, 25, 112, 163, 398, 400, 636, 24, 32)
        Corrupt = factory.create_bool_set(False, 23, 661, 25, 112, 163, 398, 400, 636)
        SpreadsCorruption = factory.create_bool_set(False, 23, 661, 25, 112, 398, 400, 163, 32, 636, 24)
        HallowBiomeSight = factory.create_bool_set(False, 109, 492, 117, 116, 164, 402, 403, 115, 110, 113)
        Hallow = factory.create_bool_set(False, 109, 492, 117, 116, 164, 402, 403, 115)
        SpreadsHallow = factory.create_bool_set(False, 109, 492, 117, 116, 402, 403, 164, 115, 110, 113)
        CanGrowCrystalShards = factory.create_bool_set(False, 117, 116, 164, 402, 403)
        CrimsonBiomeSight = factory.create_bool_set(False, 199, 662, 203, 234, 200, 399, 401, 205, 201, 352)
        Crimson = factory.create_bool_set(False, 199, 662, 203, 234, 200, 399, 401, 205)
        SpreadsCrimson = factory.create_bool_set(False, 199, 662, 203, 234, 399, 401, 200, 352, 205, 201)
        UsesADifferentTileTypeForNPCSpawning = factory.create_bool_set(False, 421, 422)
        BlocksStairs = factory.create_bool_set(False, 386, 387, 54, 328, 459, 541)
        NotReallySolid = factory.create_bool_set(False, 387, 388, 10)
        BlocksWaterDrawingBehindSelf = factory.create_bool_set(False, 54, 541, 328, 459, 470)
        AllowLightInWater = factory.create_bool_set(False, 54, 541, 328, 459, 748, 750)
        TruncatesWalls = factory.create_bool_set(False, 54, 328, 459, 748)
        FrameImportantEchoCulling = factory.create_bool_set(False, 19, 436, 435, 438, 427, 439, 437, 380)
        NeedsGrassFraming = factory.create_bool_set(False, 633)
        NeedsGrassFramingDirt = factory.create_int_set(0, 633, 57)
        ChecksForMerge = factory.create_bool_set(False, 0, 668, 2, 661, 60, 70, 199, 662, 109, 477, 492, 633, 747, 57, 58, 75, 76, 684, 147, 161, 164, 163, 200, 162, 189, 196, 460, 717, 718, 719, 170, 738, 224, 191, 383, 211, 225, 59, 226, 396, 397, 398, 399, 402, 400, 401, 403, 404, 234, 112, 407)
        FramesOnKillWall = factory.create_bool_set(False, 440, 240, 241, 242, 245, 246, 4, 136, 334, 132, 55, 395, 425, 440, 471, 510, 511, 573, 630, 631, 723)
        AvoidedByNPCs = factory.create_bool_set(False, 21, 467, 55, 85, 395, 88, 463, 334, 29, 97, 99, 356, 663, 425, 440, 209, 441, 468, 471, 491, 510, 511, 520, 573, 698)
        InteractibleByNPCs = factory.create_bool_set(False, 17, 77, 133, 12, 665, 639, 26, 695, 35, 36, 55, 395, 471, 698, 21, 467, 29, 97, 88, 99, 463, 491, 33, 372, 174, 49, 646, 100, 173, 78, 79, 94, 96, 101, 50, 707, 103, 282, 106, 114, 125, 171, 172, 207, 215, 220, 219, 244, 228, 237, 247, 128, 269, 354, 355, 377, 287, 378, 390, 302, 405, 406, 411, 425, 209, 441, 468, 452, 454, 455, 457, 462, 470, 475, 494, 499, 505, 511, 510, 520, 543, 565, 573, 597, 598, 617, 621, 464, 642, 699)
        HousingWalls = factory.create_bool_set(False, 11, 389, 386)
        BreakableWhenPlacing = factory.create_bool_set(False, 324, 186, 187, 185, 165, 530, 233, 227, 485, 81, 624)
        TouchDamageDestroyTile = factory.create_bool_set(False, 32, 69, 352, 655)
        Suffocate = factory.create_bool_set(False, 53, 112, 116, 123, 224, 234)
        TouchDamageHot = factory.create_bool_set(False, 37, 58, 76, 684, 230)
        TouchDamageBleeding = factory.create_bool_set(False, 48, 232, 750)
        TouchDamageImmediate = factory.create_int_set(0, 32, 10, 69, 17, 80, 6, 352, 10, 655, 100, 48, 60, 232, 80, 484, 25, 750, 70)
        Falling = factory.create_bool_set(False, 53, 234, 112, 116, 224, 123, 330, 331, 332, 333, 495)
        BlockMergesWithMergeAllBlock = factory.create_bool_set(False)
        OreMergesWithMud = factory.create_bool_set(False, 7, 166, 6, 167, 9, 168, 8, 169, 22, 204, 37, 58, 107, 221, 108, 222, 111, 223)
        Gems = factory.create_bool_set(False, 67, 66, 65, 63, 64, 68)
        Ore = factory.create_bool_set(False, 7, 166, 6, 167, 9, 168, 8, 169, 22, 204, 37, 58, 107, 221, 108, 222, 111, 223, 211)
        Torches = factory.create_bool_set(False, 4)
        Campfires = factory.create_bool_set(False, 215)
        IsAContainer = factory.create_bool_set(False, 21, 467, 88)
        NoQuickGrapple = factory.create_bool_set(False, 4, 33, 372, 174, 646, 49)
        FriendlyFairyCanLureTo = factory.create_bool_set(False, 8, 169, 21, 467, 107, 108, 111, 221, 222, 223, 211, 12, 665, 639, 236, 702, 227)
        IgnoredInHouseScore = factory.create_bool_set(False, 4, 3, 73, 82, 83, 84, 386)
        SpreadOverground = factory.create_bool_set(False, 2, 23, 661, 32, 60, 70, 109, 199, 662, 352, 477, 492, 633, 226)
        SpreadUnderground = factory.create_bool_set(False, 23, 661, 109, 199, 662, 60, 70, 633, 226)
        IgnoreDrawLightConditions = factory.create_bool_set(False, 144, 300, 303, 306)
        AttractsStormLightning = factory.create_bool_set(False, 6, 7, 8, 9, 16, 22, 37, 45, 46, 47, 48, 49, 58, 76, 92, 96, 97, 99, 102, 107, 108, 111, 121, 122, 132, 133, 134, 136, 139, 140, 142, 143, 144, 149, 150, 166, 167, 168, 169, 173, 174, 175, 176, 177, 202, 204, 210, 211, 214, 221, 222, 223, 235, 239, 247, 248, 249, 250, 272, 283, 284, 287, 301, 305, 306, 307, 314, 315, 325, 330, 331, 332, 333, 346, 347, 348, 350, 356, 370, 372, 390, 406, 408, 409, 411, 415, 416, 417, 418, 419, 420, 423, 424, 425, 429, 445, 462, 463, 472, 473, 489, 490, 493, 499, 506, 546, 557, 560, 564, 565, 571, 617, 642, 646, 657, 658, 663, 669, 670, 671, 672, 673, 674, 675, 676, 680, 681, 682, 684, 685, 686, 706, 720, 721, 722, 725, 726, 733, 735, 739)
        SaveSlopes = factory.create_bool_set(False)

    class RoomNeeds:
        factory = SetFactory(TileID.Count)
        CountsAsChairTypes = [15, 79, 89, 102, 487, 497]
        CountsAsChair = factory.create_bool_set(False, *CountsAsChairTypes)
        CountsAsTableTypes = [14, 18, 87, 88, 90, 101, 354, 355, 464, 469, 487, 699]
        CountsAsTable = factory.create_bool_set(False, *CountsAsTableTypes)
        CountsAsTorchTypes = [4, 33, 34, 35, 42, 49, 93, 95, 98, 100, 149, 173, 174, 270, 271, 316, 317, 318, 92, 372, 646, 405, 592, 572, 581, 660]
        CountsAsTorch = factory.create_bool_set(False, *CountsAsTorchTypes)
        CountsAsDoorTypes = [10, 11, 19, 387, 386, 388, 389, 436, 435, 438, 427, 439, 437]
        CountsAsDoor = factory.create_bool_set(False, *CountsAsDoorTypes)

    class TileCutIgnore:
        factory = SetFactory(TileID.Count)
        NoneValue = factory.create_bool_set(False)
        IgnoreDontHurtNature = factory.create_bool_set(True, 654, 444, 485, 231, 484, 32, 352, 655, 69, 51, 481, 482, 483)
        Regrowth = factory.create_bool_set(False, 3, 24, 52, 382, 61, 703, 62, 71, 73, 74, 82, 83, 84, 110, 113, 115, 184, 205, 201, 519, 518, 528, 529, 530, 705, 549, 637, 638, 636)

    class Wiring:
        factory = SetFactory(TileID.Count)
        IsAMechanism = factory.create_bool_set(False, 420, 419, 411, 4, 33, 100, 93, 42, 34, 215, 405, 92, 35, 126, 95, 149, 593, 594, 564, 10, 11, 387, 386, 388, 389, 137, 443, 141, 130, 131, 546, 557, 421, 422, 209, 212, 216, 338, 335, 497, 406, 244, 452, 565, 139, 506, 105, 349, 531, 429, 142, 143, 235, 210, 425, 21, 467, 219, 642, 356, 663, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268, 207, 480, 455, 509, 657, 658, 720, 721, 725, 733, 314)
        IsATrigger = factory.create_bool_set(False, 135, 136, 132, 144, 411, 423, 476, 440, 441, 468)
        IgnoreWhenValidatingTraps = factory.create_bool_set(False, 411, 10, 11, 387, 386, 388, 389, 4, 215, 21, 467, 219, 642, 314)
