"""
TorchID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from terrex.id.set_factory import SetFactory
from enum import IntEnum, auto


class TorchID(IntEnum):
    Torch = 0
    Blue = 1
    Red = 2
    Green = 3
    Purple = 4
    White = 5
    Yellow = 6
    Demon = 7
    Cursed = 8
    Ice = 9
    Orange = 10
    Ichor = 11
    UltraBright = 12
    Bone = 13
    Rainbow = 14
    Pink = 15
    Desert = 16
    Coral = 17
    Corrupt = 18
    Crimson = 19
    Hallowed = 20
    Jungle = 21
    Mushroom = 22
    Shimmer = 23
    Count = 24


class TorchIDSets:
    class Main:
        factory = SetFactory(TorchID.Count)
        IsABiomeTorch = factory.create_bool_set(False, 0, 18, 19, 20, 21, 23, 13, 7, 9, 22, 16)
