"""
TileChangeType - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class TileChangeType(IntEnum):
    NoneValue = 0
    LavaWater = 1
    HoneyWater = 2
    HoneyLava = 3
    ShimmerWater = 4
    ShimmerLava = 5
    ShimmerHoney = 6

