"""
PlayerTextureID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class PlayerTextureID(IntEnum):
    Head = 0
    EyeWhites = 1
    Eyes = 2
    TorsoSkin = 3
    Undershirt = 4
    Hands = 5
    Shirt = 6
    ArmSkin = 7
    ArmUndershirt = 8
    ArmHand = 9
    LegSkin = 10
    Pants = 11
    Shoes = 12
    ArmShirt = 13
    Extra = 14
    EyeBlink = 15

