from enum import IntEnum


class SkyEntityType(IntEnum):
    BirdsV = 0
    Wyvern = 1
    Airship = 2
    AirBalloon = 3
    Eyeball = 4
    Meteor = 5
    BoneSerpent = 6
    Bats = 7
    Butterflies = 8
    LostKite = 9
    Vulture = 10
    PixiePosse = 11
    Seagulls = 12
    SlimeBalloons = 13
    Gastropods = 14
    Pegasus = 15
    EaterOfSouls = 16
    Crimera = 17
    Hellbats = 18
