"""
WaterStyleID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class WaterStyleID(IntEnum):
    Purity = 0
    Lava = 1
    Corrupt = 2
    Jungle = 3
    Hallow = 4
    Snow = 5
    Desert = 6
    Underground = 7
    Cavern = 8
    Bloodmoon = 9
    Crimson = 10
    Honey = 11
    UndergroundDesert = 12

