"""
LiquidID - autogenerated from decompiled Terraria .cs files
Terraria namespace: Terraria.ID
Terraria version: v1.4.5.5
Generator: TerrariaPyGen v1.1.1 (Maksim Stashkevich)
Generated on: 2026-02-15 09:24
"""

from enum import IntEnum, auto


class LiquidID(IntEnum):
    Water = 0
    Lava = 1
    Honey = 2
    Shimmer = 3

